@@ -1,23 +1,27 @@
 <?php
 /**
+ * Authentication plugin interface
+ *
+ * Copyright © 2004 Brion Vibber <brion@pobox.com>
+ * http://www.mediawiki.org/
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
-# Copyright (C) 2004 Brion Vibber <brion@pobox.com>
-# http://www.mediawiki.org/
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-# http://www.gnu.org/copyleft/gpl.html
 
 /**
  * Authentication plugin interface. Instantiate a subclass of AuthPlugin
@@ -63,8 +67,9 @@ class AuthPlugin {
 	 * Modify options in the login template.
 	 *
 	 * @param $template UserLoginTemplate object.
+	 * @param $type String 'signup' or 'login'.
 	 */
-	public function modifyUITemplate( &$template ) {
+	public function modifyUITemplate( &$template, &$type ) {
 		# Override this!
 		$template->set( 'usedomain', false );
 	}
@@ -97,14 +102,13 @@ class AuthPlugin {
 	 * The User object is passed by reference so it can be modified; don't
 	 * forget the & on your function declaration.
 	 *
-	 * @param User $user
+	 * @param $user User object
 	 */
 	public function updateUser( &$user ) {
 		# Override this and do something
 		return true;
 	}
 
-
 	/**
 	 * Return true if the wiki should create a new local account automatically
 	 * when asked to login a user who doesn't exist locally but does in the
@@ -116,12 +120,33 @@ class AuthPlugin {
 	 *
 	 * This is just a question, and shouldn't perform any actions.
 	 *
-	 * @return bool
+	 * @return Boolean
 	 */
 	public function autoCreate() {
 		return false;
 	}
 
+	/**
+	 * Allow a property change? Properties are the same as preferences
+	 * and use the same keys. 'Realname' 'Emailaddress' and 'Nickname'
+	 * all reference this.
+	 *
+	 * @param $prop string
+	 *
+	 * @return Boolean
+	 */
+	public function allowPropChange( $prop = '' ) {
+		if ( $prop == 'realname' && is_callable( array( $this, 'allowRealNameChange' ) ) ) {
+			return $this->allowRealNameChange();
+		} elseif ( $prop == 'emailaddress' && is_callable( array( $this, 'allowEmailChange' ) ) ) {
+			return $this->allowEmailChange();
+		} elseif ( $prop == 'nickname' && is_callable( array( $this, 'allowNickChange' ) ) ) {
+			return $this->allowNickChange();
+		} else {
+			return true;
+		}
+	}
+
 	/**
 	 * Can users change their passwords?
 	 *
@@ -152,7 +177,7 @@ class AuthPlugin {
 	 * Return true if successful.
 	 *
 	 * @param $user User object.
-	 * @return bool
+	 * @return Boolean
 	 */
 	public function updateExternalDB( $user ) {
 		return true;
@@ -161,7 +186,7 @@ class AuthPlugin {
 	/**
 	 * Check to see if external accounts can be created.
 	 * Return true if external accounts can be created.
-	 * @return bool
+	 * @return Boolean
 	 */
 	public function canCreateAccounts() {
 		return false;
@@ -171,24 +196,23 @@ class AuthPlugin {
 	 * Add a user to the external authentication database.
 	 * Return true if successful.
 	 *
-	 * @param User $user - only the name should be assumed valid at this point
-	 * @param string $password
-	 * @param string $email
-	 * @param string $realname
-	 * @return bool
+	 * @param $user User: only the name should be assumed valid at this point
+	 * @param $password String
+	 * @param $email String
+	 * @param $realname String
+	 * @return Boolean
 	 */
-	public function addUser( $user, $password, $email='', $realname='' ) {
+	public function addUser( $user, $password, $email = '', $realname = '' ) {
 		return true;
 	}
 
-
 	/**
 	 * Return true to prevent logins that don't authenticate here from being
 	 * checked against the local database's password fields.
 	 *
 	 * This is just a question, and shouldn't perform any actions.
 	 *
-	 * @return bool
+	 * @return Boolean
 	 */
 	public function strict() {
 		return false;
@@ -199,7 +223,7 @@ class AuthPlugin {
 	 * If either this or strict() returns true, local authentication is not used.
 	 *
 	 * @param $username String: username.
-	 * @return bool
+	 * @return Boolean
 	 */
 	public function strictUserAuth( $username ) {
 		return false;
@@ -214,9 +238,9 @@ class AuthPlugin {
 	 * forget the & on your function declaration.
 	 *
 	 * @param $user User object.
-	 * @param $autocreate bool True if user is being autocreated on login
+	 * @param $autocreate Boolean: True if user is being autocreated on login
 	 */
-	public function initUser( &$user, $autocreate=false ) {
+	public function initUser( &$user, $autocreate = false ) {
 		# Override this to do something.
 	}
 
@@ -227,38 +251,48 @@ class AuthPlugin {
 	public function getCanonicalName( $username ) {
 		return $username;
 	}
-	
+
 	/**
 	 * Get an instance of a User object
 	 *
 	 * @param $user User
-	 * @public
+	 *
+	 * @return AuthPluginUser
 	 */
 	public function getUserInstance( User &$user ) {
 		return new AuthPluginUser( $user );
 	}
+
+	/**
+	 * Get a list of domains (in HTMLForm options format) used.
+	 *
+	 * @return array
+	 */
+	public function domainList() {
+		return array();
+	}
 }
 
 class AuthPluginUser {
 	function __construct( $user ) {
 		# Override this!
 	}
-	
+
 	public function getId() {
 		# Override this!
 		return -1;
 	}
-	
+
 	public function isLocked() {
 		# Override this!
 		return false;
 	}
-	
+
 	public function isHidden() {
 		# Override this!
 		return false;
 	}
-	
+
 	public function resetAuthToken() {
 		# Override this!
 		return true;
