@@ -1,6 +1,7 @@
 <?php
 /**
  * File for magic words
+ *
  * See docs/magicword.txt
  *
  * @file
@@ -29,13 +30,19 @@ class MagicWord {
 	/**#@+
 	 * @private
 	 */
-	var $mId, $mSynonyms, $mCaseSensitive, $mRegex;
-	var $mRegexStart, $mBaseRegex, $mVariableRegex;
-	var $mModified, $mFound;
+	var $mId, $mSynonyms, $mCaseSensitive;
+	var $mRegex = '';
+	var $mRegexStart = '';
+	var $mBaseRegex = '';
+	var $mVariableRegex = '';
+	var $mVariableStartToEndRegex = '';
+	var $mModified = false;
+	var $mFound = false;
 
 	static public $mVariableIDsInitialised = false;
 	static public $mVariableIDs = array(
 		'currentmonth',
+		'currentmonth1',
 		'currentmonthname',
 		'currentmonthnamegen',
 		'currentmonthabbrev',
@@ -46,6 +53,7 @@ class MagicWord {
 		'currenttime',
 		'currenthour',
 		'localmonth',
+		'localmonth1',
 		'localmonthname',
 		'localmonthnamegen',
 		'localmonthabbrev',
@@ -58,10 +66,12 @@ class MagicWord {
 		'numberofarticles',
 		'numberoffiles',
 		'numberofedits',
+		'articlepath',
 		'sitename',
 		'server',
 		'servername',
 		'scriptpath',
+		'stylepath',
 		'pagename',
 		'pagenamee',
 		'fullpagename',
@@ -76,12 +86,12 @@ class MagicWord {
 		'revisionday',
 		'revisionday2',
 		'revisionmonth',
+		'revisionmonth1',
 		'revisionyear',
 		'revisiontimestamp',
 		'revisionuser',
 		'subpagename',
 		'subpagenamee',
-		'displaytitle',
 		'talkspace',
 		'talkspacee',
 		'subjectspace',
@@ -92,31 +102,22 @@ class MagicWord {
 		'subjectpagenamee',
 		'numberofusers',
 		'numberofactiveusers',
-		'newsectionlink',
-		'nonewsectionlink',
 		'numberofpages',
 		'currentversion',
 		'basepagename',
 		'basepagenamee',
-		'urlencode',
 		'currenttimestamp',
 		'localtimestamp',
 		'directionmark',
-		'language',
 		'contentlanguage',
-		'pagesinnamespace',
 		'numberofadmins',
 		'numberofviews',
-		'defaultsort',
-		'pagesincategory',
-		'index',
-		'noindex',
-		'numberingroup',
 	);
 
 	/* Array of caching hints for ParserCache */
 	static public $mCacheTTLs = array (
 		'currentmonth' => 86400,
+		'currentmonth1' => 86400,
 		'currentmonthname' => 86400,
 		'currentmonthnamegen' => 86400,
 		'currentmonthabbrev' => 86400,
@@ -127,6 +128,7 @@ class MagicWord {
 		'currenttime' => 3600,
 		'currenthour' => 3600,
 		'localmonth' => 86400,
+		'localmonth1' => 86400,
 		'localmonthname' => 86400,
 		'localmonthnamegen' => 86400,
 		'localmonthabbrev' => 86400,
@@ -167,42 +169,46 @@ class MagicWord {
 		'index',
 		'noindex',
 		'staticredirect',
+		'notitleconvert',
+		'nocontentconvert',
 	);
 
+	static public $mSubstIDs = array(
+		'subst',
+		'safesubst',
+	);
 
 	static public $mObjects = array();
 	static public $mDoubleUnderscoreArray = null;
 
 	/**#@-*/
 
-	function __construct($id = 0, $syn = '', $cs = false) {
+	function __construct($id = 0, $syn = array(), $cs = false) {
 		$this->mId = $id;
 		$this->mSynonyms = (array)$syn;
 		$this->mCaseSensitive = $cs;
-		$this->mRegex = '';
-		$this->mRegexStart = '';
-		$this->mVariableRegex = '';
-		$this->mVariableStartToEndRegex = '';
-		$this->mModified = false;
 	}
 
 	/**
 	 * Factory: creates an object representing an ID
-	 * @static
+	 *
+	 * @param $id
+	 *
+	 * @return MagicWord
 	 */
 	static function &get( $id ) {
-		wfProfileIn( __METHOD__ );
-		if (!array_key_exists( $id, self::$mObjects ) ) {
+		if ( !isset( self::$mObjects[$id] ) ) {
 			$mw = new MagicWord();
 			$mw->load( $id );
 			self::$mObjects[$id] = $mw;
 		}
-		wfProfileOut( __METHOD__ );
 		return self::$mObjects[$id];
 	}
 
 	/**
 	 * Get an array of parser variable IDs
+	 *
+	 * @return array
 	 */
 	static function getVariableIDs() {
 		if ( !self::$mVariableIDsInitialised ) {
@@ -220,16 +226,31 @@ class MagicWord {
 		return self::$mVariableIDs;
 	}
 
-	/* Allow external reads of TTL array */
+	/**
+	 * Get an array of parser substitution modifier IDs
+	 */
+	static function getSubstIDs() {
+		return self::$mSubstIDs; 
+	}
+
+	/**
+	 * Allow external reads of TTL array
+	 *
+	 * @return array
+	 */
 	static function getCacheTTL($id) {
-		if (array_key_exists($id,self::$mCacheTTLs)) {
+		if ( array_key_exists( $id, self::$mCacheTTLs ) ) {
 			return self::$mCacheTTLs[$id];
 		} else {
 			return -1;
 		}
 	}
 
-	/** Get a MagicWordArray of double-underscore entities */
+	/**
+	 * Get a MagicWordArray of double-underscore entities
+	 *
+	 * @return MagicWordArray
+	 */
 	static function getDoubleUnderscoreArray() {
 		if ( is_null( self::$mDoubleUnderscoreArray ) ) {
 			self::$mDoubleUnderscoreArray = new MagicWordArray( self::$mDoubleUnderscoreIDs );
@@ -237,9 +258,22 @@ class MagicWord {
 		return self::$mDoubleUnderscoreArray;
 	}
 
-	# Initialises this object with an ID
+	/**
+	 * Clear the self::$mObjects variable
+	 * For use in parser tests
+	 */
+	public static function clearCache() {
+		self::$mObjects = array();
+	}
+
+	/**
+	 * Initialises this object with an ID
+	 *
+	 * @param $id
+	 */
 	function load( $id ) {
 		global $wgContLang;
+		wfProfileIn( __METHOD__ );
 		$this->mId = $id;
 		$wgContLang->getMagic( $this );
 		if ( !$this->mSynonyms ) {
@@ -247,6 +281,7 @@ class MagicWord {
 			#throw new MWException( "Error: invalid magic word '$id'" );
 			wfDebugLog( 'exception', "Error: invalid magic word '$id'\n" );
 		}
+		wfProfileOut( __METHOD__ );
 	}
 
 	/**
@@ -254,13 +289,13 @@ class MagicWord {
 	 * @private
 	 */
 	function initRegex() {
-		#$variableClass = Title::legalChars();
-		# This was used for matching "$1" variables, but different uses of the feature will have
-		# different restrictions, which should be checked *after* the MagicWord has been matched,
-		# not here. - IMSoP
+		// Sort the synonyms by length, descending, so that the longest synonym
+		// matches in precedence to the shortest
+		$synonyms = $this->mSynonyms;
+		usort( $synonyms, array( $this, 'compareStringLength' ) );
 
 		$escSyn = array();
-		foreach ( $this->mSynonyms as $synonym )
+		foreach ( $synonyms as $synonym )
 			// In case a magic word contains /, like that's going to happen;)
 			$escSyn[] = preg_quote( $synonym, '/' );
 		$this->mBaseRegex = implode( '|', $escSyn );
@@ -273,8 +308,32 @@ class MagicWord {
 			"/^(?:{$this->mBaseRegex})$/{$case}" );
 	}
 
+	/**
+	 * A comparison function that returns -1, 0 or 1 depending on whether the 
+	 * first string is longer, the same length or shorter than the second 
+	 * string.
+	 *
+	 * @param $s1 string
+	 * @param $s2 string
+	 *
+	 * @return int
+	 */
+	function compareStringLength( $s1, $s2 ) {
+		$l1 = strlen( $s1 );
+		$l2 = strlen( $s2 );
+		if ( $l1 < $l2 ) {
+			return 1;
+		} elseif ( $l1 > $l2 ) {
+			return -1;
+		} else {
+			return 0;
+		}
+	}
+
 	/**
 	 * Gets a regex representing matching the word
+	 *
+	 * @return string
 	 */
 	function getRegex() {
 		if ($this->mRegex == '' ) {
@@ -287,6 +346,8 @@ class MagicWord {
 	 * Gets the regexp case modifier to use, i.e. i or nothing, to be used if
 	 * one is using MagicWord::getBaseRegex(), otherwise it'll be included in
 	 * the complete expression
+	 *
+	 * @return string
 	 */
 	function getRegexCase() {
 		if ( $this->mRegex === '' )
@@ -297,6 +358,8 @@ class MagicWord {
 
 	/**
 	 * Gets a regex matching the word, if it is at the string start
+	 *
+	 * @return string
 	 */
 	function getRegexStart() {
 		if ($this->mRegex == '' ) {
@@ -307,6 +370,8 @@ class MagicWord {
 
 	/**
 	 * regex without the slashes and what not
+	 *
+	 * @return string
 	 */
 	function getBaseRegex() {
 		if ($this->mRegex == '') {
@@ -317,18 +382,24 @@ class MagicWord {
 
 	/**
 	 * Returns true if the text contains the word
+	 *
+	 * @paran $text string
+	 *
 	 * @return bool
 	 */
 	function match( $text ) {
-		return preg_match( $this->getRegex(), $text );
+		return (bool)preg_match( $this->getRegex(), $text );
 	}
 
 	/**
 	 * Returns true if the text starts with the word
+	 *
+	 * @param $text string
+	 *
 	 * @return bool
 	 */
 	function matchStart( $text ) {
-		return preg_match( $this->getRegexStart(), $text );
+		return (bool)preg_match( $this->getRegexStart(), $text );
 	}
 
 	/**
@@ -336,12 +407,16 @@ class MagicWord {
 	 * The return code is the matched string, if there's no variable
 	 * part in the regex and the matched variable part ($1) if there
 	 * is one.
+	 *
+	 * @param $text string
+	 *
+	 * @return string
 	 */
 	function matchVariableStartToEnd( $text ) {
 		$matches = array();
 		$matchcount = preg_match( $this->getVariableStartToEndRegex(), $text, $matches );
 		if ( $matchcount == 0 ) {
-			return NULL;
+			return null;
 		} else {
 			# multiple matched parts (variable match); some will be empty because of
 			# synonyms. The variable will be the second non-empty one so remove any
@@ -350,8 +425,11 @@ class MagicWord {
 
 			$matches = array_values(array_filter($matches));
 
-			if ( count($matches) == 1 ) { return $matches[0]; }
-			else { return $matches[1]; }
+			if ( count($matches) == 1 ) {
+				return $matches[0];
+			} else {
+				return $matches[1];
+			}
 		}
 	}
 
@@ -359,6 +437,10 @@ class MagicWord {
 	/**
 	 * Returns true if the text matches the word, and alters the
 	 * input string, removing all instances of the word
+	 *
+	 * @param $text string
+	 *
+	 * @return bool
 	 */
 	function matchAndRemove( &$text ) {
 		$this->mFound = false;
@@ -366,6 +448,10 @@ class MagicWord {
 		return $this->mFound;
 	}
 
+	/**
+	 * @param  $text
+	 * @return bool
+	 */
 	function matchStartAndRemove( &$text ) {
 		$this->mFound = false;
 		$text = preg_replace_callback( $this->getRegexStart(), array( &$this, 'pregRemoveAndRecord' ), $text );
@@ -374,17 +460,24 @@ class MagicWord {
 
 	/**
 	 * Used in matchAndRemove()
-	 * @private
-	 **/
-	function pregRemoveAndRecord( ) {
+	 *
+	 * @return string
+	 */
+	function pregRemoveAndRecord() {
 		$this->mFound = true;
 		return '';
 	}
 
 	/**
 	 * Replaces the word with something else
+	 *
+	 * @param $replacement
+	 * @param $subject
+	 * @param $limit int
+	 *
+	 * @return string
 	 */
-	function replace( $replacement, $subject, $limit=-1 ) {
+	function replace( $replacement, $subject, $limit = -1 ) {
 		$res = preg_replace( $this->getRegex(), StringUtils::escapeRegexReplacement( $replacement ), $subject, $limit );
 		$this->mModified = !($res === $subject);
 		return $res;
@@ -394,6 +487,11 @@ class MagicWord {
 	 * Variable handling: {{SUBST:xxx}} style words
 	 * Calls back a function to determine what to replace xxx with
 	 * Input word must contain $1
+	 *
+	 * @param $text string
+	 * @param $callback
+	 *
+	 * @return string
 	 */
 	function substituteCallback( $text, $callback ) {
 		$res = preg_replace_callback( $this->getVariableRegex(), $callback, $text );
@@ -403,6 +501,8 @@ class MagicWord {
 
 	/**
 	 * Matches the word, where $1 is a wildcard
+	 *
+	 * @return string
 	 */
 	function getVariableRegex()	{
 		if ( $this->mVariableRegex == '' ) {
@@ -413,6 +513,8 @@ class MagicWord {
 
 	/**
 	 * Matches the entire string, where $1 is a wildcard
+	 *
+	 * @return string
 	 */
 	function getVariableStartToEndRegex() {
 		if ( $this->mVariableStartToEndRegex == '' ) {
@@ -423,11 +525,18 @@ class MagicWord {
 
 	/**
 	 * Accesses the synonym list directly
+	 *
+	 * @param $i int
+	 *
+	 * @return string
 	 */
 	function getSynonym( $i ) {
 		return $this->mSynonyms[$i];
 	}
 
+	/**
+	 * @return array
+	 */
 	function getSynonyms() {
 		return $this->mSynonyms;
 	}
@@ -435,6 +544,8 @@ class MagicWord {
 	/**
 	 * Returns true if the last call to replace() or substituteCallback()
 	 * returned a modified text, otherwise false.
+	 *
+	 * @return bool
 	 */
 	function getWasModified(){
 		return $this->mModified;
@@ -445,8 +556,14 @@ class MagicWord {
 	 * This method uses the php feature to do several replacements at the same time,
 	 * thereby gaining some efficiency. The result is placed in the out variable
 	 * $result. The return value is true if something was replaced.
-	 * @static
-	 **/
+	 * @todo Should this be static? It doesn't seem to be used at all
+	 *
+	 * @param $magicarr
+	 * @param $subject
+	 * @param $result
+	 *
+	 * @return bool
+	 */
 	function replaceMultiple( $magicarr, $subject, &$result ){
 		$search = array();
 		$replace = array();
@@ -463,6 +580,9 @@ class MagicWord {
 	/**
 	 * Adds all the synonyms of this MagicWord to an array, to allow quick
 	 * lookup in a list of magic words
+	 *
+	 * @param $array
+	 * @param $value
 	 */
 	function addToArray( &$array, $value ) {
 		global $wgContLang;
@@ -471,10 +591,16 @@ class MagicWord {
 		}
 	}
 
+	/**
+	 * @return bool
+	 */
 	function isCaseSensitive() {
 		return $this->mCaseSensitive;
 	}
 
+	/**
+	 * @return int
+	 */
 	function getId() {
 		return $this->mId;
 	}
@@ -496,15 +622,18 @@ class MagicWordArray {
 
 	/**
 	 * Add a magic word by name
+	 *
+	 * @param $name string
 	 */
 	public function add( $name ) {
-		global $wgContLang;
 		$this->names[] = $name;
 		$this->hash = $this->baseRegex = $this->regex = null;
 	}
 
 	/**
 	 * Add a number of magic words by name
+	 *
+	 * $param $names array
 	 */
 	public function addArray( $names ) {
 		$this->names = array_merge( $this->names, array_values( $names ) );
@@ -555,7 +684,7 @@ class MagicWordArray {
 	}
 
 	/**
-	 * Get an unanchored regex
+	 * Get an unanchored regex that does not match parameters
 	 */
 	function getRegex() {
 		if ( is_null( $this->regex ) ) {
@@ -572,14 +701,35 @@ class MagicWordArray {
 	}
 
 	/**
-	 * Get a regex for matching variables
+	 * Get a regex for matching variables with parameters
+	 *
+	 * @return string
 	 */
 	function getVariableRegex() {
 		return str_replace( "\\$1", "(.*?)", $this->getRegex() );
 	}
 
 	/**
-	 * Get an anchored regex for matching variables
+	 * Get a regex anchored to the start of the string that does not match parameters
+	 *
+	 * @return string
+	 */
+	function getRegexStart() {
+		$base = $this->getBaseRegex();
+		$newRegex = array( '', '' );
+		if ( $base[0] !== '' ) {
+			$newRegex[0] = "/^(?:{$base[0]})/iuS";
+		}
+		if ( $base[1] !== '' ) {
+			$newRegex[1] = "/^(?:{$base[1]})/S"; 
+		}
+		return $newRegex;
+	}
+
+	/**
+	 * Get an anchored regex for matching variables with parameters
+	 *
+	 * @return string
 	 */
 	function getVariableStartToEndRegex() {
 		$base = $this->getBaseRegex();
@@ -597,6 +747,10 @@ class MagicWordArray {
 	 * Parse a match array from preg_match
 	 * Returns array(magic word ID, parameter value)
 	 * If there is no parameter value, that element will be false.
+	 *
+	 * @param $m arrray
+	 *
+	 * @return array
 	 */
 	function parseMatch( $m ) {
 		reset( $m );
@@ -616,7 +770,6 @@ class MagicWordArray {
 		}
 		// This shouldn't happen either
 		throw new MWException( __METHOD__.': parameter not found' );
-		return array( false, false );
 	}
 
 	/**
@@ -624,9 +777,12 @@ class MagicWordArray {
 	 * Returns an array with the magic word name in the first element and the
 	 * parameter in the second element.
 	 * Both elements are false if there was no match.
+	 *
+	 * @param $text string
+	 *
+	 * @return array
 	 */
 	public function matchVariableStartToEnd( $text ) {
-		global $wgContLang;
 		$regexes = $this->getVariableStartToEndRegex();
 		foreach ( $regexes as $regex ) {
 			if ( $regex !== '' ) {
@@ -642,6 +798,10 @@ class MagicWordArray {
 	/**
 	 * Match some text, without parameter capture
 	 * Returns the magic word name, or false if there was no capture
+	 *
+	 * @param $text string
+	 *
+	 * @return string|false
 	 */
 	public function matchStartToEnd( $text ) {
 		$hash = $this->getHash();
@@ -659,6 +819,10 @@ class MagicWordArray {
 	/**
 	 * Returns an associative array, ID => param value, for all items that match
 	 * Removes the matched items from the input string (passed by reference)
+	 *
+	 * @param $text string
+	 *
+	 * @return array
 	 */
 	public function matchAndRemove( &$text ) {
 		$found = array();
@@ -676,4 +840,33 @@ class MagicWordArray {
 		}
 		return $found;
 	}
+
+	/**
+	 * Return the ID of the magic word at the start of $text, and remove
+	 * the prefix from $text.
+	 * Return false if no match found and $text is not modified.
+	 * Does not match parameters.
+	 *
+	 * @param $text string
+	 *
+	 * @return int|false
+	 */
+	public function matchStartAndRemove( &$text ) {
+		$regexes = $this->getRegexStart();
+		foreach ( $regexes as $regex ) {
+			if ( $regex === '' ) {
+				continue;
+			}
+			if ( preg_match( $regex, $text, $m ) ) {
+				list( $id, ) = $this->parseMatch( $m );
+				if ( strlen( $m[0] ) >= strlen( $text ) ) {
+					$text = '';
+				} else {
+					$text = substr( $text, strlen( $m[0] ) );
+				}
+				return $id;
+			}
+		}
+		return false;
+	}
 }
