@@ -1,11 +1,10 @@
 <?php
-
-/*
+/**
+ *
+ *
  * Created on Sep 19, 2006
  *
- * API for MediaWiki 1.8+
- *
- * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ * Copyright © 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,38 +18,32 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-if (!defined('MEDIAWIKI')) {
+if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ('ApiFormatBase.php');
+	require_once( 'ApiFormatBase.php' );
 }
 
 /**
- * @addtogroup API
+ * API YAML output formatter
+ * @ingroup API
  */
-class ApiFormatYaml extends ApiFormatBase {
-
-	public function __construct($main, $format) {
-		parent :: __construct($main, $format);
-	}
+class ApiFormatYaml extends ApiFormatJson {
 
 	public function getMimeType() {
 		return 'application/yaml';
 	}
 
-	public function execute() {
-		$this->printText(Spyc :: YAMLDump($this->getResultData()));
-	}
-
-	protected function getDescription() {
-		return 'Output data in YAML format' . parent :: getDescription();
+	public function getDescription() {
+		return 'Output data in YAML format' . parent::getDescription();
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiFormatYaml.php 23531 2007-06-29 01:19:14Z simetrical $';
+		return __CLASS__ . ': $Id: ApiFormatYaml.php 86302 2011-04-18 11:42:44Z reedy $';
 	}
 }
-
