@@ -1,11 +1,10 @@
 <?php
-
-/*
+/**
+ *
+ *
  * Created on Sep 4, 2006
  *
- * API for MediaWiki 1.8+
- *
- * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ * Copyright © 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,13 +18,15 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-if (!defined('MEDIAWIKI')) {
+if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ('ApiBase.php');
+	require_once( 'ApiBase.php' );
 }
 
 /**
@@ -53,8 +54,8 @@ class ApiResult extends ApiBase {
 	 * Constructor
 	 * @param $main ApiMain object
 	 */
-	public function __construct($main) {
-		parent :: __construct($main, 'result');
+	public function __construct( $main ) {
+		parent::__construct( $main, 'result' );
 		$this->mIsRawMode = false;
 		$this->mCheckingSize = true;
 		$this->reset();
@@ -64,7 +65,7 @@ class ApiResult extends ApiBase {
 	 * Clear the current result data.
 	 */
 	public function reset() {
-		$this->mData = array ();
+		$this->mData = array();
 		$this->mSize = 0;
 	}
 
@@ -91,21 +92,23 @@ class ApiResult extends ApiBase {
 	public function getData() {
 		return $this->mData;
 	}
-	
+
 	/**
 	 * Get the 'real' size of a result item. This means the strlen() of the item,
 	 * or the sum of the strlen()s of the elements if the item is an array.
 	 * @param $value mixed
 	 * @return int
 	 */
-	public static function size($value) {
+	public static function size( $value ) {
 		$s = 0;
-		if(is_array($value))
-			foreach($value as $v)
-				$s += self::size($v);
-		else if(!is_object($value))
+		if ( is_array( $value ) ) {
+			foreach ( $value as $v ) {
+				$s += self::size( $v );
+			}
+		} elseif ( !is_object( $value ) ) {
 			// Objects can't always be cast to string
-			$s = strlen($value);
+			$s = strlen( $value );
+		}
 		return $s;
 	}
 
@@ -116,7 +119,7 @@ class ApiResult extends ApiBase {
 	public function getSize() {
 		return $this->mSize;
 	}
-	
+
 	/**
 	 * Disable size checking in addValue(). Don't use this unless you
 	 * REALLY know what you're doing. Values added while size checking
@@ -125,7 +128,7 @@ class ApiResult extends ApiBase {
 	public function disableSizeCheck() {
 		$this->mCheckingSize = false;
 	}
-	
+
 	/**
 	 * Re-enable size checking in addValue()
 	 */
@@ -139,57 +142,65 @@ class ApiResult extends ApiBase {
 	 * @param $arr array to add $value to
 	 * @param $name string Index of $arr to add $value at
 	 * @param $value mixed
+	 * @param $overwrite bool Whether overwriting an existing element is allowed
 	 */
-	public static function setElement(& $arr, $name, $value) {
-		if ($arr === null || $name === null || $value === null || !is_array($arr) || is_array($name))
-			ApiBase :: dieDebug(__METHOD__, 'Bad parameter');
-
-		if (!isset ($arr[$name])) {
-			$arr[$name] = $value;
+	public static function setElement( &$arr, $name, $value, $overwrite = false ) {
+		if ( $arr === null || $name === null || $value === null || !is_array( $arr ) || is_array( $name ) ) {
+			ApiBase::dieDebug( __METHOD__, 'Bad parameter' );
 		}
-		elseif (is_array($arr[$name]) && is_array($value)) {
-			$merged = array_intersect_key($arr[$name], $value);
-			if (!count($merged))
+
+		if ( !isset ( $arr[$name] ) || $overwrite ) {
+			$arr[$name] = $value;
+		} elseif ( is_array( $arr[$name] ) && is_array( $value ) ) {
+			$merged = array_intersect_key( $arr[$name], $value );
+			if ( !count( $merged ) ) {
 				$arr[$name] += $value;
-			else
-				ApiBase :: dieDebug(__METHOD__, "Attempting to merge element $name");
-		} else
-			ApiBase :: dieDebug(__METHOD__, "Attempting to add element $name=$value, existing value is {$arr[$name]}");
+			} else {
+				ApiBase::dieDebug( __METHOD__, "Attempting to merge element $name" );
+			}
+		} else {
+			ApiBase::dieDebug( __METHOD__, "Attempting to add element $name=$value, existing value is {$arr[$name]}" );
+		}
 	}
 
 	/**
 	 * Adds a content element to an array.
 	 * Use this function instead of hardcoding the '*' element.
 	 * @param $arr array to add the content element to
+	 * @param $value Mixed
 	 * @param $subElemName string when present, content element is created
 	 *  as a sub item of $arr. Use this parameter to create elements in
 	 *  format <elem>text</elem> without attributes
 	 */
-	public static function setContent(& $arr, $value, $subElemName = null) {
-		if (is_array($value))
-			ApiBase :: dieDebug(__METHOD__, 'Bad parameter');
-		if (is_null($subElemName)) {
-			ApiResult :: setElement($arr, '*', $value);
+	public static function setContent( &$arr, $value, $subElemName = null ) {
+		if ( is_array( $value ) ) {
+			ApiBase::dieDebug( __METHOD__, 'Bad parameter' );
+		}
+		if ( is_null( $subElemName ) ) {
+			ApiResult::setElement( $arr, '*', $value );
 		} else {
-			if (!isset ($arr[$subElemName]))
-				$arr[$subElemName] = array ();
-			ApiResult :: setElement($arr[$subElemName], '*', $value);
+			if ( !isset( $arr[$subElemName] ) ) {
+				$arr[$subElemName] = array();
+			}
+			ApiResult::setElement( $arr[$subElemName], '*', $value );
 		}
 	}
 
 	/**
 	 * In case the array contains indexed values (in addition to named),
 	 * give all indexed values the given tag name. This function MUST be
-	 * called on every arrray that has numerical indexes.
+	 * called on every array that has numerical indexes.
 	 * @param $arr array
 	 * @param $tag string Tag name
 	 */
-	public function setIndexedTagName(& $arr, $tag) {
+	public function setIndexedTagName( &$arr, $tag ) {
 		// In raw mode, add the '_element', otherwise just ignore
-		if (!$this->getIsRawMode())
+		if ( !$this->getIsRawMode() ) {
 			return;
-		if ($arr === null || $tag === null || !is_array($arr) || is_array($tag))
-			ApiBase :: dieDebug(__METHOD__, 'Bad parameter');
+		}
+		if ( $arr === null || $tag === null || !is_array( $arr ) || is_array( $tag ) ) {
+			ApiBase::dieDebug( __METHOD__, 'Bad parameter' );
+		}
 		// Do not use setElement() as it is ok to call this more than once
 		$arr['_element'] = $tag;
 	}
@@ -199,17 +210,17 @@ class ApiResult extends ApiBase {
 	 * @param $arr array
 	 * @param $tag string Tag name
 	 */
-	public function setIndexedTagName_recursive(&$arr, $tag)
-	{
-			if(!is_array($arr))
-					return;
-			foreach($arr as &$a)
-			{
-					if(!is_array($a))
-							continue;
-					$this->setIndexedTagName($a, $tag);
-					$this->setIndexedTagName_recursive($a, $tag);
+	public function setIndexedTagName_recursive( &$arr, $tag ) {
+		if ( !is_array( $arr ) ) {
+			return;
+		}
+		foreach ( $arr as &$a ) {
+			if ( !is_array( $a ) ) {
+				continue;
 			}
+			$this->setIndexedTagName( $a, $tag );
+			$this->setIndexedTagName_recursive( $a, $tag );
+		}
 	}
 
 	/**
@@ -220,56 +231,81 @@ class ApiResult extends ApiBase {
 	 * @param $tag string
 	 */
 	public function setIndexedTagName_internal( $path, $tag ) {
-		$data = & $this->mData;
-		foreach((array)$path as $p) {
+		$data = &$this->mData;
+		foreach ( (array)$path as $p ) {
 			if ( !isset( $data[$p] ) ) {
 				$data[$p] = array();
 			}
-			$data = & $data[$p];
+			$data = &$data[$p];
 		}
-		if(is_null($data))
+		if ( is_null( $data ) ) {
 			return;
-		$this->setIndexedTagName($data, $tag);
+		}
+		$this->setIndexedTagName( $data, $tag );
 	}
 
 	/**
 	 * Add value to the output data at the given path.
-	 * Path is an indexed array, each element specifing the branch at which to add the new value
+	 * Path is an indexed array, each element specifying the branch at which to add the new value
 	 * Setting $path to array('a','b','c') is equivalent to data['a']['b']['c'] = $value
 	 * If $name is empty, the $value is added as a next list element data[] = $value
+	 *
+	 * @param $path
+	 * @param $name string
+	 * @param $value mixed
+	 * @param $overwrite bool
+	 *
 	 * @return bool True if $value fits in the result, false if not
 	 */
-	public function addValue($path, $name, $value) {
+	public function addValue( $path, $name, $value, $overwrite = false ) {
 		global $wgAPIMaxResultSize;
-		$data = & $this->mData;
-		if( $this->mCheckingSize ) {
-			$newsize = $this->mSize + self::size($value);
-			if($newsize > $wgAPIMaxResultSize)
+		$data = &$this->mData;
+		if ( $this->mCheckingSize ) {
+			$newsize = $this->mSize + self::size( $value );
+			if ( $newsize > $wgAPIMaxResultSize ) {
+				$this->setWarning(
+					"This result was truncated because it would otherwise be larger than the " .
+							"limit of {$wgAPIMaxResultSize} bytes" );
 				return false;
+			}
 			$this->mSize = $newsize;
 		}
 
-		if (!is_null($path)) {
-			if (is_array($path)) {
-				foreach ($path as $p) {
-					if (!isset ($data[$p]))
-						$data[$p] = array ();
-					$data = & $data[$p];
+		if ( !is_null( $path ) ) {
+			if ( is_array( $path ) ) {
+				foreach ( $path as $p ) {
+					if ( !isset( $data[$p] ) ) {
+						$data[$p] = array();
+					}
+					$data = &$data[$p];
 				}
 			} else {
-				if (!isset ($data[$path]))
-					$data[$path] = array ();
-				$data = & $data[$path];
+				if ( !isset( $data[$path] ) ) {
+					$data[$path] = array();
+				}
+				$data = &$data[$path];
 			}
 		}
 
-		if (!$name)
-			$data[] = $value;	// Add list element
-		else
-			ApiResult :: setElement($data, $name, $value);	// Add named element
+		if ( !$name ) {
+			$data[] = $value; // Add list element
+		} else {
+			self::setElement( $data, $name, $value, $overwrite ); // Add named element
+		}
 		return true;
 	}
 
+	/**
+	 * Add a parsed limit=max to the result.
+	 *
+	 * @param $moduleName string
+	 * @param $limit int
+	 */
+	public function setParsedLimit( $moduleName, $limit ) {
+		// Add value, allowing overwriting
+		$this->addValue( 'limits', $moduleName, $limit, true );
+	}
+
 	/**
 	 * Unset a value previously added to the result set.
 	 * Fails silently if the value isn't found.
@@ -277,69 +313,65 @@ class ApiResult extends ApiBase {
 	 * @param $path array
 	 * @param $name string
 	 */
-	public function unsetValue($path, $name) {
-		$data = & $this->mData;
-		if(!is_null($path))
-			foreach((array)$path as $p) {
-				if(!isset($data[$p]))
+	public function unsetValue( $path, $name ) {
+		$data = &$this->mData;
+		if ( !is_null( $path ) ) {
+			foreach ( (array)$path as $p ) {
+				if ( !isset( $data[$p] ) ) {
 					return;
-				$data = & $data[$p];
+				}
+				$data = &$data[$p];
 			}
-		$this->mSize -= self::size($data[$name]);
-		unset($data[$name]);
+		}
+		$this->mSize -= self::size( $data[$name] );
+		unset( $data[$name] );
 	}
 
 	/**
 	 * Ensure all values in this result are valid UTF-8.
 	 */
-	public function cleanUpUTF8()
-	{
-		array_walk_recursive($this->mData, array('ApiResult', 'cleanUp_helper'));
+	public function cleanUpUTF8() {
+		array_walk_recursive( $this->mData, array( 'ApiResult', 'cleanUp_helper' ) );
 	}
 
 	/**
 	 * Callback function for cleanUpUTF8()
+	 *
+	 * @param $s string
 	 */
-	private static function cleanUp_helper(&$s)
-	{
-		if(!is_string($s))
+	private static function cleanUp_helper( &$s ) {
+		if ( !is_string( $s ) ) {
 			return;
-		$s = UtfNormal::cleanUp($s);
+		}
+		global $wgContLang;
+		$s = $wgContLang->normalize( $s );
+	}
+
+	/**
+	 * Converts a Status object to an array suitable for addValue
+	 * @param Status $status
+	 * @param string $errorType
+	 * @return array
+	 */
+	public function convertStatusToArray( $status, $errorType = 'error' ) {
+		if ( $status->isGood() ) {
+			return array();
+		}
+
+		$result = array();
+		foreach ( $status->getErrorsByType( $errorType ) as $error ) {
+			$this->setIndexedTagName( $error['params'], 'param' );
+			$result[] = $error;
+		}
+		$this->setIndexedTagName( $result, $errorType );
+		return $result;
 	}
 
 	public function execute() {
-		ApiBase :: dieDebug(__METHOD__, 'execute() is not supported on Result object');
+		ApiBase::dieDebug( __METHOD__, 'execute() is not supported on Result object' );
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiResult.php 47447 2009-02-18 12:41:28Z tstarling $';
-	}
-}
-
-/* For compatibility with PHP versions < 5.1.0, define our own array_intersect_key function. */
-if (!function_exists('array_intersect_key')) {
-	function array_intersect_key($isec, $keys) {
-		$argc = func_num_args();
-
-		if ($argc > 2) {
-			for ($i = 1; $isec && $i < $argc; $i++) {
-				$arr = func_get_arg($i);
-
-				foreach (array_keys($isec) as $key) {
-					if (!isset($arr[$key]))
-						unset($isec[$key]);
-				}
-			}
-
-			return $isec;
-		} else {
-			$res = array();
-			foreach (array_keys($isec) as $key) {
-				if (isset($keys[$key]))
-					$res[$key] = $isec[$key];
-			}
-
-			return $res;
-		}
+		return __CLASS__ . ': $Id: ApiResult.php 91144 2011-06-29 23:46:39Z reedy $';
 	}
 }
