@@ -1,4 +1,12 @@
 <?php
+/**
+ * Local repository that stores files in the local filesystem and registers them
+ * in the wiki's own database.
+ *
+ * @file
+ * @ingroup FileRepo
+ */
+
 /**
  * A repository that stores files in the local filesystem and registers them
  * in the wiki's own database. This is the most commonly used repository class.
@@ -6,10 +14,17 @@
  */
 class LocalRepo extends FSRepo {
 	var $fileFactory = array( 'LocalFile', 'newFromTitle' );
+	var $fileFactoryKey = array( 'LocalFile', 'newFromKey' );
 	var $oldFileFactory = array( 'OldLocalFile', 'newFromTitle' );
+	var $oldFileFactoryKey = array( 'OldLocalFile', 'newFromKey' );
 	var $fileFromRowFactory = array( 'LocalFile', 'newFromRow' );
 	var $oldFileFromRowFactory = array( 'OldLocalFile', 'newFromRow' );
 
+	/**
+	 * @throws MWException
+	 * @param  $row
+	 * @return File
+	 */
 	function newFileFromRow( $row ) {
 		if ( isset( $row->img_name ) ) {
 			return call_user_func( $this->fileFromRowFactory, $row, $this );
@@ -20,6 +35,11 @@ class LocalRepo extends FSRepo {
 		}
 	}
 
+	/**
+	 * @param $title
+	 * @param $archiveName
+	 * @return OldLocalFile
+	 */
 	function newFromArchiveName( $title, $archiveName ) {
 		return OldLocalFile::newFromArchiveName( $title, $this, $archiveName );
 	}
@@ -29,13 +49,16 @@ class LocalRepo extends FSRepo {
 	 * filearchive table. This needs to be done in the repo because it needs to
 	 * interleave database locks with file operations, which is potentially a
 	 * remote operation.
+	 *
+	 * @param $storageKeys array
+	 *
 	 * @return FileRepoStatus
 	 */
 	function cleanupDeletedBatch( $storageKeys ) {
 		$root = $this->getZonePath( 'deleted' );
 		$dbw = $this->getMasterDB();
 		$status = $this->newGood();
-		$storageKeys = array_unique($storageKeys);
+		$storageKeys = array_unique( $storageKeys );
 		foreach ( $storageKeys as $key ) {
 			$hashPath = $this->getDeletedHashPath( $key );
 			$path = "$root/$hashPath$key";
@@ -44,18 +67,21 @@ class LocalRepo extends FSRepo {
 				array( 'fa_storage_group' => 'deleted', 'fa_storage_key' => $key ),
 				__METHOD__, array( 'FOR UPDATE' ) );
 			if( !$inuse ) {
-				$sha1 = substr( $key, 0, strcspn( $key, '.' ) );
-				$ext = substr( $key, strcspn($key,'.') + 1 );
+				$sha1 = self::getHashFromKey( $key );
+				$ext = substr( $key, strcspn( $key, '.' ) + 1 );
 				$ext = File::normalizeExtension($ext);
 				$inuse = $dbw->selectField( 'oldimage', '1',
 					array( 'oi_sha1' => $sha1,
-						"oi_archive_name LIKE '%.{$ext}'",
-						'oi_deleted & '.File::DELETED_FILE => File::DELETED_FILE ),
+						'oi_archive_name ' . $dbw->buildLike( $dbw->anyString(), ".$ext" ),
+						$dbw->bitAnd('oi_deleted', File::DELETED_FILE) => File::DELETED_FILE ),
 					__METHOD__, array( 'FOR UPDATE' ) );
 			}
 			if ( !$inuse ) {
 				wfDebug( __METHOD__ . ": deleting $key\n" );
-				if ( !@unlink( $path ) ) {
+				wfSuppressWarnings();
+				$unlink = unlink( $path );
+				wfRestoreWarnings();
+				if ( !$unlink ) {
 					$status->error( 'undelete-cleanup-error', $path );
 					$status->failCount++;
 				}
@@ -67,33 +93,50 @@ class LocalRepo extends FSRepo {
 		}
 		return $status;
 	}
+
+	/**
+	 * Gets the SHA1 hash from a storage key
+	 *
+	 * @param string $key
+	 * @return string
+	 */
+	public static function getHashFromKey( $key ) {
+		return strtok( $key, '.' );
+	}
 	
 	/**
 	 * Checks if there is a redirect named as $title
 	 *
-	 * @param Title $title Title of image
+	 * @param $title Title of file
 	 */
 	function checkRedirect( $title ) {
 		global $wgMemc;
 
 		if( is_string( $title ) ) {
-			$title = Title::newFromTitle( $title );
+			$title = Title::newFromText( $title );
 		}
 		if( $title instanceof Title && $title->getNamespace() == NS_MEDIA ) {
 			$title = Title::makeTitle( NS_FILE, $title->getText() );
 		}
 
-		$memcKey = $this->getMemcKey( "image_redirect:" . md5( $title->getPrefixedDBkey() ) );
-		$cachedValue = $wgMemc->get( $memcKey );
-		if( $cachedValue ) {
-			return Title::newFromDbKey( $cachedValue );
-		} elseif( $cachedValue == ' ' ) { # FIXME: ugly hack, but BagOStuff caching seems to be weird and return false if !cachedValue, not only if it doesn't exist
-			return false;
+		$memcKey = $this->getSharedCacheKey( 'image_redirect', md5( $title->getDBkey() ) );
+		if ( $memcKey === false ) {
+			$memcKey = $this->getLocalCacheKey( 'image_redirect', md5( $title->getDBkey() ) );
+			$expiry = 300; // no invalidation, 5 minutes
+		} else {
+			$expiry = 86400; // has invalidation, 1 day
 		}
+		$cachedValue = $wgMemc->get( $memcKey );
+		if ( $cachedValue === ' '  || $cachedValue === '' ) {
+			// Does not exist
+			return false;
+		} elseif ( strval( $cachedValue ) !== '' ) {
+			return Title::newFromText( $cachedValue, NS_FILE );
+		} // else $cachedValue is false or null: cache miss
 
 		$id = $this->getArticleID( $title );
 		if( !$id ) {
-			$wgMemc->set( $memcKey, " ", 9000 );
+			$wgMemc->set( $memcKey, " ", $expiry );
 			return false;
 		}
 		$dbr = $this->getSlaveDB();
@@ -104,18 +147,21 @@ class LocalRepo extends FSRepo {
 			__METHOD__
 		);
 
-		if( $row ) $targetTitle = Title::makeTitle( $row->rd_namespace, $row->rd_title );
-		$wgMemc->set( $memcKey, ($row ? $targetTitle->getPrefixedDBkey() : " "), 9000 );
-		if( !$row ) {
+		if( $row && $row->rd_namespace == NS_FILE ) {
+			$targetTitle = Title::makeTitle( $row->rd_namespace, $row->rd_title );
+			$wgMemc->set( $memcKey, $targetTitle->getDBkey(), $expiry );
+			return $targetTitle;
+		} else {
+			$wgMemc->set( $memcKey, '', $expiry );
 			return false;
 		}
-		return $targetTitle;
 	}
 
 
 	/**
 	 * Function link Title::getArticleID().
 	 * We can't say Title object, what database it should use, so we duplicate that function here.
+	 * @param $title Title
 	 */
 	protected function getArticleID( $title ) {
 		if( !$title instanceof Title ) {
@@ -127,15 +173,17 @@ class LocalRepo extends FSRepo {
 			'page_id',	//Field
 			array(	//Conditions
 				'page_namespace' => $title->getNamespace(),
-				'page_title' => $title->getDBKey(),
+				'page_title' => $title->getDBkey(),
 			),
 			__METHOD__	//Function name
 		);
 		return $id;
 	}
 
-
-	
+	/**
+	 * Get an array or iterator of file objects for files that have a given 
+	 * SHA-1 content hash.
+	 */
 	function findBySha1( $hash ) {
 		$dbr = $this->getSlaveDB();
 		$res = $dbr->select(
@@ -145,33 +193,49 @@ class LocalRepo extends FSRepo {
 		);
 		
 		$result = array();
-		while ( $row = $res->fetchObject() )
+		foreach ( $res as $row ) {
 			$result[] = $this->newFileFromRow( $row );
-		$res->free();
-		return $result;
-	}
-	
-	/*
-	 * Find many files using one query
-	 */
-	function findFiles( $titles ) {
-	 	// FIXME: Only accepts a $titles array where the keys are the sanitized
-	 	// file names.
-	 	 
-		if ( count( $titles ) == 0 ) return array();		
-	
-		$dbr = $this->getSlaveDB();
-		$res = $dbr->select(
-			'image',
-			LocalFile::selectFields(),
-			array( 'img_name' => array_keys( $titles ) )		
-		);
-		
-		$result = array();
-		while ( $row = $res->fetchObject() ) {
-			$result[$row->img_name] = $this->newFileFromRow( $row );
 		}
 		$res->free();
+
 		return $result;
 	}
+
+	/**
+	 * Get a connection to the slave DB
+	 */
+	function getSlaveDB() {
+		return wfGetDB( DB_SLAVE );
+	}
+
+	/**
+	 * Get a connection to the master DB
+	 */
+	function getMasterDB() {
+		return wfGetDB( DB_MASTER );
+	}
+
+	/**
+	 * Get a key on the primary cache for this repository.
+	 * Returns false if the repository's cache is not accessible at this site. 
+	 * The parameters are the parts of the key, as for wfMemcKey().
+	 */
+	function getSharedCacheKey( /*...*/ ) {
+		$args = func_get_args();
+		return call_user_func_array( 'wfMemcKey', $args );
+	}
+
+	/**
+	 * Invalidates image redirect cache related to that image
+	 *
+	 * @param $title Title of page
+	 */
+	function invalidateImageRedirect( $title ) {
+		global $wgMemc;
+		$memcKey = $this->getSharedCacheKey( 'image_redirect', md5( $title->getDBkey() ) );
+		if ( $memcKey ) {
+			$wgMemc->delete( $memcKey );
+		}
+	}
 }
+
