@@ -14,13 +14,10 @@
 $fallback = 'es';
 
 $namespaceNames = array(
-	# NS_MEDIA            => 'Media',
 	NS_SPECIAL          => 'Mba\'echĩchĩ',
-	NS_MAIN             => '',
 	NS_TALK             => 'Myangekõi',
 	NS_USER             => 'Puruhára',
 	NS_USER_TALK        => 'Puruhára_myangekõi',
-	# NS_PROJECT set by $wgMetaNamespace
 	NS_PROJECT_TALK     => '$1_myangekõi',
 	NS_FILE             => 'Ta\'ãnga',
 	NS_FILE_TALK        => 'Ta\'ãnga_myangekõi',
@@ -31,7 +28,7 @@ $namespaceNames = array(
 	NS_HELP             => 'Pytyvõ',
 	NS_HELP_TALK        => 'Pytyvõ_myangekõi',
 	NS_CATEGORY         => 'Ñemohenda',
-	NS_CATEGORY_TALK    => 'Ñemohenda_myangekõi'
+	NS_CATEGORY_TALK    => 'Ñemohenda_myangekõi',
 );
 
 $messages = array(
@@ -101,16 +98,18 @@ $messages = array(
 # Categories related messages
 'pagecategories' => '{{PLURAL:$1|Ñemohenda|Ñemohendakuéra}}',
 
-'about'          => 'Rehegua',
-'article'        => 'Kuatiahai',
-'newwindow'      => "(Ojepe'a peteĩ ovetã pyahu)",
-'cancel'         => 'Mbotove',
+'about'      => 'Rehegua',
+'article'    => 'Kuatiahai',
+'newwindow'  => "(Ojepe'a peteĩ ovetã pyahu)",
+'cancel'     => 'Mbotove',
+'mypage'     => 'Che kuatiarogue',
+'mytalk'     => 'Che myangekõi',
+'navigation' => 'Kundaharã',
+
+# Cologne Blue skin
 'qbfind'         => 'Heka',
 'qbedit'         => 'Jehaijey',
 'qbspecialpages' => 'Kuatiarogue hekochĩchĩva',
-'mypage'         => 'Che kuatiarogue',
-'mytalk'         => 'Che myangekõi',
-'navigation'     => 'Kundaharã',
 
 'tagline'          => '{{SITENAME}}megua',
 'help'             => 'Pytyvõhára',
@@ -136,7 +135,7 @@ $messages = array(
 'viewtalkpage'     => 'Hecha myangekõi',
 'otherlanguages'   => "Ambue ñe'ẽ",
 'redirectedfrom'   => '(Oñembohapejeýva $1)',
-'lastmodifiedat'   => 'Ko kuatiarogue oñemoambuejeýkuri: $2, $1.', # $1 date, $2 time
+'lastmodifiedat'   => 'Ko kuatiarogue oñemoambuejeýkuri: $2, $1.',
 'viewcount'        => 'Esta página ha sido visitada $1 veces.',
 'jumpto'           => 'Kundaharãme jeho',
 'jumptonavigation' => 'kundaharã',
@@ -187,21 +186,17 @@ $messages = array(
 'ns-specialprotected' => 'Las páginas en el espacio de nombres Especial no se pueden editar.',
 
 # Login and logout pages
-'loginpagetitle'          => 'Terañemboguapy/Ke',
 'yourname'                => 'Hero',
 'yourpassword'            => 'Ne remiñemi',
 'yourpasswordagain'       => 'Repita ne remiñemi',
-'remembermypassword'      => "Aipota chemomandu'ajepi amba'apo jave.",
+'remembermypassword'      => "Aipota chemomandu'ajepi amba'apo jave (for a maximum of $1 {{PLURAL:$1|day|days}})",
 'login'                   => 'Terañemboguapy/Ke',
 'nav-login-createaccount' => 'Terañemboguapy/Ke',
 'userlogin'               => 'Terañemboguapy/Ke',
 'logout'                  => 'Sẽ',
 'userlogout'              => 'Sẽ',
-'nologin'                 => "¿Ne'ĩrãpa remohenda nde réra? $1.",
+'nologin'                 => "¿Ne'ĩrãpa remohenda nde réra? '''$1'''.",
 'nologinlink'             => 'Téra ñemohenda',
-'youremail'               => "Ñe'ẽveve",
-'yourlanguage'            => "Ñe'ẽ:",
-'email'                   => 'Pareha eleytróniko',
 'loginsuccesstitle'       => 'Remoñepyrũ hekopete ne rembiapo',
 'nosuchusershort'         => 'No hay un usuario con el nombre "$1". Compruebe que lo ha escrito correctamente.',
 'mailmypassword'          => "Embou chéve ñe'ẽveve rupive peteĩ temiñemĩ pyahu",
@@ -215,7 +210,6 @@ $messages = array(
 'link_tip'      => 'Joaju hyepyguávandi',
 'extlink_tip'   => 'Joaju okapeguávandi (recuerde añadir el prefijo http://)',
 'headline_tip'  => 'Teraete mokõiha',
-'math_tip'      => 'Matemátika kuaareko (LaTeX)',
 'nowiki_tip'    => "Viki jehaireko ñembo'yke",
 'image_tip'     => "Ta'ãnga moĩngepyréva",
 'media_tip'     => "Joaju jehai'aty multimediaguándi",
@@ -235,23 +229,20 @@ $messages = array(
 'newarticletext'        => "Rehapykuehókuri peteĩ joaju peteĩ kuatiarogue ndaipórivape.
 Nde remoheñoisérõ ko kuatiarogue, eñepyrũkatu ehai.
 Reikotevẽvérõ marandu, emoñe'ẽ kuatiarogue ñepytyvõ rehegua. Oiméramo reikereínte térã rejavyhaguére, upéicharõ terehojey [[{{MediaWiki:Helppage}}|kuatiarogue mboyveguápe]].",
-'userinvalidcssjstitle' => "'''Aviso:''' No existe la piel \"\$1\". Recuerda que las páginas personalizadas .css y .js tienen un título en minúsculas, p.e. Usuario:Foo/monobook.css en vez de  Usuario:Foo/Monobook.css.",
+'userinvalidcssjstitle' => "'''Aviso:''' No existe la piel \"\$1\". Recuerda que las páginas personalizadas .css y .js tienen un título en minúsculas, p.e. Usuario:Foo/vector.css en vez de  Usuario:Foo/Vector.css.",
 'editing'               => 'Ojehaihína $1',
 'editingsection'        => 'Ojehaihína $1 (vore)',
 'editingcomment'        => 'Ojehaihína $1 (comentario)',
 'yourtext'              => "Mba'ehaipyre",
-'longpagewarning'       => "'''Ejesarekóke: ko kuatiarogue, tuichakuépe, oguereko $1 kb; heta kundahára ikatu iñapañuãi jehaijeýpe kuatiarogue ohaságui 32 kb.
-Aipórõ, eñeha'ãna emboja'o ne rembiapo, vore michĩvévape.'''",
 
 # History pages
 'cur'         => "ko'ag̃agua",
 'last'        => 'ipaha',
-'deletedrev'  => '[oñembogue]',
 'historysize' => '($1 bytes)',
 
 # Revision deletion
 'rev-delundel'       => 'hechauka/toñemi',
-'logdelete-selected' => "'''Seleccionados $2 eventos de registro:'''",
+'logdelete-selected' => "'''Seleccionados $1 eventos de registro:'''",
 
 # Diffs
 'difference' => "(Mba'épe ojaovy oñemyatyrõva'ekue)",
@@ -262,9 +253,8 @@ Aipórõ, eñeha'ãna emboja'o ne rembiapo, vore michĩvévape.'''",
 # Search results
 'searchresults'     => 'Ojejuhúva jeheka',
 'searchsubtitle'    => "Nde reporandúkuri: '''[[:$1]]-re'''",
-'noexactmatch'      => "'''Ndaipóri kuatiarogue hérava: \"\$1\".''' Ikatu ndetevoi [[:\$1|rehai]].",
-'prevn'             => '$1 mboyvegua',
-'viewprevnext'      => 'Hecha ($1) ($2) ($3).',
+'prevn'             => '{{PLURAL:$1|$1}} mboyvegua',
+'viewprevnext'      => 'Hecha ($1 {{int:pipe-separator}} $2) ($3).',
 'showingresults'    => "Abajo se muestran hasta '''$1''' resultados empezando por el nº '''$2'''.",
 'showingresultsnum' => "Abajo se muestran los '''$3''' resultados empezando por el nº '''$2'''.",
 'powersearch'       => 'Jeheka',
@@ -274,6 +264,9 @@ Aipórõ, eñeha'ãna emboja'o ne rembiapo, vore michĩvévape.'''",
 'mypreferences'     => 'Che mbohoryha',
 'prefs-rc'          => 'Oñemoambue pyahúva',
 'searchresultshead' => 'Jeheka',
+'youremail'         => "Ñe'ẽveve",
+'yourlanguage'      => "Ñe'ẽ:",
+'email'             => 'Pareha eleytróniko',
 
 # User rights
 'userrights-lookup-user'   => 'Configurar grupos de usuarios',
@@ -309,7 +302,7 @@ Aipórõ, eñeha'ãna emboja'o ne rembiapo, vore michĩvévape.'''",
 # Upload
 'upload'     => "Tojehupi jehai'aty",
 'uploadtext' => "Eipuru pe tembipuru oĩva iguýpe ehupi hag̃ua jehai'aty, rehecha térã reheka hag̃ua ta'ãnga ojehupipyrémava eike jehai'aty jehupipyre rysýipe, umi ihupipyréva ha oñemboguémava avei oñemboguapy [[Special:Log/upload|jehai'aty jehupipyrépe]].
-Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju: 
+Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju:
 '''<nowiki>[[</nowiki>Imagen<nowiki>:Archivo.jpg]]</nowiki>''', '''<nowiki>[[</nowiki>Imagen<nowiki>:Archivo.png|texto alternativo]]</nowiki>''' o
 '''<nowiki>[[</nowiki>Media<nowiki>:Archivo.ogg]]</nowiki>''' ojoaju hag̃ua hekopete pe jehai'atýre.",
 'filename'   => "Téra jehai'aty",
@@ -319,6 +312,7 @@ Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju:
 'listfiles_user' => 'Puruhára',
 
 # File description page
+'file-anchor-link'  => 'Ñongatupy',
 'filehist-revert'   => 'embojevy',
 'filehist-current'  => "ko'ag̃agua",
 'filehist-datetime' => 'Ára/Aravo',
@@ -357,8 +351,8 @@ Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju:
 'doubleredirects' => "Ñembohapejey jo'apyre",
 
 'brokenredirects'        => "Ñembohapejey hekopegua'ỹva",
-'brokenredirects-edit'   => '(jehaijey)',
-'brokenredirects-delete' => "(mboje'o)",
+'brokenredirects-edit'   => 'jehaijey',
+'brokenredirects-delete' => "mboje'o",
 
 'withoutinterwiki' => 'Kuatiarogue ndorekóiva interwiki',
 
@@ -480,7 +474,7 @@ Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju:
 'ipblocklist-submit' => 'Heka',
 'blocklink'          => 'ejoko',
 'contribslink'       => "mba'emoĩmbyre",
-'blocklogtext'       => 'Esto es un registro de bloqueos y desbloqueos de usuarios. Las direcciones bloqueadas automáticamente no aparecen aquí. Consulte la [[Special:IPBlockList|IP mbohape rysýi imbotypyréva]] para ver la lista de prohibiciones y bloqueos actualmente vigente.',
+'blocklogtext'       => 'Esto es un registro de bloqueos y desbloqueos de usuarios. Las direcciones bloqueadas automáticamente no aparecen aquí. Consulte la [[Special:BlockList|IP mbohape rysýi imbotypyréva]] para ver la lista de prohibiciones y bloqueos actualmente vigente.',
 
 # Move page
 'movearticle'     => 'Guerova kuatiarogue',
@@ -521,7 +515,7 @@ Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju:
 'spam_blanking'       => 'Todas las revisiones contienen enlaces a $1, blanqueando',
 
 # Media information
-'file-info' => "(tamaño de jehai'aty: $1; tipo MIME: $2)",
+'file-info' => "tamaño de jehai'aty: $1; tipo MIME: $2",
 
 # Special:NewFiles
 'newimages' => "Ta'ãnga pyahu renda",
@@ -544,7 +538,7 @@ Reomĩsérõ ta'ãnga peteĩ kuatiaroguépe, eipuru peteĩ joaju:
 'watchlistedit-raw-removed'   => '$1 páginas han sido borradas:',
 
 # Special:Version
-'version' => "Mba'ereko", # Not used as normal message but as header for the special page itself
+'version' => "Mba'ereko",
 
 # Special:FilePath
 'filepath'        => 'Ruta de archivo',
