@@ -9,15 +9,18 @@
  *
  * @author Bombola
  * @author Dato deutschland
+ * @author Dawid Deutschland
  * @author Ibero-kolxi
  * @author The Evil IP address
  */
 
+$fallback = 'tr';
+
 $messages = array(
 # User preference toggles
 'tog-underline'        => "Link'iş tude kogu3’uxaçki:",
 'tog-highlightbroken'  => 'Upşu linkepe <a href="" class="new">am şekilite</a> (alternatifi: am şekilite<a href="" class="internal">?</a>) ko3\'iri.',
-'tog-rememberpassword' => 'Parola-skani goişini',
+'tog-rememberpassword' => 'Parola-skani goişini (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-showhiddencats'   => "Şinaxeri k'at'egorepe ko3'iri",
 
 'underline-always' => "P'anda",
@@ -82,34 +85,34 @@ $messages = array(
 'category-media-header'         => '"$1" k\'at\'egoris media',
 'category-empty'                => "''Am k'at'egoris çkar madde varna media va uğun.''",
 'hidden-categories'             => '{{PLURAL:$1|Şinaxeri kʼatʼegori|Şinaxeri kʼatʼegorepe}}',
-'hidden-category-category'      => "Şinaxeri k'at'egorepe", # Name of the category where hidden categories will be listed
+'hidden-category-category'      => "Şinaxeri k'at'egorepe",
 'category-subcat-count'         => '{{PLURAL:$2|Am kʼatʼegoris, xvala, tude na ren kʼatʼegori uğun.|Am kʼatʼegori tʼoplamurot $2 kʼatʼegorişen {{PLURAL:$1|tudekʼatʼegori|$1 tudekʼatʼegori}}s uğun}}',
 'category-subcat-count-limited' => "Am k'at'egori tudes na dgin {{PLURAL:$1|tude k'at'egoris|$1 tude k'at'egoris}} uğun.",
 'category-article-count'        => '{{PLURAL:$2|Am kʼatʼegoris, xvala, tude na ren kʼatʼegori uğun.|Tʼoplami $2 şen, tude na ren {{PLURAL:$1|butʼkʼa|$1 butʼkʼa}} am kʼatʼegoris ren.}}',
 'listingcontinuesabbrev'        => '(naqona)',
+'index-category'                => "Indexi na uğun but'k'ape",
+'noindex-category'              => 'Indexi muşi na var uğun sayfape',
 
-'mainpagetext'      => "'''Mediawiki dido k'ai ik'idu.'''",
-'mainpagedocfooter' => "Vik'i şeni muç'o ixmarinen ya mutxanepe oguru şeni [http://meta.wikimedia.org/wiki/Help:Contents oxmaruşi rexberis] o3'k'edit.
+'about'         => 'Şeni',
+'newwindow'     => '(ağne penceres guin3ʼkʼen)',
+'cancel'        => 'İpʼtʼali qʼvi',
+'moredotdotdot' => 'Çkva…',
+'mypage'        => 'Çkimi sayfa',
+'mytalk'        => 'Çkimi mesajepe',
+'anontalk'      => "Am IP'şi mesajepe",
+'navigation'    => 'Goxtima',
+'and'           => '&#32;do',
 
-== Ağani na gyoç’k’u maxmarepe ==
-* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Ok'iduşi ayarepeşi liste]
-* [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki P'anda Na-k'itxu K'itxalape]
-* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki e-mailepeşiş liste]",
-
-'about'          => 'Şeni',
-'newwindow'      => '(ağne penceres guin3ʼkʼen)',
-'cancel'         => 'İpʼtʼali qʼvi',
+# Cologne Blue skin
 'qbfind'         => 'Koz*iri',
 'qbedit'         => 'Doktiri',
 'qbpageoptions'  => 'Am sayfa',
 'qbmyoptions'    => 'Çkimi sayfape',
 'qbspecialpages' => 'Doxmeli sayfape',
-'moredotdotdot'  => 'Çkva…',
-'mypage'         => 'Çkimi sayfa',
-'mytalk'         => 'Çkimi mesajepe',
-'anontalk'       => "Am IP'şi mesajepe",
-'navigation'     => 'Goxtima',
-'and'            => '&#32;do',
+
+# Vector skin
+'vector-action-delete' => 'Jili',
+'vector-view-edit'     => 'Doktiri',
 
 'errorpagetitle'   => 'Çilata',
 'returnto'         => '$1 butʼkʼaşa goikti.',
@@ -121,7 +124,6 @@ $messages = array(
 'searcharticle'    => 'İgzali',
 'history'          => 'Butʼkʼaş tarixi',
 'history_short'    => 'Tarixi',
-'info_short'       => 'Çkina',
 'printableversion' => "Kart'alişa na geibaz*gen versiyoni",
 'permalink'        => 'Am xalişa kʼontaktʼi qʼvi',
 'edit'             => 'doktiri',
@@ -142,7 +144,7 @@ $messages = array(
 'otherlanguages'   => 'Majurani nenapes',
 'redirectedfrom'   => '($1 butʼkʼaşen moxtu)',
 'redirectpagesub'  => 'Redirektʼiş butʼkʼa',
-'lastmodifiedat'   => 'Am butʼkʼa çodinurot $2, $1 tarixis iktirinu.', # $1 date, $2 time
+'lastmodifiedat'   => 'Am butʼkʼa çodinurot $2, $1 tarixis iktirinu.',
 'jumpto'           => 'İdi do:',
 'jumptonavigation' => 'ixmari',
 'jumptosearch'     => 'mgori',
@@ -151,7 +153,6 @@ $messages = array(
 'aboutsite'            => '{{SITENAME}} şeni',
 'aboutpage'            => 'Project:Ambarepe',
 'copyright'            => 'Doloxe na renanpe, $1-şi ren.',
-'copyrightpagename'    => '{{SITENAME}} copyright',
 'copyrightpage'        => '{{ns:project}}:Şinaxeri Hakʼepe',
 'disclaimers'          => 'Kʼabuli na var ixvenu ondepe',
 'disclaimerpage'       => 'Project:Mtelot kʼabuli na var ixvenu ondepe',
@@ -203,14 +204,14 @@ Muşeni? Çunki am butʼkʼa, jileri na ren a butʼkʼaşi golaxteri versiyoni r
 Eger sebebi aya na va renna, pʼrogramis ar çilata z*irit.
 Mu iqʼven! Aya, a [[Special:ListUsers/sysop|adminis]], URL-ti çʼareli şekʼilite rapʼortʼi doçʼarit.',
 'missingarticle-rev' => '(revizyoni#: $1)',
-'badtitletext'       => 'Na içʼaren butʼkʼaşi coxo ya çilatoni ren ya boşi ren varna inter-nena do inter-vikʼişi kʼontʼaktʼis na uğutʼu şeni mtini varen. 
+'badtitletext'       => 'Na içʼaren butʼkʼaşi coxo ya çilatoni ren ya boşi ren varna inter-nena do inter-vikʼişi kʼontʼaktʼis na uğutʼu şeni mtini varen.
 Dudicoxopes oxmaruşi yasaği na ren ar, varna daha dido kʼarakʼtʼeri uğun.',
 'viewsource'         => 'Odudes o3ʼkʼedi',
 
 # Login and logout pages
 'yourname'                => 'Skani maxmare-coxo:',
 'yourpassword'            => 'Pʼarola-skani:',
-'remembermypassword'      => 'Parola-skani goişini',
+'remembermypassword'      => 'Parola-skani goişini (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                   => 'Sitʼeşa amaxti',
 'nav-login-createaccount' => 'Sitʼeşa amaxti / hesabi dokʼidi',
 'userlogin'               => 'Sitʼeşa amaxti / hesabi dokʼidi',
@@ -218,15 +219,9 @@ Dudicoxopes oxmaruşi yasaği na ren ar, varna daha dido kʼarakʼtʼeri uğun.'
 'userlogout'              => 'Siteşen Kogamaxti',
 'nologin'                 => "Hesabi va giğuni? '''$1'''",
 'nologinlink'             => 'Hesabi dokʼidi.',
-'youremail'               => 'E-maili:',
-'yourrealname'            => 'Coxo skani:',
-'yourlanguage'            => 'Nena skani:',
-'gender-male'             => "Biç'i",
-'gender-female'           => "Bozo (K'ulani)",
-'email'                   => 'E-maili',
 'mailmypassword'          => 'Ağne pʼarola-çkimi moncğoni',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => "Mcveşi p'arola:",
 'newpassword' => "Ağani P'arola:",
 
@@ -241,8 +236,6 @@ Dudicoxopes oxmaruşi yasaği na ren ar, varna daha dido kʼarakʼtʼeri uğun.'
 'extlink_tip'     => 'Galeni kʼontʼaktʼi (Adresiş dudis http:// ukʼatit)',
 'headline_sample' => 'Dudicoxoşi nçʼara',
 'headline_tip'    => '2. derece dudicoxo',
-'math_sample'     => 'Matematʼikuri-ifade-doçʼarit',
-'math_tip'        => 'Matʼematʼikuri formuli (LaTeX)',
 'nowiki_sample'   => 'Oxoşkveri formatʼi nçʼara-tkvani ak doçʼarit.',
 'nowiki_tip'      => 'vikʼiş formatʼi ipʼtʼali qʼvi.',
 'image_tip'       => 'Doxveri dosya',
@@ -271,11 +264,13 @@ varna am butʼkʼa [{{fullurl:{{FULLPAGENAME}}|action=edit}} gaktirinen]</span>.
 'previewnote'                      => "'''Aya, xvala, \"Evvelişen i3ʼkʼedi\" fonkʼsioni ren do oktirobape-skani kʼayitʼi var ixvenu çkva!'''",
 'editing'                          => '"$1" butʼkʼa iktirinen a3ʼi',
 'editingsection'                   => '"$1" butʼkʼas burme iktirinen',
-'copyrightwarning'                 => "'''Mu iqʼven kʼun3xi:''' {{SITENAME}} sitʼeşa na ixvenu mteli meşvelape <i>$2</i> 
+'copyrightwarning'                 => "'''Mu iqʼven kʼun3xi:''' {{SITENAME}} sitʼeşa na ixvenu mteli meşvelape <i>$2</i>
 paktʼiş doloxe ren (detayepe şeni $1's o3ʼkʼedi).
 Na qʼvi meşvelaşa başka makʼaturepeşkʼelen pʼatʼi mutxanepe ixvenen varna xemoşletinerot do uoçodinurot başka svapeşa niçinen, aya kʼabuli qʼvi varna am sitʼe şeni mutu mo ikip!<br />
 Edo amuş metʼi, ak mxuciş meçamu ginonna, meşvelape ti-skani kʼala oçʼaruşi re, varna ofi3ialurişa gon3ʼkʼimeri na ren ar kʼaynağişen (odudeşen) varna başka oxoşkveri kʼaynağepeşen (odudepeşen) na ezdi kʼabuli oxvenuşi re.<br />
 '''<center>DOXMELİ HAKʼEPETE NA İŞİNAXENAN XANDAPE AK MO UKʼATEPT!</center>'''",
+'templatesused'                    => 'Am butʼkʼas na ixmarinen {{PLURAL:$1|şabloni|şablonepe}}:',
+'templatesusedpreview'             => 'Am "Evvelişen i3ʼkʼedi" fonkʼsionis na ixmarinen {{PLURAL:$1|şabloni|şablonepe}}:',
 'template-protected'               => '(oçvu)',
 'template-semiprotected'           => '(gverd-oçvu)',
 'hiddencategories'                 => 'Am butʼkʼa {{PLURAL:$1|1 şinaxeri kʼatʼegori|$1 şinaxeri kʼatʼegori}}şi ren:',
@@ -283,6 +278,8 @@ Edo amuş metʼi, ak mxuciş meçamu ginonna, meşvelape ti-skani kʼala oçʼar
 
 # History pages
 'viewpagelogs'           => 'Am butʼkʼa şeni kʼayitʼepe ko3ʼiri',
+'currentrev-asof'        => '$1 itibariten butʼkʼaşi a3ʼineri xali.',
+'revisionasof'           => 'Butʼkʼaşi $1 tarixis xali muşi',
 'previousrevision'       => '← Mcveşi xali muşi',
 'nextrevision'           => 'Ağani xali-muşi →',
 'currentrevisionlink'    => 'İrişen ağne xali-muşi ko3ʼiri',
@@ -296,8 +293,10 @@ Oxo3ʼonapape: (a3ʼineri) = a3ʼineri versiyoni kʼala na ren farkʼi,
 'histlast'               => 'irişen ağani',
 
 # Revision deletion
-'rev-delundel'   => 'ko3ʼiri/doşinaxi',
-'revdel-restore' => 'Ozʼiramuşi doktiri',
+'rev-delundel'          => 'ko3ʼiri/doşinaxi',
+'revdelete-radio-set'   => 'Ho',
+'revdelete-radio-unset' => 'Var',
+'revdel-restore'        => 'Ozʼiramuşi doktiri',
 
 # Merge log
 'revertmerge' => 'Artikʼartişen okʼo3ʼkʼi',
@@ -317,7 +316,9 @@ Oxo3ʼonapape: (a3ʼineri) = a3ʼineri versiyoni kʼala na ren farkʼi,
 'searchsubtitleinvalid'     => "'''$1''' şeni mgori",
 'notitlematches'            => 'Çkar svas var iz*irinu',
 'notextmatches'             => 'Çkar butʼkʼa var iz*irinu',
-'viewprevnext'              => '($1) ($2) ($3)',
+'prevn'                     => 'ukʼuni {{PLURAL:$1|$1}}',
+'nextn'                     => 'mendi {{PLURAL:$1|$1}}',
+'viewprevnext'              => '($1 {{int:pipe-separator}} $2) ($3)',
 'search-result-size'        => '$1 ({{PLURAL:$2|1 tkvala|$2 tkvala}})',
 'search-redirect'           => '(redirektʼi $1)',
 'search-section'            => '(burme $1)',
@@ -343,6 +344,12 @@ Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (o
 'timezoneregion-antarctica' => "Antartik'a",
 'timezoneregion-asia'       => 'Asya',
 'timezoneregion-europe'     => "Avrop'a",
+'youremail'                 => 'E-maili:',
+'yourrealname'              => 'Coxo skani:',
+'yourlanguage'              => 'Nena skani:',
+'gender-male'               => "Biç'i",
+'gender-female'             => "Bozo (K'ulani)",
+'email'                     => 'E-maili',
 
 # Groups
 'group'       => 'Grubi:',
@@ -407,17 +414,21 @@ Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (o
 'filehist-current'          => 'A3ʼineri',
 'filehist-datetime'         => 'Dğa/Ora',
 'filehist-thumb'            => 'Mçʼitʼa sureti',
+'filehist-thumbtext'        => '$1 tarixis na iz*iren versiyonişi mçʼitʼa na ren xali',
 'filehist-user'             => 'Maxmare',
 'filehist-dimensions'       => 'Ebatʼepe',
 'filehist-comment'          => 'Kʼommentʼi',
 'imagelinks'                => 'Dosyaşi kʼontaktʼepe',
 'linkstoimage'              => 'Am oz*ira-dosyaşa kʼontʼaktʼi na ikips {{PLURAL:$1|butʼkʼa|$1 butʼkʼa}}:',
-'sharedupload'              => 'Am dosya $1-şen moxtu do belkim majurani pʼrojepesti ixmarinen.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
+'sharedupload'              => 'Am dosya $1-şen moxtu do belkim majurani pʼrojepesti ixmarinen.',
 'uploadnewversion-linktext' => 'Dosyaşi ağani versiyoni doloxe kamaxvi',
 
 # Statistics
 'statistics' => 'İstatistʼiğepe',
 
+'brokenredirects-edit'   => 'doktiri',
+'brokenredirects-delete' => 'jili',
+
 # Miscellaneous special pages
 'nbytes'        => '$1 {{PLURAL:$1|byte|byte}}',
 'nmembers'      => '{{PLURAL:$1|makʼature|makʼaturepe}}',
@@ -461,8 +472,6 @@ Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (o
 # Watchlist
 'watchlist'         => 'çkimi gotxozu listʼe',
 'mywatchlist'       => 'Çkimi gotxozu listʼe',
-'watchlistfor'      => "('''$1''' şeni)",
-'addedwatch'        => 'Skani gotxozu listʼeşa ikʼayitʼinu.',
 'addedwatchtext'    => '"<nowiki>[[:$1]]</nowiki>" coxoni butʼkʼa [[Special:Watchlist|gotxozu listʼes]] ikʼayitʼinu.
 
 Na moxtasen oras, am butʼkʼaşa do am butʼkʼa kʼala alakʼali na ren oğarğaluşi butʼkʼaşa na ixvenasen oktirobape ak ilistʼelinasen.
@@ -470,7 +479,6 @@ Na moxtasen oras, am butʼkʼaşa do am butʼkʼa kʼala alakʼali na ren oğar
 Dido kʼai o3xunu şeni doloxe muşis [[Special:RecentChanges|çodinaşi oktirobapeşi listʼe]] stʼatʼias dolom3ʼkʼupineri harfepete ilistʼelinasenan.
 
 Butʼkʼai gotxozu listʼeşen ojilu şeni "gotxozu naşkʼvi" linkʼişa gebaz*git.',
-'removedwatch'      => "Skani gotxozu list'eşen nijilu",
 'removedwatchtext'  => '"[[:$1]]" but\'k\'a, [[Special:Watchlist|skani gotxozu list\'eşen]] nijilu.',
 'watch'             => 'Amus gatxozi',
 'watchthispage'     => 'Butʼkʼa gatxozi',
@@ -488,7 +496,7 @@ Butʼkʼai gotxozu listʼeşen ojilu şeni "gotxozu naşkʼvi" linkʼişa gebaz*
 'confirmdeletetext'     => 'Aşoten am butʼkʼa varna dosya, mteli golaxteri kʼayitʼepe kʼala datʼabeizişen nijilen.
 Am dulyaşen na yeçkindasen zararepe giçkinna do am dulya [[{{MediaWiki:Policy-url}}|Ojiluşi kʼaidepe]] şeni mtini renya isimadep na, am dulya doqʼvi.',
 'actioncomplete'        => 'Aksiyoni içodinu.',
-'deletedtext'           => '"<nowiki>$1</nowiki>" nijilu.
+'deletedtext'           => '"$1" nijilu.
 Xolosi oras jileri na renanpe oz*iru şeni: $2.',
 'deletedarticle'        => '"[[$1]]" aya nijilu',
 'dellogpage'            => 'Ojiluşi kʼayitʼepe',
@@ -507,7 +515,7 @@ Xolosi oras jileri na renanpe oz*iru şeni: $2.',
 'protectexpiry'               => 'Am tarixis içoden:',
 'protect_expiry_invalid'      => 'Am tarixis var içoden, mtini va ren.',
 'protect_expiry_old'          => 'Golaxteris soni oxmaruşi ora.',
-'protect-text'                => "'''<nowiki>$1</nowiki>''' butʼkʼaşi oçvaluşi sinori akolen gazʼiren do gaktirinen.",
+'protect-text'                => "'''$1''' butʼkʼaşi oçvaluşi sinori akolen gazʼiren do gaktirinen.",
 'protect-locked-access'       => "Butʼkʼaşi oçvalu sinorepe oktiru şeni maxmare-hesabi skanis yetʼkʼi var uğun.
 '''$1''' butʼkʼaşi maartani tercihepe antepe renan:",
 'protect-cascadeon'           => 'Am butʼkʼa, "kʼademoni oçvuşi sistemi" aktʼifi na ixvenu do tude na ren {{PLURAL:$1|$1 butʼkʼas|$1 butʼkʼas}} na ixmarinetʼu şeni a3ʼi içven.
@@ -567,7 +575,7 @@ Am butʼkʼaşi oçvuşi sinori gaktirinen; ama am oktiroba, kʼademoni oçvalu
 
 # Block/unblock
 'blockip'                  => 'Maxmares bloği qʼvi',
-'ipboptions'               => '2 saatʼi:2 hours,1 ndğa:1 day,3 ndğa:3 days,1 doloni:1 week,2 doloni:2 weeks,1 tuta:1 month,3 tuta:3 months,6 tuta:6 months,1 3ʼana:1 year,pʼanda:infinite', # display1:time1,display2:time2,...
+'ipboptions'               => '2 saatʼi:2 hours,1 ndğa:1 day,3 ndğa:3 days,1 doloni:1 week,2 doloni:2 weeks,1 tuta:1 month,3 tuta:3 months,6 tuta:6 months,1 3ʼana:1 year,pʼanda:infinite',
 'ipblocklist'              => 'Bloği xveneri na renan IP adresepe do maxmareş coxope',
 'blocklink'                => 'bloği qʼvi',
 'unblocklink'              => 'bloği kezdi',
@@ -579,9 +587,9 @@ Am butʼkʼaşi oçvuşi sinori gaktirinen; ama am oktiroba, kʼademoni oçvalu
 'block-log-flags-nocreate' => 'hesabi okʼidu geinkʼilu',
 
 # Move page
-'movepagetext'     => "Tude na ren formi oxmarute butʼkʼaşi coxo iktirinen. Edo xolo mteli golaxteri kʼayitʼepeti ağani coxos itiren. 
-Mcveşi coxo, ağani coxoşa redirektʼi xali aqʼven. 
-Otomatikurot mcveşi stʼatʼiaşa na ixvenen redirektʼepe gaktirinen. 
+'movepagetext'     => "Tude na ren formi oxmarute butʼkʼaşi coxo iktirinen. Edo xolo mteli golaxteri kʼayitʼepeti ağani coxos itiren.
+Mcveşi coxo, ağani coxoşa redirektʼi xali aqʼven.
+Otomatikurot mcveşi stʼatʼiaşa na ixvenen redirektʼepe gaktirinen.
 Am dulya otomatikurot oxvenu va ginonna [[Special:DoubleRedirects|tʼkʼubi]] varna [[Special:BrokenRedirects|tʼaxeri]] na renan redirektʼepe ti-skani kʼala oktiruşi re. Na qʼvare am oktirobate mteli kʼontʼaktʼepe dido kʼai oçalişu ren, amuşen si sorumli re.
 
 Eger ağani coxos ar butʼkʼa zate korenna coxoşi oktiroba '''var ixvenasen'''. Amuş metʼi, coxoşi oktirobaşen pişmani qʼvi na, am oktiroba ipʼtʼali gaxvenen, aşoten başka butʼkʼapeşati zarari meçameri va gaqʼven.
@@ -599,7 +607,7 @@ Am situa3yonepes, butʼkʼa skanişkʼelen otiruşi ren.",
 'move-watch'       => 'Am butʼkʼa gatxozi',
 'movepagebtn'      => 'Coxo-muşi doktiri',
 'pagemovedsub'     => 'Coxo iktirinu.',
-'movepage-moved'   => '\'\'\'"$1",  "$2" butʼkʼa muşişa itirinu\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => '\'\'\'"$1",  "$2" butʼkʼa muşişa itirinu\'\'\'',
 'articleexists'    => 'Am coxos ar butʼkʼa koren varna na çʼari coxo mtini va ren.
 Mu iqʼven başka coxo doçʼari.',
 'talkexists'       => "'''Butʼkʼa dido kʼai itirinu, mara oğarğaluşi butʼkʼa var itirinu çunki na itirinasen coxos zate ar butʼkʼa rtʼu. Mu iqʼven butʼkʼaşi doloçʼareli nç'arape majurani butʼkʼaşa ti-skani kʼala itirini.'''",
@@ -639,6 +647,7 @@ Mu iqʼven başka coxo doçʼari.',
 'tooltip-search-go'               => 'Eger korenna, am coxos na uğun ar butʼkʼaşa idi',
 'tooltip-search-fulltext'         => 'Am nçʼara şeni butʼkʼape mgori',
 'tooltip-n-mainpage'              => 'Dudi butʼkʼaşa idi',
+'tooltip-n-mainpage-description'  => 'Dudi butʼkʼaşa idi',
 'tooltip-n-portal'                => 'Proje şeni, şeyepe so gaz*iren, mu gaxvenen',
 'tooltip-n-currentevents'         => 'Ağani oğodape şeni çodinaşi çkinape',
 'tooltip-n-recentchanges'         => 'Vikʼis na ixvenu sonni oktirobapeşi listʼe.',
@@ -676,11 +685,10 @@ Mu iqʼven başka coxo doçʼari.',
 'nextdiff'     => 'Ukʼaçxineri versiyoni kʼala na ren farkʼi →',
 
 # Media information
-'file-info-size'       => '($1 × $2 pikseli, dosyaşi didinoba: $3, MIME type: $4)',
-'file-nohires'         => '<small>Çkva kʼai ozʼiramuşis na uğun versiyoni va ren.</small>',
-'svg-long-desc'        => '(SVG dosya, coxoten $1 × $2 pʼikʼseli, dosyaşi didinoba: $3)',
-'show-big-image'       => 'Tam ozʼiramuşi',
-'show-big-image-thumb' => '<small>"Evvelişen i3ʼkʼedi" fonkʼsionişi didinoba: $1 × $2 pikseli</small>',
+'file-info-size' => '$1 × $2 pikseli, dosyaşi didinoba: $3, MIME type: $4',
+'file-nohires'   => '<small>Çkva kʼai ozʼiramuşis na uğun versiyoni va ren.</small>',
+'svg-long-desc'  => 'SVG dosya, coxoten $1 × $2 pʼikʼseli, dosyaşi didinoba: $3',
+'show-big-image' => 'Tam ozʼiramuşi',
 
 # Bad image list
 'bad_image_list' => 'Formatʼi aşo ren:
@@ -695,18 +703,23 @@ Ukʼaçxe na mulunan kʼontʼaktʼepe istʼisna oqʼopinot kʼabuli ixvenen. Mes
 'metadata-expand'   => 'Detayepe ko3ʼiri',
 'metadata-collapse' => 'Detayepe doşinaxi',
 'metadata-fields'   => 'Am butʼkʼas na ilistʼelinen EXIF metadataş burmepe, resimi ozʼiramuşi butʼkʼapes metadata tʼablo na ğuru oras ixmarinen. Majuranepeti maartani oqʼopinot işinaxasen.
-
 * make
 * model
 * datetimeoriginal
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength', # Do not translate list items
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => 'Dosyas, kʼompʼuteris na renan pʼrogramepe kʼala oktirobape doqʼvi.',
-'edit-externally-help' => '(Dido çkina şeni metʼas na renan [http://www.mediawiki.org/wiki/Manual:External_editors galeni xvenaş tercihepe] (İngilisuri) butʼkʼa muşis o3ʼkʼedit)',
+'edit-externally-help' => '(Dido çkina şeni metʼas na renan [//www.mediawiki.org/wiki/Manual:External_editors galeni xvenaş tercihepe] (İngilisuri) butʼkʼa muşis o3ʼkʼedit)',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'mteli',
