@@ -67,14 +67,16 @@ $messages = array(
 'category-empty'         => "''Taggayt a war dags bu ca n Tasna niɣ ca n umedia.''",
 'listingcontinuesabbrev' => 'arni-d.',
 
-'about'          => 'Xef',
-'newwindow'      => '(Areẓm di tburjet d-tamaynut)',
-'cancel'         => 'Sbdd',
+'about'      => 'Xef',
+'newwindow'  => '(Areẓm di tburjet d-tamaynut)',
+'cancel'     => 'Sbdd',
+'mytalk'     => 'Amsawal inu',
+'navigation' => 'Tagriwa',
+
+# Cologne Blue skin
 'qbfind'         => 'Af',
 'qbedit'         => 'Ẓṛeg',
 'qbspecialpages' => 'Tudmawin Special',
-'mytalk'         => 'Amsawal inu',
-'navigation'     => 'Tagriwa',
 
 'errorpagetitle'   => 'Anezri',
 'returnto'         => 'Dwl ghar $1.',
@@ -93,6 +95,7 @@ $messages = array(
 'editthispage'     => 'Ẓṛg tasna ya',
 'delete'           => 'Kks',
 'protect'          => 'Mstn',
+'protect_change'   => 'sbadl',
 'newpage'          => 'Tasna d-tamaynut',
 'talkpage'         => 'Siwl xf tasna ya',
 'talkpagelinktext' => 'Awal',
@@ -161,7 +164,7 @@ teqqad ad yilli days ca n usekkil war itwagg deg isem .',
 # Login and logout pages
 'yourname'                => 'Izwl-usqdac:',
 'yourpassword'            => 'Tawalt n wadaf:',
-'remembermypassword'      => 'ejj (login) inu deg uselkim a',
+'remembermypassword'      => 'ejj (login) inu deg uselkim a (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                   => 'Adf',
 'nav-login-createaccount' => 'Adef / egg amiḍan',
 'loginprompt'             => "itxessa ad-teṭfed (''cookies'') bac ad tadfed ɣar {{SITENAME}}.",
@@ -173,14 +176,11 @@ teqqad ad yilli days ca n usekkil war itwagg deg isem .',
 'createaccount'           => 'Egg amiḍan',
 'gotaccount'              => "ɣark  amiḍan? '''$1'''.",
 'gotaccountlink'          => 'Adeff',
-'yourrealname'            => 'isem n deṣṣaḥ :',
-'prefs-help-realname'     => 'isem inec n deṣṣaḥ mala txesad waha .
-mala tucit-id, ataf Lxdant inec a tetwassan ila inec.',
 'loginsuccesstitle'       => 'Adaf icna',
 'loginsuccess'            => "'''Qac tudeffed di {{SITENAME}} s \"\$1\".'''",
 'nosuchuser'              => 'War illi ca n useqdac s isem a"$1".
 xemm tirra , niɣ egg amiḍan d amaynu.',
-'nosuchusershort'         => 'War illi ca n useqdac s isem a "<nowiki>$1</nowiki>".
+'nosuchusershort'         => 'War illi ca n useqdac s isem a "$1".
 xemm tirra.',
 'nouserspecified'         => 'ixessa ad tuced isem n useqdac.',
 'wrongpassword'           => 'Taguri n wadaf war tceni ca. Sideff tenni nican.',
@@ -201,7 +201,7 @@ adeff-d xmi ɣa teṭfed.',
 'eauthentsent'            => 'ijj n e-mail itwasekked ɣar e-mail nni.
 zzat ma ca n e-mail nniḍen ma ad itwasekk ɣar umiḍan , ixessa ad tegged manayenni di e-mail, bac ad nessen ila qa amiḍan a inec.',
 
-# Password reset dialog
+# Change password dialog
 'retypenew' => 'Ɛawd arri Taguri n wadaf tamaynut:',
 
 # Edit page toolbar
@@ -215,8 +215,6 @@ zzat ma ca n e-mail nniḍen ma ad itwasekk ɣar umiḍan , ixessa ad tegged man
 'extlink_tip'     => 'Tazdayt n baṛṛa (qa tettud http:// prefix)',
 'headline_sample' => 'Aḍris n ixf-isem',
 'headline_tip'    => 'Aswir 2 n ixf-isem',
-'math_sample'     => 'Egg ijj n formula da',
-'math_tip'        => 'Mathematical formula (LaTeX)',
 'nowiki_sample'   => 'Sideff da tirra bla taseddast(formatting) n wiki',
 'nowiki_tip'      => 'Ur tawi x taseddast(formatting) n wiki',
 'image_tip'       => 'Afaylu war-itmesebḍi',
@@ -225,18 +223,18 @@ zzat ma ca n e-mail nniḍen ma ad itwasekk ɣar umiḍan , ixessa ad tegged man
 'hr_tip'          => 'Acariḍ aglawan',
 
 # Edit pages
-'summary'                => 'Tagḍwit:',
-'subject'                => 'Abatu/izwl:',
-'minoredit'              => 'Ta d taẓrigt d-tamẓeyant',
-'watchthis'              => 'Ḥḍa tasna ya',
-'savearticle'            => 'Xmml tasna',
-'preview'                => 'Azar-ascan',
-'showpreview'            => 'Ẓar Azar-ascan',
-'showdiff'               => 'Ẓar mayn teẓṛegd.',
-'anoneditwarning'        => "'''ɣark:''' war tudifd ca s isem inec.
+'summary'                    => 'Tagḍwit:',
+'subject'                    => 'Abatu/izwl:',
+'minoredit'                  => 'Ta d taẓrigt d-tamẓeyant',
+'watchthis'                  => 'Ḥḍa tasna ya',
+'savearticle'                => 'Xmml tasna',
+'preview'                    => 'Azar-ascan',
+'showpreview'                => 'Ẓar Azar-ascan',
+'showdiff'                   => 'Ẓar mayn teẓṛegd.',
+'anoneditwarning'            => "'''ɣark:''' war tudifd ca s isem inec.
 Tansa n IP inac ad-teqqim deg umezruy n teẓṛigin n Tasna ya .",
-'summary-preview'        => 'Azar-ascan n Tegḍwit:',
-'blockedtext'            => "'''Isem useqdac niɣ tansa IP inecc tewabluca  .'''
+'summary-preview'            => 'Azar-ascan n Tegḍwit:',
+'blockedtext'                => "'''Isem useqdac niɣ tansa IP inecc tewabluca  .'''
 
 iblocat  $1.
 Maynzi ''$2''.
@@ -249,33 +247,30 @@ Tzemred ad temsawaded ag $1 niɣ [[{{MediaWiki:Grouppage-sysop}}|administrator]]
 war tzemred ca ad ad tesxedmed 'e-mail this user' ɣar mala ca n e-mail illa ɣark di [[Special:Preferences|Isemyifiyen n umiḍan]] u war twabluki ca usexdem ines.
 Tansa IP inecc n ruxa d $3, u ID icecc iteblukan d #$5.
 maṛṛa manaya deg ujenna eggit di tabrat i ɣ-ad tsekked.",
-'newarticle'             => '(Amaynu)',
-'newarticletext'         => "Tdefar-d tazdayt n Tasna εad war telli .
+'newarticle'                 => '(Amaynu)',
+'newarticletext'             => "Tdefar-d tazdayt n Tasna εad war telli .
 bac ad tegged , arri di taflwit a swadday (xemm i [[{{MediaWiki:Helppage}}| Tasna n Tallalt]] i ineɣmisen ifruryen).
 mala qacek da s ɣalaṭ waha, tecca di tbutunt n '''deffar''' di (browser) inec .",
-'noarticletext'          => 'Rxxu ur din llint ca tira di tasna ya.
+'noarticletext'              => 'Rxxu ur din llint ca tira di tasna ya.
 Tzmmard [[Special:Search/{{PAGENAME}}|rzu xf yizwl n tasna ya]] di tasniwin nnḍni,
 <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs],
 nigh [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit this page]</span>.',
-'previewnote'            => "'''Wa d Azar-ascan waha;
+'previewnote'                => "'''Wa d Azar-ascan waha;
 tiẓṛigin εad war twaḥḍent!'''",
-'editing'                => 'Aẓṛag di $1',
-'editingsection'         => 'Aẓrag  di $1 (tigezmi)',
-'copyrightwarning'       => "Maṛṛa tirra di {{SITENAME}} twaggent swadday i $2 (ẓar da $1).
+'editing'                    => 'Aẓṛag di $1',
+'editingsection'             => 'Aẓrag  di $1 (tigezmi)',
+'copyrightwarning'           => "Maṛṛa tirra di {{SITENAME}} twaggent swadday i $2 (ẓar da $1).
 mala war texsed tirra inac ad twaẓṛegent , ad twamsebḍant .
 Ur ten-teg ca da.<br />
 tjadjid-anɣ Ɛawt ila qa d cekk ig yuran manaya, niɣ tesneɣlet-id zi ca n uɣbal nniḍn d alelli.
 '''UR SADDAF CA TIRRA ƔARSENT COPYRIGHTE BLA MA AD-IXES BAB-INES !'''",
-'longpagewarning'        => "'''WARNING: Tasna ya dag-s $1 kilobyte ;
-ca n imsuṭṭuyen(browsers) war zemren ca ad ẓṛegen tasniwin dag-sent 32 kb niɣ ktar.
-ixessa ad ten tebḍid ɣar tigezmin(sections) d timeẓyanin.'''",
-'templatesused'          => 'Timudmiwin itwaggen di Tasna ya:',
-'templatesusedpreview'   => 'Timudmiwin igg itwasxdemen dg uzar-ascan a :',
-'template-protected'     => '(twaḥḍa)',
-'template-semiprotected' => '(semi-protected)',
-'nocreatetext'           => '{{SITENAME}} war iqqim ca itejja iwdan ad ggen Tasniwin timaynutin.
+'templatesused'              => 'Timudmiwin itwaggen di Tasna ya:',
+'templatesusedpreview'       => 'Timudmiwin igg itwasxdemen dg uzar-ascan a :',
+'template-protected'         => '(twaḥḍa)',
+'template-semiprotected'     => '(semi-protected)',
+'nocreatetext'               => '{{SITENAME}} war iqqim ca itejja iwdan ad ggen Tasniwin timaynutin.
 tzemred addewred ɣar deffar, niɣ [[Special:UserLogin|Adeff niɣ egg amiḍan]].',
-'recreate-deleted-warn'  => "'''Ɣark: qac tegged Tasna ig itwaksen zzat uya.'''
+'recreate-moveddeleted-warn' => "'''Ɣark: qac tegged Tasna ig itwaksen zzat uya.'''
 
 Ẓar aɣmis n umzruy n usfad n Tasna ya bac ad tsenad ma mliḥ ad tkemled aẓṛag.",
 
@@ -283,7 +278,7 @@ tzemred addewred ɣar deffar, niɣ [[Special:UserLogin|Adeff niɣ egg amiḍan]]
 'viewpagelogs'           => 'Ẓar aɣmis n Tasna ya',
 'currentrev'             => 'Afegged n ruxa',
 'revisionasof'           => 'Affegged am $1',
-'revision-info'          => 'Afegged am $1 s $2', # Additionally available: $3: revision id
+'revision-info'          => 'Afegged am $1 s $2',
 'previousrevision'       => '←Affegged n zik/zic',
 'nextrevision'           => 'Afegged d amaynu→',
 'currentrevisionlink'    => 'Afegged n rux',
@@ -299,7 +294,7 @@ Tasarut: (cur) = imṣebḍiyen ag tunɣilt n ruxa,
 'histlast'               => 'Anggaru n marra',
 
 # Revision feed
-'history-feed-item-nocomment' => '$1 ɣar $2', # user at time
+'history-feed-item-nocomment' => '$1 ɣar $2',
 
 # Revision deletion
 'rev-delundel' => 'sken/ffer',
@@ -316,11 +311,9 @@ Tasarut: (cur) = imṣebḍiyen ag tunɣilt n ruxa,
 'searchresults'             => 'Tifellawin n tarezzut',
 'searchresults-title'       => 'Tifellawin n tarezzut xef "$1"',
 'searchsubtitle'            => 'Trezzud xef \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|marra tasniwin issentan s "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|marra tasniwin iteqqnen ghar "$1"]])',
-'noexactmatch'              => "'''war telli ca n Tasna qarn-as \"\$1\".'''
-tzemred ad [[:\$1|tarnid cek]].",
-'prevn'                     => 'zzat $1',
-'nextn'                     => 'deffar $1',
-'viewprevnext'              => 'Ẓar ($1) ($2) ($3)',
+'prevn'                     => 'Amzray {{PLURAL:$1|$1}}',
+'nextn'                     => 'wn d-itasn {{PLURAL:$1|$1}}',
+'viewprevnext'              => 'Ẓeṛ ($1 {{int:pipe-separator}} $2) ($3)',
 'search-result-size'        => '$1 ({{PLURAL:$2|1 tawalt|$2 tiwalin}})',
 'search-suggest'            => 'Ttugha txsd a tinid: $1',
 'search-interwiki-caption'  => 'Awmatn n usnfar',
@@ -332,9 +325,12 @@ tzemred ad [[:\$1|tarnid cek]].",
 'powersearch-legend'        => 'Tarzzut tanmhazt',
 
 # Preferences page
-'preferences'       => 'Ismyifiyn',
-'mypreferences'     => 'Isemyifiyen inu',
-'searchresultshead' => 'Tarzzut',
+'preferences'         => 'Ismyifiyn',
+'mypreferences'       => 'Isemyifiyen inu',
+'searchresultshead'   => 'Tarzzut',
+'yourrealname'        => 'isem n deṣṣaḥ :',
+'prefs-help-realname' => 'isem inec n deṣṣaḥ mala txesad waha .
+mala tucit-id, ataf Lxdant inec a tetwassan ila inec.',
 
 # Groups
 'group-sysop' => 'Indbaln',
@@ -369,6 +365,8 @@ tzemred ad [[:\$1|tarnid cek]].",
 
 # Recent changes linked
 'recentchangeslinked'          => 'Isenfilen i yudsen wa',
+'recentchangeslinked-feed'     => 'Tiẓṛigin ag ta',
+'recentchangeslinked-toolbox'  => 'Tiẓṛigin ag ta',
 'recentchangeslinked-title'    => 'Tiẓṛigin ssaɣant-id ɣar "$1"',
 'recentchangeslinked-noresult' => 'War llint ca n tiẓṛigin di Tasna ya di lwaqt id-tucid .',
 'recentchangeslinked-summary'  => "Ta d tabdart n isnfiln itwaggn drus zggwami di tasniwin id-iqqnen zg ict tasna nniḍn (nigh iqqnen ghar iwdan zi ca n taggayt).
@@ -388,6 +386,7 @@ Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
 'listfiles' => 'Tabdart n ifayluten',
 
 # File description page
+'file-anchor-link'          => 'Afaylu',
 'filehist'                  => 'Amzruy n usatul',
 'filehist-help'             => 'Tka di date/time bac ad tẓerd afaylu mamec ja d-itban di Lwaqt a .',
 'filehist-deleteone'        => 'sfaḍ',
@@ -397,12 +396,10 @@ Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
 'filehist-dimensions'       => 'Tisektiwin',
 'filehist-filesize'         => 'Tiddi n ufaylu',
 'filehist-comment'          => 'Tinit',
-'imagelinks'                => 'Tizdayin',
+'imagelinks'                => 'Iwurn n usdaw',
 'linkstoimage'              => '{{PLURAL:$1|Tasna ya teqn-ad|$1 Tasniwin a qnent-id}} ɣa ufaylu ya :',
 'nolinkstoimage'            => 'war telli ca n Tasna teqqen-d ɣa ufaylu ya.',
-'sharedupload'              => 'Wa d ijj ufaylu itwacrec jar aṭṭas n isenfaren(projects).', # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'noimage'                   => 'war illi ca n ufaylu s isem a , tzemred ad $1.',
-'noimage-linktext'          => 'Zdem d ijj',
+'sharedupload'              => 'Wa d ijj ufaylu itwacrec jar aṭṭas n isenfaren(projects).',
 'uploadnewversion-linktext' => 'Zdem-d tunɣilt d-tamaynut n ufaylu a',
 
 # File deletion
@@ -431,8 +428,8 @@ Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
 'doubleredirects' => '(redirects) ɛɛawdent',
 
 'brokenredirects'        => '(redirects) arẓent',
-'brokenredirects-edit'   => '(arri)',
-'brokenredirects-delete' => '(sfaḍ)',
+'brokenredirects-edit'   => 'arri',
+'brokenredirects-delete' => 'sfaḍ',
 
 'withoutinterwiki'        => 'Tasna bla tiẓdayin n tutlayt',
 'withoutinterwiki-submit' => 'Smmrad',
@@ -506,10 +503,7 @@ Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
 # Watchlist
 'watchlist'         => 'Tabdart uḥṭṭu inu',
 'mywatchlist'       => 'Tabdart uḥṭṭu inu',
-'watchlistfor'      => "(i '''$1''')",
-'addedwatch'        => 'Temmarni ɣar Tabdart uḥṭṭu',
 'addedwatchtext'    => 'Tasna "[[:$1]]" Temmarni ɣar [[Special:Watchlist|Tabdart uḥṭṭu]].',
-'removedwatch'      => 'twakkes zi Tabdart uḥṭṭu',
 'removedwatchtext'  => 'Tasna "[[:$1]]" twakkes zi [[Special:Watchlist|Tabdart uḥṭṭu inec]].',
 'watch'             => 'Ḥḍa',
 'watchthispage'     => 'Ḥḍa tasna ya',
@@ -528,7 +522,7 @@ Tasniwin di [[Special:Watchlist|your watchlist]] d '''tizurarin'''.",
 'confirmdeletetext'     => 'Ur d ac iqqim walu a tsfḍed ict tasna ak marra amzruy nns.
 Ma nican txsd a tggd manaya? Ma tssnd min ttggd? Ma ttggd manaya amc teqqaṛ  [[{{MediaWiki:Policy-url}}|tasrtit n Wiki]] ?',
 'actioncomplete'        => 'Tiggawt tsala',
-'deletedtext'           => '"<nowiki>$1</nowiki>" Twakkes.
+'deletedtext'           => '"$1" Twakkes.
 Xemm $2 i tikkas timaynutin.',
 'deletedarticle'        => 'twakkes "[[$1]]"',
 'dellogpage'            => 'Aɣmis n uṣfaḍ',
@@ -546,8 +540,7 @@ Xemm $2 i tikkas timaynutin.',
 'protectexpiry'               => 'Itsala:',
 'protect_expiry_invalid'      => 'Akud n usali ur illi nican.',
 'protect_expiry_old'          => 'Akud usali izri, idwl d amzruy.',
-'protect-unchain'             => 'Arzem turagin n usnaqel',
-'protect-text'                => "tzemred ad teẓṛed u atbedeld aswir n uḥeṭṭu n Tasna ya da '''<nowiki>$1</nowiki>'''.",
+'protect-text'                => "tzemred ad teẓṛed u atbedeld aswir n uḥeṭṭu n Tasna ya da '''$1'''.",
 'protect-locked-access'       => "Amiḍan inecc war ɣars turagt bac ad ibeddel aswir n uḥeṭṭu n Tasna .
 Aqa (settings) n Tasna '''$1''':",
 'protect-cascadeon'           => 'Tasna ya tẓarq ruxa mayenzi tudef di {{PLURAL:$1|Tasna, iɣa illa|Tasniwin, iɣa illa}} aḥeṭṭu n usmuzzar(cascading protection).
@@ -560,7 +553,7 @@ Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥe
 'protect-expiring'            => 'itsala deg $1 (UTC)',
 'protect-cascade'             => 'Ḥḍa Tasniwin i yudfen di Tasna ya (cascading protection)',
 'protect-cantedit'            => 'war tezemred ca ad tbedeld iswiren n uḥeṭṭu n Tasna ya, mayenzi war ɣark turagt bac ad tẓṛegd.',
-'protect-expiry-options'      => '2 tasεεat:2 hours,1 ass:1 day,3 ussan:3 days,1 amalass:1 week,2 imallasen:2 weeks,1 ayur:1 month,3 iyuren:3 months,6 iyuren:6 months,1 asggas:1 year,infinite:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '2 tasεεat:2 hours,1 ass:1 day,3 ussan:3 days,1 amalass:1 week,2 imallasen:2 weeks,1 ayur:1 month,3 iyuren:3 months,6 iyuren:6 months,1 asggas:1 year,infinite:infinite',
 'restriction-type'            => 'Turagt:',
 'restriction-level'           => 'Aswir uskref:',
 
@@ -587,6 +580,7 @@ Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥe
 'sp-contributions-newbies'     => 'Ẓar Tabdart n tiggawin n useqdac a deg umiḍan amaynu waha',
 'sp-contributions-newbies-sub' => 'i imiḍan imaynuten',
 'sp-contributions-blocklog'    => 'sbdd tabdart n talghut',
+'sp-contributions-talk'        => 'Awal',
 'sp-contributions-search'      => 'Arzu x tiggawin',
 'sp-contributions-username'    => 'Tansa IP d isem useqdac:',
 'sp-contributions-submit'      => 'Tarzzut',
@@ -607,7 +601,7 @@ Tezemred ad tbedeld aswir n uḥeṭṭu n Tasna ya, maca war itegg walu i uḥe
 
 # Block/unblock
 'blockip'                  => 'Sbdd asqdac a',
-'ipboptions'               => '2 n timirin:2 hours,1 n wass:1 day,3 n wussan:3 days,1 imalass:1 week,2 imallassn:2 weeks,1 wayur:1 month,3 wayurn:3 months,6 wayurn:6 months,1 asggwas:1 year,tartalla:infinite', # display1:time1,display2:time2,...
+'ipboptions'               => '2 n timirin:2 hours,1 n wass:1 day,3 n wussan:3 days,1 imalass:1 week,2 imallassn:2 weeks,1 wayur:1 month,3 wayurn:3 months,6 wayurn:6 months,1 asggwas:1 year,tartalla:infinite',
 'ipblocklist'              => 'Tabdart n tansiwin IP d isemawen n iseqdacen ig iteblukan',
 'ipblocklist-submit'       => 'Tarzzut',
 'blocklink'                => 'Sbedd',
@@ -639,7 +633,7 @@ mala amya, itxessa cekk ad tesnaqled s ufus mala txisd.",
 'move-watch'       => 'Ẓar Tasna ya',
 'movepagebtn'      => 'Snaqel Tasna',
 'pagemovedsub'     => 'Asmutti itwagg',
-'movepage-moved'   => '\'\'\'"$1" twanql ɣar "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => '\'\'\'"$1" twanql ɣar "$2"\'\'\'',
 'articleexists'    => 'Tasna s isem a tella da, niɣ isem itucid war icni.
 ixdar isem nniḍn.',
 'talkexists'       => "'''Tasna twanql , maca Tasna n usiwl ins war twanqel ca maymmi qaddin ict nninḍ.
@@ -669,7 +663,7 @@ snaqlitent s ufus.'''",
 'tooltip-pt-mytalk'               => 'Tasna usiwl inu',
 'tooltip-pt-preferences'          => 'Isemyifiyen inu',
 'tooltip-pt-watchlist'            => 'Tabdart n Tasniwin umi txmamd bac ad-ten teẓṛegd',
-'tooltip-pt-mycontris'            => 'Tabdart n tiggawin inu',
+'tooltip-pt-mycontris'            => 'Umuɣ n tiwuriwin inu',
 'tooltip-pt-login'                => 'Neqqar ac adef s umiḍan nnek; maca malla texsed waha',
 'tooltip-pt-logout'               => 'Ufugh',
 'tooltip-ca-talk'                 => 'Amsawal xef tasna n ukettur',
@@ -688,6 +682,7 @@ Bbeẓ x ufeskar n uzar-timeẓṛi zzat i gha txemmled min turid',
 'tooltip-search-fulltext'         => 'Rzu di tasniwin x waḍṛis a',
 'tooltip-p-logo'                  => 'Tasbtirt Tamzwarut',
 'tooltip-n-mainpage'              => 'Adef ghar tasna tamezwarut',
+'tooltip-n-mainpage-description'  => 'Adef ghar tasna tamezwarut',
 'tooltip-n-portal'                => 'Xf usenfar, mayn tzemmared a tegged, mani gha tafed tighawsiwin',
 'tooltip-n-currentevents'         => 'Af tilgha n ugilal xf tmsarin titurawin',
 'tooltip-n-recentchanges'         => 'Tabdart n isenfilen imaynuten di Wiki.',
@@ -719,11 +714,10 @@ Bbeẓ x ufeskar n uzar-timeẓṛi zzat i gha txemmled min turid',
 'nextdiff'     => 'Amṣebḍi zzat  →',
 
 # Media information
-'file-info-size'       => '($1 × $2 pixel, tiddi(size) n ufaylu: $3, anaw(type) n MIME: $4)',
-'file-nohires'         => '<small>walu ca n resolution yemɣa x wa.</small>',
-'svg-long-desc'        => '(Afaylu n SVG, dis $1 × $2 pixel, Tiddi n ufaylu: $3)',
-'show-big-image'       => 'Resolution ameqran',
-'show-big-image-thumb' => '<small>Tiddi n uzar-ascan: $1 × $2 pixel </small>',
+'file-info-size' => '$1 × $2 pixel, tiddisize n ufaylu: $3, anawtype n MIME: $4',
+'file-nohires'   => '<small>walu ca n resolution yemɣa x wa.</small>',
+'svg-long-desc'  => 'Afaylu n SVG, dis $1 × $2 pixel, Tiddi n ufaylu: $3',
+'show-big-image' => 'Resolution ameqran',
 
 # Special:NewFiles
 'newimages' => 'Amewlaf n ifayluten imaynuten',
@@ -750,18 +744,22 @@ Innḍni ad twaffrn dg umzwar.
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength', # Do not translate list items
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => 'Ẓṛeg afaylu a s usnas zi baṛṛa',
-'edit-externally-help' => 'Xemm [http://www.mediawiki.org/wiki/Manual:External_editors setup instructions] i ktar n tilɣa(informations).',
+'edit-externally-help' => 'Xemm [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] i ktar n tilɣa(informations).',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'maṛṛa',
-'imagelistall'     => 'maṛṛa',
-'watchlistall2'    => 'marra',
-'namespacesall'    => 'marra',
-'monthsall'        => 'marra',
+'watchlistall2' => 'marra',
+'namespacesall' => 'marra',
+'monthsall'     => 'marra',
 
 # Multipage image navigation
 'imgmultigo' => 'Raḥ ɣa!',
@@ -775,7 +773,7 @@ Innḍni ad twaffrn dg umzwar.
 'watchlisttools-raw'  => 'Ẓṛeg Tabdart uḥṭṭu tamenzut',
 
 # Special:Version
-'version'              => 'Tunɣilt', # Not used as normal message but as header for the special page itself
+'version'              => 'Tunɣilt',
 'version-specialpages' => 'Tudmawin Special',
 
 # Special:FileDuplicateSearch
