@@ -33,79 +33,79 @@ $namespaceNames = array(
 );
 
 $specialPageAliases = array(
-	'DoubleRedirects'           => array( 'ٻٽا چورڻا' ),
-	'BrokenRedirects'           => array( 'ٽٽل چورڻا' ),
-	'Disambiguations'           => array( 'سلجھائپ' ),
-	'Userlogin'                 => array( 'يوزر لاگ اِن' ),
-	'Userlogout'                => array( 'يوزر لاگ آئوٽ' ),
-	'CreateAccount'             => array( 'کاتو کوليو' ),
-	'Preferences'               => array( 'ترجيحات' ),
-	'Watchlist'                 => array( 'ٽيٽ فهرست' ),
-	'Recentchanges'             => array( 'تازيون تبديليون' ),
-	'Upload'                    => array( 'چاڙهيو' ),
-	'Listfiles'                 => array( 'عڪس فهرست' ),
-	'Newimages'                 => array( 'نوان عڪس' ),
-	'Listusers'                 => array( 'يوزر فهرست' ),
-	'Statistics'                => array( 'انگ اکر' ),
-	'Randompage'                => array( 'بلا ترتيب' ),
-	'Lonelypages'               => array( 'يتيم صفحا' ),
-	'Uncategorizedpages'        => array( 'اڻزمرايل صفحا' ),
-	'Uncategorizedcategories'   => array( 'اڻ زمرايل زمرا' ),
-	'Uncategorizedimages'       => array( 'اڻ زمرايل عڪس' ),
-	'Uncategorizedtemplates'    => array( 'اڻ زمرايل سانچا' ),
-	'Unusedcategories'          => array( 'اڻ استعماليل زمرا' ),
-	'Unusedimages'              => array( 'اڻ استعماليل عڪس' ),
-	'Wantedpages'               => array( 'گھربل صفحا' ),
-	'Wantedcategories'          => array( 'گھربل زمرا' ),
-	'Shortpages'                => array( 'مختصر صفحا' ),
-	'Longpages'                 => array( 'طويل صفحا' ),
-	'Newpages'                  => array( 'نوان صفحا' ),
-	'Ancientpages'              => array( 'قديم صفحا' ),
-	'Protectedpages'            => array( 'تحفظيل صفحا' ),
-	'Protectedtitles'           => array( 'تحفظيل عنوان' ),
-	'Allpages'                  => array( 'سڀ صفحا' ),
-	'Prefixindex'               => array( 'اڳياڙي ڏسڻي' ),
-	'Ipblocklist'               => array( 'آءِ پي بندش فهرست' ),
-	'Specialpages'              => array( 'خاص صفحا' ),
-	'Contributions'             => array( 'ڀاڱيداريون' ),
-	'Emailuser'                 => array( 'برقٽپال يوزر' ),
-	'Confirmemail'              => array( 'برقٽپال تصديقيو' ),
-	'Whatlinkshere'             => array( 'هتان ڳنڍيل صفحا' ),
-	'Movepage'                  => array( 'صفحو چوريو' ),
-	'Blockme'                   => array( 'مونکي بندشيو' ),
-	'Categories'                => array( 'زمرا' ),
-	'Export'                    => array( 'برآمد' ),
-	'Version'                   => array( 'ورزن' ),
 	'Allmessages'               => array( 'سڀ نياپا' ),
-	'Log'                       => array( 'لاگس' ),
-	'Blockip'                   => array( 'آءِ پي بندش' ),
-	'Undelete'                  => array( 'اڻ ڊاهيو' ),
-	'Import'                    => array( 'درآمد' ),
-	'Lockdb'                    => array( 'اعدادخانو بند' ),
-	'Unlockdb'                  => array( 'اعدادخانو کول' ),
-	'Userrights'                => array( 'يوزر حق' ),
-	'MIMEsearch'                => array( 'مائيم ڳولا' ),
+	'Allpages'                  => array( 'سڀ صفحا' ),
+	'Ancientpages'              => array( 'قديم صفحا' ),
+	'Block'                     => array( 'آءِ پي بندش' ),
+	'Blockme'                   => array( 'مونکي بندشيو' ),
+	'BrokenRedirects'           => array( 'ٽٽل چورڻا' ),
+	'Categories'                => array( 'زمرا' ),
+	'Confirmemail'              => array( 'برقٽپال تصديقيو' ),
+	'Contributions'             => array( 'ڀاڱيداريون' ),
+	'CreateAccount'             => array( 'کاتو کوليو' ),
+	'Disambiguations'           => array( 'سلجھائپ' ),
+	'DoubleRedirects'           => array( 'ٻٽا چورڻا' ),
+	'Emailuser'                 => array( 'برقٽپال يوزر' ),
+	'Export'                    => array( 'برآمد' ),
 	'FileDuplicateSearch'       => array( 'ساڳيا فائيل ڳولا' ),
-	'Unwatchedpages'            => array( 'اڻٽيٽيل صفحا' ),
-	'Listredirects'             => array( 'چورڻا فهرست' ),
-	'Unusedtemplates'           => array( 'اڻ استعماليل سانچا' ),
-	'Randomredirect'            => array( 'بلا ترتيب چورڻو' ),
-	'Mypage'                    => array( 'منهنجو صفحو' ),
-	'Mytalk'                    => array( 'مون سان ڳالهه' ),
-	'Mycontributions'           => array( 'منهنجون ڀاڱيداريون' ),
+	'Filepath'                  => array( 'فائيل ڏس' ),
+	'Import'                    => array( 'درآمد' ),
+	'Invalidateemail'           => array( 'ناقابلڪار برقٽپال' ),
+	'BlockList'                 => array( 'آءِ پي بندش فهرست' ),
 	'Listadmins'                => array( 'منتظمين فهرست' ),
 	'Listbots'                  => array( 'بوٽس فهرست' ),
-	'Popularpages'              => array( 'مقبول صفحا' ),
-	'Search'                    => array( 'ڳولا' ),
-	'Withoutinterwiki'          => array( 'ري بين الوڪي' ),
+	'Listfiles'                 => array( 'عڪس فهرست' ),
+	'Listredirects'             => array( 'چورڻا فهرست' ),
+	'Listusers'                 => array( 'يوزر فهرست' ),
+	'Lockdb'                    => array( 'اعدادخانو بند' ),
+	'Log'                       => array( 'لاگس' ),
+	'Lonelypages'               => array( 'يتيم صفحا' ),
+	'Longpages'                 => array( 'طويل صفحا' ),
 	'MergeHistory'              => array( 'سوانح ضماءُ' ),
-	'Filepath'                  => array( 'فائيل ڏس' ),
-	'Invalidateemail'           => array( 'ناقابلڪار برقٽپال' ),
+	'MIMEsearch'                => array( 'مائيم ڳولا' ),
+	'Movepage'                  => array( 'صفحو چوريو' ),
+	'Mycontributions'           => array( 'منهنجون ڀاڱيداريون' ),
+	'Mypage'                    => array( 'منهنجو صفحو' ),
+	'Mytalk'                    => array( 'مون سان ڳالهه' ),
+	'Newimages'                 => array( 'نوان عڪس' ),
+	'Newpages'                  => array( 'نوان صفحا' ),
+	'Popularpages'              => array( 'مقبول صفحا' ),
+	'Preferences'               => array( 'ترجيحات' ),
+	'Prefixindex'               => array( 'اڳياڙي ڏسڻي' ),
+	'Protectedpages'            => array( 'تحفظيل صفحا' ),
+	'Protectedtitles'           => array( 'تحفظيل عنوان' ),
+	'Randompage'                => array( 'بلا ترتيب' ),
+	'Randomredirect'            => array( 'بلا ترتيب چورڻو' ),
+	'Recentchanges'             => array( 'تازيون تبديليون' ),
+	'Search'                    => array( 'ڳولا' ),
+	'Shortpages'                => array( 'مختصر صفحا' ),
+	'Specialpages'              => array( 'خاص صفحا' ),
+	'Statistics'                => array( 'انگ اکر' ),
+	'Uncategorizedcategories'   => array( 'اڻ زمرايل زمرا' ),
+	'Uncategorizedimages'       => array( 'اڻ زمرايل عڪس' ),
+	'Uncategorizedpages'        => array( 'اڻزمرايل صفحا' ),
+	'Uncategorizedtemplates'    => array( 'اڻ زمرايل سانچا' ),
+	'Undelete'                  => array( 'اڻ ڊاهيو' ),
+	'Unlockdb'                  => array( 'اعدادخانو کول' ),
+	'Unusedcategories'          => array( 'اڻ استعماليل زمرا' ),
+	'Unusedimages'              => array( 'اڻ استعماليل عڪس' ),
+	'Unusedtemplates'           => array( 'اڻ استعماليل سانچا' ),
+	'Unwatchedpages'            => array( 'اڻٽيٽيل صفحا' ),
+	'Upload'                    => array( 'چاڙهيو' ),
+	'Userlogin'                 => array( 'يوزر لاگ اِن' ),
+	'Userlogout'                => array( 'يوزر لاگ آئوٽ' ),
+	'Userrights'                => array( 'يوزر حق' ),
+	'Version'                   => array( 'ورزن' ),
+	'Wantedcategories'          => array( 'گھربل زمرا' ),
+	'Wantedpages'               => array( 'گھربل صفحا' ),
+	'Watchlist'                 => array( 'ٽيٽ فهرست' ),
+	'Whatlinkshere'             => array( 'هتان ڳنڍيل صفحا' ),
+	'Withoutinterwiki'          => array( 'ري بين الوڪي' ),
 );
 
 $magicWords = array(
 	'redirect'              => array( '0', '#چوريو', '#REDIRECT' ),
-	'localmonth'            => array( '1', 'مقاميمهينو', 'LOCALMONTH' ),
+	'localmonth'            => array( '1', 'مقاميمهينو', 'LOCALMONTH', 'LOCALMONTH2' ),
 	'localmonthname'        => array( '1', 'مقاميمهينونالو', 'LOCALMONTHNAME' ),
 	'localday'              => array( '1', 'مقاميڏينهن', 'LOCALDAY' ),
 	'localday2'             => array( '1', 'مقاميڏينهن2', 'LOCALDAY2' ),
@@ -139,7 +139,6 @@ $magicWords = array(
 	'currentweek'           => array( '1', 'هلندڙهفتو', 'CURRENTWEEK' ),
 	'currentdow'            => array( '1', 'اڄوڪوڏينهن', 'CURRENTDOW' ),
 	'localweek'             => array( '1', 'مقاميهفتو', 'LOCALWEEK' ),
-	'localdow'              => array( '1', 'مقاميڏينهن', 'LOCALDOW' ),
 	'plural'                => array( '0', 'جمع', 'PLURAL:' ),
 	'fullurl'               => array( '0', 'مڪمليوآريل', 'FULLURL:' ),
 	'currenttimestamp'      => array( '1', 'هلندڙوقتمهر', 'CURRENTTIMESTAMP' ),
@@ -231,23 +230,36 @@ $messages = array(
 'subcategories'            => 'ذيلي زمرا',
 'category-media-header'    => ' "$1" زمري اندر ذريعات',
 'category-empty'           => "''في الوقت هن زمري ۾ ڪي به صفحا يا ذريعات شامل ناهن.''",
-'hidden-category-category' => 'لڪل زمرا', # Name of the category where hidden categories will be listed
+'hidden-category-category' => 'لڪل زمرا',
 'listingcontinuesabbrev'   => 'جاري..',
 
-'about'          => 'بابت',
-'article'        => 'مسوَدو',
-'newwindow'      => '(نئين کڙڪيءَ ۾ کلندو)',
-'cancel'         => 'رد',
+'about'         => 'بابت',
+'article'       => 'مسوَدو',
+'newwindow'     => '(نئين کڙڪيءَ ۾ کلندو)',
+'cancel'        => 'رد',
+'moredotdotdot' => 'اڃا...',
+'mypage'        => 'منهنجو صفحو',
+'mytalk'        => 'مون سان ڳالهه',
+'and'           => '&#32;۽',
+
+# Cologne Blue skin
 'qbfind'         => 'ڳوليو',
 'qbbrowse'       => 'جھانگيو',
 'qbedit'         => 'سنواريو',
 'qbpageoptions'  => 'هيءُ صفحو',
 'qbmyoptions'    => 'منهنجا صفحا',
 'qbspecialpages' => 'خاص صفحا',
-'moredotdotdot'  => 'اڃا...',
-'mypage'         => 'منهنجو صفحو',
-'mytalk'         => 'مون سان ڳالهه',
-'and'            => '&#32;۽',
+'faq'            => 'ڪپوس',
+'faqpage'        => 'Project:ڪپوس',
+
+# Vector skin
+'vector-action-delete'    => 'ڊاھيو',
+'vector-action-move'      => 'چوريو',
+'vector-action-protect'   => 'تحفظيو',
+'vector-action-unprotect' => 'اڻتحفظيو',
+'vector-view-create'      => 'سرجيو',
+'vector-view-edit'        => 'سنواريو',
+'vector-view-viewsource'  => 'ڪوڊ ڏسو',
 
 'errorpagetitle'    => 'چُڪَ',
 'returnto'          => '$1 ڏانهن وَرو.',
@@ -259,7 +271,6 @@ $messages = array(
 'searcharticle'     => 'کوليو',
 'history'           => 'صفحي جي سوانح',
 'history_short'     => 'سوانح',
-'info_short'        => 'معلومات',
 'printableversion'  => 'ڇپائتو پرت',
 'permalink'         => 'مسقتل ڳنڍڻو',
 'print'             => 'ڇاپيو',
@@ -295,7 +306,7 @@ $messages = array(
 'otherlanguages'    => 'ٻين ٻولين ۾',
 'redirectedfrom'    => '($1 کان چوريل)',
 'redirectpagesub'   => 'چوريل صفحو',
-'lastmodifiedat'    => 'هيءُ صفحو آخري ڀيرو $2، $1ع تي ترميميو ويو هو.', # $1 date, $2 time
+'lastmodifiedat'    => 'هيءُ صفحو آخري ڀيرو $2، $1ع تي ترميميو ويو هو.',
 'viewcount'         => 'هيءُ صفحو {{PLURAL:$1|دفعو|$1 دفعا}} ڏسجي چڪو آهي.',
 'protectedpage'     => 'تحفظيل صفحو',
 'jumptosearch'      => 'ڳولا',
@@ -304,7 +315,6 @@ $messages = array(
 'aboutsite'            => '{{SITENAME}} بابت',
 'aboutpage'            => 'Project:بابت',
 'copyright'            => 'سمورو مواد $1 تحت ميسر ڪجي ٿو',
-'copyrightpagename'    => '{{SITENAME}} حق ۽ واسطا',
 'copyrightpage'        => '{{ns:project}}:حق ۽ واسطا',
 'currentevents'        => 'ھاڻوڪا واقعا',
 'currentevents-url'    => 'Project: اعداد',
@@ -312,8 +322,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:عام غيرجوابدارينامو',
 'edithelp'             => 'مدد براءِ ترميم',
 'edithelppage'         => 'Help:سنوارڻ',
-'faq'                  => 'ڪپوس',
-'faqpage'              => 'Project:ڪپوس',
 'helppage'             => 'Help:فهرست',
 'mainpage'             => 'مُک صفحو',
 'mainpage-description' => 'مُک صفحو',
@@ -330,6 +338,9 @@ $messages = array(
 'newmessagesdifflink' => 'آخري تبديلي',
 'editsection'         => 'سنواريو',
 'editold'             => 'سنواريو',
+'viewsourceold'       => 'ڪوڊ ڏسو',
+'editlink'            => 'سنواريو',
+'viewsourcelink'      => 'ڪوڊ ڏسو',
 'editsectionhint'     => 'سنواريو سيڪشن: $1',
 'toc'                 => 'فهرست',
 'showtoc'             => 'ڏيکاريو',
@@ -339,13 +350,14 @@ $messages = array(
 'site-rss-feed'       => '$1 آر ايس ايس روان رسد',
 'site-atom-feed'      => '$1 اڻو روان رسد',
 'page-rss-feed'       => '"$1" RSS برق مواد',
+'page-atom-feed'      => '"$1" اڻو روان رسد',
 'red-link-title'      => '$1 (اڃا لکيل ناهي)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'صفحو',
 'nstab-user'      => 'تعارفي صفحو',
 'nstab-media'     => 'ذريعاتي صفحو',
-'nstab-special'   => 'خاص',
+'nstab-special'   => 'خاص صفحو',
 'nstab-project'   => 'رٿائي صفحو',
 'nstab-image'     => 'فائيل',
 'nstab-mediawiki' => 'نياپو',
@@ -359,7 +371,6 @@ $messages = array(
 # General errors
 'error'               => 'چُڪَ',
 'databaseerror'       => 'اعدادخاني ۾ چڪ',
-'nodb'                => 'اعدادخانو $1 چونڊجي نه سگھيو',
 'readonly'            => 'اعدادخانو بنديل',
 'missingarticle-diff' => '(تفاوت: $1، $2)',
 'internalerror'       => 'اندروني خرابي',
@@ -377,31 +388,25 @@ $messages = array(
 'ns-specialprotected' => 'خاص صفحا سنواري نٿا سگھجن.',
 
 # Login and logout pages
-'logouttitle'                => 'يوزر لاگ آئوٽ',
 'yourname'                   => 'يُوزرنانءُ:',
 'yourpassword'               => 'ڳجھو لفظ:',
-'remembermypassword'         => 'هن ڳڻپيوڪر تي مون کي ياد رکو',
+'remembermypassword'         => 'هن ڳڻپيوڪر تي مون کي ياد رکو (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                      => 'لاگ اِن',
 'nav-login-createaccount'    => 'لاگ اِن ٿيو / کاتو کوليو',
 'loginprompt'                => '{{SITENAME}} ۾ لاگ اِن ٿيڻ لاءِ ڪوڪيز جي قبوليت لازمي آهي.',
 'userlogin'                  => 'لاگ اِن ٿيو / کاتو کوليو',
 'logout'                     => 'لاگ آئوٽ',
 'userlogout'                 => 'لاگ آئوٽ',
-'nologin'                    => 'پنهنجو کاتو نه ٿا رکو؟ $1.',
+'nologin'                    => "پنهنجو کاتو نه ٿا رکو؟ '''$1'''.",
 'nologinlink'                => 'نئون کاتو کوليو',
 'createaccount'              => 'کاتو کوليو',
-'gotaccount'                 => 'ڇا اڳي ئي کاتو رکو ٿا؟ $1.',
+'gotaccount'                 => "ڇا اڳي ئي کاتو رکو ٿا؟ '''$1'''.",
 'gotaccountlink'             => 'لاگ اِن',
 'createaccountmail'          => 'بذريعه برق ٽپال',
-'yourrealname'               => 'اصل نالو:',
-'badsiglength'               => 'اها صحيح تمام وڏي آهي.
-$1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
-'prefs-help-realname'        => 'اصل نالو اختياري آهي.
-جيڪڏهن توهان اصل نالو ڄاڻائڻ جو فيصلو ٿا ڪريو، ته اهو توهان کي مڃتا ڏيڻ لاءِ ڪم آندو ويندو.',
 'loginsuccesstitle'          => 'لاگ اِن ڪامياب',
 'loginsuccess'               => "'''هاڻي توهان {{SITENAME}} تي بطور \"\$1\" لاگ اِن ٿيل آهيو.'''",
 'nosuchuser'                 => '"$1" نالي سان ڪو به يوزر نه آهي. هِجي چڪاسيو، يا نئون کاتو کوليو.',
-'nosuchusershort'            => '"<nowiki>$1</nowiki>" نالي ڪو به يُوزر ناهي.
+'nosuchusershort'            => '"$1" نالي ڪو به يُوزر ناهي.
 هِجي جي پڪ ڪندا.',
 'nouserspecified'            => 'توهان کي ڪو يوزرنانءُ ڄاڻائڻو پوندو.',
 'wrongpassword'              => 'ڏنل ڳجھو لفظ غير درست آهي. مهرباني ڪري ٻيهر ڪوشش ڪندا.',
@@ -421,7 +426,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'accountcreated'             => 'کاتو کلي چڪو',
 'accountcreatedtext'         => '$1 نالي يوزر کاتو کلي چڪو آھي.',
 
-# Password reset dialog
+# Change password dialog
 'retypenew' => 'نئون ڳجھو لفظ ٻيهر ٽائيپ ڪندا:',
 
 # Edit page toolbar
@@ -435,28 +440,26 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'extlink_tip'     => 'خارجي ڳنڍڻو (اڳياڙي http://  نه وساريندا)',
 'headline_sample' => 'سرخي',
 'headline_tip'    => 'سطح 2 جي سرخي',
-'math_sample'     => 'هتي فارمولو وجھو',
-'math_tip'        => 'رياضياتي مساوات (LaTeX)',
 'image_tip'       => 'جَڙيل فائيل',
 'media_tip'       => 'فائيل جو ڳنڍڻو',
 'sig_tip'         => 'توهان جي صحيح بمع اوقاتي مهر',
 'hr_tip'          => 'افقي لڪير (غيرضروري استعمال کان پاسو ڪندا)',
 
 # Edit pages
-'summary'                => 'تَتُ:',
-'subject'                => 'موضوع/سُرخي:',
-'minoredit'              => 'هيءَ هڪ معمولي ترميم آهي',
-'watchthis'              => 'هيءُ صفحو سانڍيو',
-'savearticle'            => 'صفحو سانڍيو',
-'preview'                => 'پيش نگاهه',
-'showpreview'            => 'پيش نگاهه',
-'showdiff'               => 'تبديليون ڏيکاريو',
-'anoneditwarning'        => "'''خبردار:''' توهان لاگ اِن ٿيل ناهيو.
+'summary'                    => 'تَتُ:',
+'subject'                    => 'موضوع/سُرخي:',
+'minoredit'                  => 'هيءَ هڪ معمولي ترميم آهي',
+'watchthis'                  => 'هيءُ صفحو سانڍيو',
+'savearticle'                => 'صفحو سانڍيو',
+'preview'                    => 'پيش نگاهه',
+'showpreview'                => 'پيش نگاهه',
+'showdiff'                   => 'تبديليون ڏيکاريو',
+'anoneditwarning'            => "'''خبردار:''' توهان لاگ اِن ٿيل ناهيو.
 هن صفحي جي سوانح ۾ توهان جو آءِ پي پتو درج ڪيو ويندو.",
-'missingcommenttext'     => 'براءِ مهرباني هيٺ پنهنجا تاثرات درج ڪندا.',
-'summary-preview'        => 'تت تي پيش نگاهه:',
-'blockedtitle'           => 'يُوزر بندشيل آهي.',
-'blockedtext'            => "<big>'''توهان جي يوزرنانءُ يا آءِ پي کي بندشيو ويو آهي.'''</big>
+'missingcommenttext'         => 'براءِ مهرباني هيٺ پنهنجا تاثرات درج ڪندا.',
+'summary-preview'            => 'تت تي پيش نگاهه:',
+'blockedtitle'               => 'يُوزر بندشيل آهي.',
+'blockedtext'                => "'''توهان جي يوزرنانءُ يا آءِ پي کي بندشيو ويو آهي.'''
 
 بندش $1 هنئي. جڏهن ته ڄاڻايل سبب ''$2'' آهي.
 
@@ -466,24 +469,23 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 * بندش جو هدف: $7
 
 اهڙي روڪ تي بحث ڪرڻ لاءِ توهان $1 يا ڪنهن ٻي [[{{MediaWiki:Grouppage-sysop}}|منتظم]] سان رابطو ڪري سگھو ٿا. جيڪڏهن توهان جو درست [[Special:ترجيحات|کاتو ترجيحات]] ۾ درست برق ٽپال پتو درج ٿيل نه آهي ته توهان 'هن يوزر کي برق ٽپال ڪريو' وارو فيچر نه ٿا استعمال ڪري سگھو. توهان جو هاڻوڪو آءِ پي پتو $3 آهي، ۽ بندش سڃاڻپ $5 آهي. مهرباني ڪري ڪنهن به پڇا ڳاڇا يا لهوچڙ  لاءِ انهن مان ڪنهن هڪ يا ٻنهي جو حوالو ڏيندا.",
-'blockednoreason'        => 'سبب اڻڄاڻايل',
-'accmailtitle'           => 'ڳجھو لفظ اماڻجي چڪو.',
-'newarticle'             => '(نئون)',
-'newarticletext'         => "توهان اهڙي صفحي جو ڳنڍڻو وٺي هتي پهتا آهيو، جيڪو اڃا وجود نه ٿو رکي. اهڙو صفحو جوڙڻ لاءِ هيٺين باڪس ۾ ٽائيپ ڪرڻ شروع ڪريو (وڌيڪ ڄاڻڻ لاءِ [[{{MediaWiki:Helppage}}|امدادي صفحو]] ڏسندا). جي توهان هتي غلطيءَ ۾ اچي ويا آهيو ته رڳو پنهنجي جهانگُوءَ جو '''back''' بٽڻ ڪلڪ ڪندا.",
-'previewnote'            => "'''هيءَ محظ پيش نگاهه آهي، ترميمون اڃا سانڍجون ناهن!'''",
-'editing'                => 'زير ترميم $1',
-'editingsection'         => 'زير ترميم $1 (سيڪشن)',
-'copyrightwarning'       => "ياد رکندا ته {{SITENAME}} لاءِ سموريون ڀاڱيداريون $2 تحت پڌريون ڪجن ٿيون (تفصيلن لاءِ $1 ڏسندا). اوهان جي تحرير کي {{SITENAME}} جي قائدن تحت ترميمي سگهجي ٿو. جيڪڏهن اوهان نه ٿا چاهيو ته اوهان جي لکڻين کي بي رحميءَ سان ترميميو وڃي يا ورهائي عام ڪيو وڃي ته پوءِ پنهنجي لکڻي هتي جمع نه ڪرايو. پنهنجو مواد هتي جمع ڪرڻ جو مطلب هوندو ته توهان کي جمع ڪرايل مواد جي مفت فراهمي ۽ کُليل تبديليءَ تي ڪو به اعتراز ناهي.<br />
+'blockednoreason'            => 'سبب اڻڄاڻايل',
+'accmailtitle'               => 'ڳجھو لفظ اماڻجي چڪو.',
+'newarticle'                 => '(نئون)',
+'newarticletext'             => "توهان اهڙي صفحي جو ڳنڍڻو وٺي هتي پهتا آهيو، جيڪو اڃا وجود نه ٿو رکي. اهڙو صفحو جوڙڻ لاءِ هيٺين باڪس ۾ ٽائيپ ڪرڻ شروع ڪريو (وڌيڪ ڄاڻڻ لاءِ [[{{MediaWiki:Helppage}}|امدادي صفحو]] ڏسندا). جي توهان هتي غلطيءَ ۾ اچي ويا آهيو ته رڳو پنهنجي جهانگُوءَ جو '''back''' بٽڻ ڪلڪ ڪندا.",
+'previewnote'                => "'''هيءَ محظ پيش نگاهه آهي، ترميمون اڃا سانڍجون ناهن!'''",
+'editing'                    => 'زير ترميم $1',
+'editingsection'             => 'زير ترميم $1 (سيڪشن)',
+'copyrightwarning'           => "ياد رکندا ته {{SITENAME}} لاءِ سموريون ڀاڱيداريون $2 تحت پڌريون ڪجن ٿيون (تفصيلن لاءِ $1 ڏسندا). اوهان جي تحرير کي {{SITENAME}} جي قائدن تحت ترميمي سگهجي ٿو. جيڪڏهن اوهان نه ٿا چاهيو ته اوهان جي لکڻين کي بي رحميءَ سان ترميميو وڃي يا ورهائي عام ڪيو وڃي ته پوءِ پنهنجي لکڻي هتي جمع نه ڪرايو. پنهنجو مواد هتي جمع ڪرڻ جو مطلب هوندو ته توهان کي جمع ڪرايل مواد جي مفت فراهمي ۽ کُليل تبديليءَ تي ڪو به اعتراز ناهي.<br />
 توهان اهڙي پڪ ڏيڻ جا پابند پڻ آهيو ته توهان جو جمع ڪرايل مواد توهان جو پنهنجو لکيل آهي يا وري توهان ڪنهن مفت وسيلي تان ڪاپي ڪيو آهي.
 '''تحفظيل حق ۽ واسطا رکندڙ مواد واسطيدار مالڪ کان اڳواٽ اجازت وٺڻ کان سواءِ هتي جمع نه ڪريو.'''",
-'longpagewarning'        => "'''خبردار: هيءُ صفحو $1 ڪلوٻاٽڻيون وڏو آهي؛ 32 ڪلوٻاٽڻين کان وڏا صفحا سنواريندي ڪن جھانگوئن سان مسئلا ٿين ٿا. مهرباني ڪري هن صفحي کي ننڍن سيڪشنز ۾ ٽوڙڻ تي ويچاريندا.'''",
-'templatesused'          => 'هن صفحي تي استعمال ٿيندڙ سانچا:',
-'templatesusedpreview'   => 'هن پيش نگاهه ۾ استعمال ٿيل سانچا:',
-'template-protected'     => '(تحفظيل)',
-'template-semiprotected' => '(نيم تحفظيل)',
-'nocreatetext'           => '{{SITENAME}} نوان صفحا سرجڻ جي روڪَ ڪئي آهي.
+'templatesused'              => 'هن صفحي تي استعمال ٿيندڙ سانچا:',
+'templatesusedpreview'       => 'هن پيش نگاهه ۾ استعمال ٿيل سانچا:',
+'template-protected'         => '(تحفظيل)',
+'template-semiprotected'     => '(نيم تحفظيل)',
+'nocreatetext'               => '{{SITENAME}} نوان صفحا سرجڻ جي روڪَ ڪئي آهي.
 توهان اڳي ئي موجود صفحن کي سنواري سگھو ٿا، يا [[Special:UserLogin|لاگ اِن ٿي يا نئون کاتو کولي سگھو ٿا]].',
-'recreate-deleted-warn'  => "'''خبردار: توهان اهڙو صفحو نئين سر سرجي رهيا آهيو جيڪو اڳي ڊاٺو ويو آهي.'''
+'recreate-moveddeleted-warn' => "'''خبردار: توهان اهڙو صفحو نئين سر سرجي رهيا آهيو جيڪو اڳي ڊاٺو ويو آهي.'''
 
 بهتر ٿيندو ته توهان سوچي وٺو ته ڇا ان صفحي کي سنوارڻ بهتر ٿيندو.
 توهآن جي سهوليت خاطر هتي ان صفحي جو ڊاٺ لاگ ميسر ڪجي ٿو:",
@@ -492,7 +494,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'viewpagelogs'        => 'هن صفحي جا لاگ ڏسو',
 'currentrev'          => 'هاڻوڪو مسودو',
 'revisionasof'        => '$1 وارو پرت',
-'revision-info'       => '$1 تي $2 جي ترميم بعد مسودو', # Additionally available: $3: revision id
+'revision-info'       => '$1 تي $2 جي ترميم بعد مسودو',
 'previousrevision'    => '←اڃا پراڻو پرت',
 'nextrevision'        => 'اڃا نئون پرت→',
 'currentrevisionlink' => 'هاڻوڪو پرت',
@@ -505,7 +507,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'historyempty'        => '(خالي)',
 
 # Revision feed
-'history-feed-item-nocomment' => '$2 تي $1', # user at time
+'history-feed-item-nocomment' => '$2 تي $1',
 
 # Revision deletion
 'pagehist' => 'صفحي جي سوانح',
@@ -519,26 +521,29 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'diff-multi'              => '({{PLURAL:$1|هڪ وسطي مسودو|$1 وسطي مسودا}} لڪايل.)',
 
 # Search results
-'noexactmatch'      => "'''\"\$1\" جي عنوان سان ڪو به صفحو ناهي.'''
-توهان [[:\$1|اهو صفحو سرجيو]].",
-'prevn'             => 'پويان $1',
-'nextn'             => 'اڳيان $1',
-'viewprevnext'      => 'ڏسو ($1) ($2) ($3)',
+'prevn'             => 'پويان {{PLURAL:$1|$1}}',
+'nextn'             => 'اڳيان {{PLURAL:$1|$1}}',
+'viewprevnext'      => 'ڏسو ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url'    => 'Help:فهرست',
 'powersearch'       => 'نفيس ڳولا',
 'powersearch-redir' => 'چورڻن جي فهرست ڏيکاريو',
 
 # Preferences page
-'preferences'    => 'ترجيحات',
-'mypreferences'  => 'منهنجون ترجيحات',
-'changepassword' => 'ڳجھو لفظ تبديل ڪريو',
-'skin-preview'   => 'پيش نگاهه',
-'datedefault'    => 'بلا ترجيحا',
-'datetime'       => 'تاريخ ۽ وقت',
-'allowemail'     => 'ٻين يُوزرس کان ايندڙ برق ٽپال بحال ڪريو',
+'preferences'         => 'ترجيحات',
+'mypreferences'       => 'منهنجون ترجيحات',
+'changepassword'      => 'ڳجھو لفظ تبديل ڪريو',
+'skin-preview'        => 'پيش نگاهه',
+'datedefault'         => 'بلا ترجيحا',
+'prefs-datetime'      => 'تاريخ ۽ وقت',
+'allowemail'          => 'ٻين يُوزرس کان ايندڙ برق ٽپال بحال ڪريو',
+'yourrealname'        => 'اصل نالو:',
+'badsiglength'        => 'اها صحيح تمام وڏي آهي.
+$1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
+'prefs-help-realname' => 'اصل نالو اختياري آهي.
+جيڪڏهن توهان اصل نالو ڄاڻائڻ جو فيصلو ٿا ڪريو، ته اهو توهان کي مڃتا ڏيڻ لاءِ ڪم آندو ويندو.',
 
 # User rights
-'userrights-reason' => 'تبديليءَ جو سبب:',
+'userrights-reason' => 'سبب:',
 
 # Groups
 'group'      => 'گروپ:',
@@ -576,6 +581,8 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 
 # Recent changes linked
 'recentchangeslinked'          => 'لاڳاپيل تبديليون',
+'recentchangeslinked-feed'     => 'لاڳاپيل تبديليون',
+'recentchangeslinked-toolbox'  => 'لاڳاپيل تبديليون',
 'recentchangeslinked-title'    => '"$1" سان لاڳاپيل تبديليون',
 'recentchangeslinked-noresult' => 'ڄاڻايل مدي دوران ڳنڍيل صفحن ۾ ڪا به تبديلي ناهي ٿي.',
 
@@ -589,6 +596,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'listfiles' => 'فائيل فهرست',
 
 # File description page
+'file-anchor-link'          => 'فائيل',
 'filehist'                  => 'فائيل جي سوانح',
 'filehist-help'             => 'ڪنهن به تاريخ/وقت تي ڪلڪ ڪري ڏسندا ته تڏڻي اهو فائيل ڪيئن هو.',
 'filehist-current'          => 'هاڻوڪو',
@@ -600,9 +608,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'imagelinks'                => 'ڳنڍڻا',
 'linkstoimage'              => 'هن فائيل سان {{PLURAL:$1|هيٺيون صفحو ڳنڍيل آهي |$1 هيٺيان صفحا ڳنڍيل آهن}}:',
 'nolinkstoimage'            => 'هن فائيل سان ڪو به صفحو ڳنڍيل ناهي.',
-'sharedupload'              => 'هيءَ هڪ شراڪتي چاڙهه آهي، تنهنڪري ان کي ٻيون رٿائون به استعمال ڪري سگھن ٿيون.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'noimage'                   => 'ان نالي سان ڪو به فائيل وجود نٿو رکي، جي چاهيو ته $1.',
-'noimage-linktext'          => 'اهو چاڙهيو',
+'sharedupload'              => 'هيءَ هڪ شراڪتي چاڙهه آهي، تنهنڪري ان کي ٻيون رٿائون به استعمال ڪري سگھن ٿيون.',
 'uploadnewversion-linktext' => 'هن فائيل جو نئون پرت چاڙهيو',
 
 # MIME search
@@ -628,8 +634,8 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'doubleredirects' => 'ٻٽا چورڻا',
 
 'brokenredirects'        => 'ٽٽل چورڻا',
-'brokenredirects-edit'   => '(سنواريو)',
-'brokenredirects-delete' => '(ڊاهيو)',
+'brokenredirects-edit'   => 'سنواريو',
+'brokenredirects-delete' => 'ڊاهيو',
 
 'withoutinterwiki' => 'ڪنهن به ٻي ٻوليءَ سان نه ڳنڍيل صفحا',
 
@@ -694,10 +700,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 # Watchlist
 'watchlist'         => 'منهنجي ٽيٽ فهرست',
 'mywatchlist'       => 'منهنجي ٽيٽ فهرست',
-'watchlistfor'      => "(براءِ '''$1''')",
-'addedwatch'        => 'ٽيٽ فھرست ۾ شامل ڪيو ويو.',
 'addedwatchtext'    => "صفحو بعنوان \"[[:\$1]]\" اوهان جي [[Special:Watchlist|ٽيٽ فهرست]] ۾ شامل ٿي ويو. استقبالي تبديليون هتي درج ٿينديون وينديون. اهو صفحو [[Special:RecentChanges|تازين تبديلين]] واري صفحي تي '''گهرن''' اکرن ۾ نمايان ڪري ڏيکاريو ويندو. جيڪڏهن اوهان اهو سڀ نه ٿا چاهيو ته '''اڻ ٽيٽيو''' تي ڪلڪ ڪريو.",
-'removedwatch'      => 'ٽيٽ فهرست مان هٽايو ويو',
 'removedwatchtext'  => 'صفحو بعنوان "[[:$1]]" توهان جي ٽيٽ فهرست مان هٽي چڪو آهي.',
 'watch'             => 'ٽيٽيو',
 'watchthispage'     => 'هيءُ صفحو ٽيٽيو',
@@ -720,11 +723,11 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'historywarning'        => 'خبردار: جيڪو صفحو توهان ڊاهڻ وارا آهيو، تنهن جي هڪ سوانح آهي:',
 'confirmdeletetext'     => 'توهان هڪ صفحي کي ان جي سموري سوانح سميت ڊاهڻ وارا آهيو. مهرباني ڪري پڪ ڪندا ته توهان اهو ئي ڪرڻ گھرو ٿا، ۽ اهو ته توهان ان جي نتيجن کان واقف آهيو، ۽ اهو پڻ ته توهان اهو ڪم [[{{MediaWiki:Policy-url}}|پاليسي]]ءَ مطابق ڪري رهيا آهيو.',
 'actioncomplete'        => 'ڪم پُورو',
-'deletedtext'           => '"<nowiki>$1</nowiki>" ڊهي چڪو آهي.
+'deletedtext'           => '"$1" ڊهي چڪو آهي.
 تازو ڊاٺل صفحن جي فهرست لاءِ $2 ڏسندا.',
 'deletedarticle'        => '"[[$1]]" ڊهي چڪو',
 'dellogpage'            => 'ڊاٺ لاگ',
-'deletecomment'         => 'ڊاهڻ جو سبب:',
+'deletecomment'         => 'سبب:',
 'deleteotherreason'     => 'اڃا ڪو ٻيو سبب:',
 'deletereasonotherlist' => 'ٻيو سبب',
 
@@ -735,12 +738,11 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'protectlogpage'              => 'تحفظ لاگ',
 'prot_1movedto2'              => '[[$1]] کي چوري [[$2]] تي رکيو ويو',
 'protect-legend'              => 'تحفظڻ جي پڪ ڪريو',
-'protectcomment'              => 'تاثرات:',
+'protectcomment'              => 'سبب:',
 'protectexpiry'               => 'اختتام:',
 'protect_expiry_invalid'      => 'انجامي مدو ناقابلڪار آهي.',
 'protect_expiry_old'          => 'انجامي مدو ماضيءَ ۾ آهي.',
-'protect-unchain'             => 'چورڻ جي روڪ ختم ڪريو',
-'protect-text'                => "توهان '''<nowiki>$1</nowiki>''' صفحي جي تحفظاتي سطح ڏسي ۽ بدلائي سگھو ٿا.",
+'protect-text'                => "توهان '''$1''' صفحي جي تحفظاتي سطح ڏسي ۽ بدلائي سگھو ٿا.",
 'protect-locked-access'       => "توهان جو کاتو صفحن جي تحفظاتي سطح تبديلي ڪرڻ جا اختيار نه ٿو رکي. هيٺ صفحي جون وقوعات (سيٽڱس) پيش ڪجن ٿيون '''$1''':",
 'protect-cascadeon'           => 'هيءُ صفحو في الوقت تحفظيل آهي، ڇاڪاڻ ته اهو هيٺين {{PLURAL:$1|صفحي|صفحن}} جو حصو آهي، جنهن تي تحفظ در تحفظ لاڳو ٿيل آهي.',
 'protect-fallback'            => '"$1" جي اجازت گھرجي',
@@ -749,7 +751,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'protect-summary-cascade'     => 'تحفظ در تحفظ',
 'protect-cascade'             => 'هن صفحي ۾ شامل صفحن کي تحفظيو (تحفظ در تحفظ)',
 'protect-cantedit'            => 'توهان هن صفحي جي تحفظاتي سطح نٿا بدلائي سگھو، ڇاڪاڻ ته توهان ان کي سنوارڻ جي اجازت نٿا رکو.',
-'protect-expiry-options'      => '2 ڪلاڪ:2 hours،1 ڏينهن:1 day،3 ڏينهن:3 days،1 هفتو:1 week،2 هفتا:2 weeks،1 مهينو:1 month،3 مهينا:3 months،6 مهينا:6 months،1 سال:1 year،لامحدود:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '2 ڪلاڪ:2 hours،1 ڏينهن:1 day،3 ڏينهن:3 days،1 هفتو:1 week،2 هفتا:2 weeks،1 مهينو:1 month،3 مهينا:3 months،6 مهينا:6 months،1 سال:1 year،لامحدود:infinite',
 'restriction-type'            => 'اجازتنامو:',
 'restriction-level'           => 'روڪ سطح:',
 'pagesize'                    => '(ٻاٽڻيون)',
@@ -773,6 +775,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 
 'sp-contributions-newbies-sub' => 'نون کاتن لاءِ',
 'sp-contributions-blocklog'    => 'بنسش لاگ',
+'sp-contributions-talk'        => 'بحث',
 
 # What links here
 'whatlinkshere'       => 'هتان ڇا ڳنڍيل آهي',
@@ -787,7 +790,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 
 # Block/unblock
 'blockip'                  => 'يُوزر کي روڪيو',
-'ipboptions'               => '2 ڪلاڪ:2 hours،1 ڏينهن:1 day،3 ڏينهن:3 days،1 هفتو:1 week،2 هفتا:2 weeks،1 مهينو:1 month،3 مهينا:3 months،6 مهينا:6 months،1 سال:1 year،لامحدود:infinite', # display1:time1,display2:time2,...
+'ipboptions'               => '2 ڪلاڪ:2 hours،1 ڏينهن:1 day،3 ڏينهن:3 days،1 هفتو:1 week،2 هفتا:2 weeks،1 مهينو:1 month،3 مهينا:3 months،6 مهينا:6 months،1 سال:1 year،لامحدود:infinite',
 'badipaddress'             => 'ناقابلڪار آءِ پي پتو',
 'ipblocklist'              => 'بندشيل يوزرنانءُ ۽ آءِ پي پتا',
 'infiniteblock'            => 'لامحدود',
@@ -819,7 +822,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'move-watch'              => 'هيءُ صفحو ٽيٽيو',
 'movepagebtn'             => 'صفحو چوريو',
 'pagemovedsub'            => 'چورڻ جو عمل ڪامياب ٿيو',
-'movepage-moved'          => '<big>\'\'\'"$1" کي چوري "$2" تي رکيو ويو آهي\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'          => '\'\'\'"$1" کي چوري "$2" تي رکيو ويو آهي\'\'\'',
 'articleexists'           => 'ان نالي سان صفحو اڳي ئي وجود رکي ٿو، يا ته توهان جو ڏنل نالو ناقابلڪار آهي.',
 'talkexists'              => "
 '''موادي صفحو پاڻ ته ڪاميابيءَ سان چُري ويو، پر لاڳاپيل مباحثي صفحو چُري نه سگھيو ڇاڪاڻ ته نئين عنوان تي اڳي ئي هڪ مباحثي صفحو موجود آهي. براءِ مهرباني انهن ٻنهي هٿ سان ضمائيندا.",
@@ -836,11 +839,9 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'export' => 'صفحا برآمديو',
 
 # Namespace 8 related
-'allmessages'         => 'سرشتائي نياپا',
-'allmessagesname'     => 'نالو',
-'allmessagescurrent'  => 'موجوده تحرير',
-'allmessagesfilter'   => 'نياپي نانءُ ڇاڻي:',
-'allmessagesmodified' => 'صرف ترميم شدھ ڏيکاريو',
+'allmessages'        => 'سرشتائي نياپا',
+'allmessagesname'    => 'نالو',
+'allmessagescurrent' => 'موجوده تحرير',
 
 # Thumbnails
 'thumbnail-more' => 'وڏو ڪريو',
@@ -899,11 +900,10 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'nextdiff'     => 'نئون تفاوت -->',
 
 # Media information
-'file-info-size'       => '($1 × $2 عڪسلون، فائيل سائيز: $3، MIME ٽائيپ: $4)',
-'file-nohires'         => '<small>اڃا سنهو تحلل ميسر ناهي.</small>',
-'svg-long-desc'        => '(ايس وي جي فائيل، اٽڪل $1 × $2 عڪسلون، فائيل سائيز: $3)',
-'show-big-image'       => 'سنهو ترين تحلل',
-'show-big-image-thumb' => '<small>هن پيش نگاهه جي ماپ: $1 × $2 عڪسلون</small>',
+'file-info-size' => '$1 × $2 عڪسلون، فائيل سائيز: $3، MIME ٽائيپ: $4',
+'file-nohires'   => '<small>اڃا سنهو تحلل ميسر ناهي.</small>',
+'svg-long-desc'  => 'ايس وي جي فائيل، اٽڪل $1 × $2 عڪسلون، فائيل سائيز: $3',
+'show-big-image' => 'سنهو ترين تحلل',
 
 # Special:NewFiles
 'newimages' => 'نون فائيلن جي گيلري',
@@ -932,7 +932,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 
 'exif-unknowndate' => 'نامعلوم تاريخ',
 
-'exif-orientation-3' => '180° موڙيل', # 0th row: bottom; 0th column: right
+'exif-orientation-3' => '180° موڙيل',
 
 'exif-componentsconfiguration-0' => 'وجود نه ٿو رکي',
 
@@ -955,21 +955,19 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'exif-gpsmeasuremode-2' => '2-رخي ماپ',
 'exif-gpsmeasuremode-3' => '3-رخي ماپ',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-k' => 'ڪلوميٽر في ڪلاڪ',
 'exif-gpsspeed-m' => 'ميل في ڪلاڪ',
 'exif-gpsspeed-n' => 'ڳنڍيون',
 
 # External editor support
 'edit-externally'      => 'هيءُ فائيل ڪنهن خارجي منتقڪريءَ سان سنواريو',
-'edit-externally-help' => 'وڌيڪ معلومات لاءِ [http://www.mediawiki.org/wiki/Manual:External_editors هدايتون براءِ تنصيبڪاري] ڏسندا.',
+'edit-externally-help' => 'وڌيڪ معلومات لاءِ [//www.mediawiki.org/wiki/Manual:External_editors هدايتون براءِ تنصيبڪاري] ڏسندا.',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'سڀ',
-'imagelistall'     => 'سڀ',
-'watchlistall2'    => 'سڀ',
-'namespacesall'    => 'سڀ',
-'monthsall'        => 'سڀ',
+'watchlistall2' => 'سڀ',
+'namespacesall' => 'سڀ',
+'monthsall'     => 'سڀ',
 
 # E-mail address confirmation
 'confirmemail_success' => 'توھان جي برق ٽپال جي پڪ ڪئي وئي آھي. ھاڻِ توھان لاگ ان ٿي وڪيءَ جو مزو وٺي سگھو ٿا',
@@ -983,7 +981,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'watchlisttools-raw'  => 'ڪچي ٽيٽ فهرست سنواريو',
 
 # Special:Version
-'version' => 'ورزن', # Not used as normal message but as header for the special page itself
+'version' => 'ورزن',
 
 # Special:SpecialPages
 'specialpages'             => 'خاص صفحا',
