@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Andrijko Z.
  * @author Bïerne
  * @author M.M.S.
  * @author Urhixidur
@@ -80,21 +81,25 @@ $messages = array(
 'category-empty'         => "''Dïhte kategorije sisvege ijje bielieh jallh baalkah.''",
 'listingcontinuesabbrev' => 'jåar.',
 
-'about'          => 'Bïjre',
-'article'        => 'Sisvege bielie',
-'newwindow'      => '(geehpehtidh sïjse orre klaase)',
-'cancel'         => 'Orrijidh',
+'about'         => 'Bïjre',
+'article'       => 'Sisvege bielie',
+'newwindow'     => '(geehpehtidh sïjse orre klaase)',
+'cancel'        => 'Orrijidh',
+'moredotdotdot' => 'Jienebe...',
+'mypage'        => 'Mov bielie',
+'mytalk'        => 'Mov dïjveldidh',
+'anontalk'      => 'Dïjveldidh ihke dïhte IP',
+'navigation'    => 'Navigasjovne',
+'and'           => '&#32;jih',
+
+# Cologne Blue skin
 'qbfind'         => 'Gaavnedh',
 'qbedit'         => 'Värrhtoedimmie',
 'qbpageoptions'  => 'Dïhte bielie',
 'qbmyoptions'    => 'Mov bielieh',
 'qbspecialpages' => 'Joekoelaakan bielieh',
-'moredotdotdot'  => 'Jienebe...',
-'mypage'         => 'Mov bielie',
-'mytalk'         => 'Mov dïjveldidh',
-'anontalk'       => 'Dïjveldidh ihke dïhte IP',
-'navigation'     => 'Navigasjovne',
-'and'            => '&#32;jih',
+'faq'            => 'FAQ',
+'faqpage'        => 'Project:FAQ',
 
 'errorpagetitle'   => 'Båajhtode',
 'returnto'         => 'Bååstide gåajkoe $1.',
@@ -106,7 +111,6 @@ $messages = array(
 'searcharticle'    => 'Vaadtsa',
 'history'          => 'Histovrije',
 'history_short'    => 'Histovrije',
-'info_short'       => 'Bïevnesh',
 'printableversion' => 'Tjaelije bielie',
 'permalink'        => 'Permanente lïenghke',
 'print'            => 'Tjaeledh olkese',
@@ -149,8 +153,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:Bäjjesereaktah',
 'edithelp'             => 'Sjiehtedimmie viehkie',
 'edithelppage'         => 'Help:Sjiehtedimmie',
-'faq'                  => 'FAQ',
-'faqpage'              => 'Project:FAQ',
 'helppage'             => 'Help:Sisvege',
 'mainpage'             => 'Aalkoebielie',
 'mainpage-description' => 'Aalkoebielie',
@@ -202,7 +204,7 @@ $messages = array(
 # Login and logout pages
 'yourname'                => 'Nuhtjiennomme:',
 'yourpassword'            => 'Loevesbaakoe:',
-'remembermypassword'      => 'Måjhtije mov loggesïjse nille dïhte daatovre',
+'remembermypassword'      => 'Måjhtije mov loggesïjse nille dïhte daatovre (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'          => 'Dov domäne:',
 'login'                   => 'Logge sïjse',
 'nav-login-createaccount' => 'Logge sïjse / skaepede nuhtjien',
@@ -216,19 +218,11 @@ $messages = array(
 'gotaccount'              => "Åtna dov joe nuhtjiennomme? '''$1'''.",
 'gotaccountlink'          => 'Logge sïjse',
 'createaccountmail'       => 'meatan e-påaste',
-'youremail'               => 'E-påaste:',
-'username'                => 'Nuhtjiennomme:',
-'uid'                     => 'Nuhtjien ID:',
-'yourrealname'            => 'Ov nomme:',
-'yourlanguage'            => 'Gïele:',
-'yournick'                => 'Nuhjiennomme:',
-'email'                   => 'E-påaste',
-'prefs-help-realname'     => 'Ov nomme galkedh ijje tjaeledh. Bïjre datne veeljeme tjaeledh dov ov nomme, båetedh dïhte nuhtjie ihke tjaeledh dov barkoe.',
 'loginerror'              => 'Logge sïjse båajhtode',
 'loginsuccesstitle'       => 'Dov lea daelie sïjse logge',
 'loginsuccess'            => "'''Dov lea daelie sïjselogge nille {{SITENAME}} goh \"\$1\".'''",
 'nosuchuser'              => 'Dïhte gååvnese ijje nuhtjien goh nomme "$1". Gïehtjedidh dov baakoehtidh, jallh skaepede orre nuhtjien.',
-'nosuchusershort'         => 'Dïhte gååvnese ijje nuhtjien goh nomme "<nowiki>$1</nowiki>". Gïehtjedidh baakoehtidh.',
+'nosuchusershort'         => 'Dïhte gååvnese ijje nuhtjien goh nomme "$1". Gïehtjedidh baakoehtidh.',
 'nouserspecified'         => 'Dov galkedh tjaeledh nuhtjiennomme.',
 'wrongpassword'           => 'Loevesbaakoe lea gåarhmede. Vuejnedh vihth.',
 'wrongpasswordempty'      => 'Loevesbaakoe lea gåaroes. Vuejnedh vihth.',
@@ -242,7 +236,7 @@ Gïemhpes logge sïjse vihth männgan datne åtna låhka dïhte.',
 'accountcreated'          => 'Nuhtjien skaepede',
 'loginlanguagelabel'      => 'Gïele: $1',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => 'Båeries loevesbaakoe:',
 'newpassword' => 'Orre loevesbaakoe:',
 'retypenew'   => 'Odhasit orre loevesbaakoe:',
@@ -258,8 +252,6 @@ Gïemhpes logge sïjse vihth männgan datne åtna låhka dïhte.',
 'extlink_tip'     => 'Ehkstäärne lïenghke (måjhtajidh http:// prefihkse)',
 'headline_sample' => 'Rubriike tjaalege',
 'headline_tip'    => 'Daltese 2 rubriike',
-'math_sample'     => 'Bïejedh fårmele daesnie',
-'math_tip'        => 'Ryökneme fårmele (LaTeX)',
 'nowiki_sample'   => 'Bïejedh ijje-hammode tjaalege daesnie',
 'nowiki_tip'      => 'Rievdde wikïhammode',
 'image_tip'       => 'Lååtje guvvie',
@@ -284,7 +276,8 @@ Gïemhpes logge sïjse vihth männgan datne åtna låhka dïhte.',
 'accmailtext'            => 'Loevesbaakoe ihke ”$1” utnedh seedtedh gåajkoe $2.',
 'newarticle'             => '(Orre)',
 'noarticletext'          => 'Dïhte lea daelie ijje tjaalege sïjse dïhte bielie, dov dorje [[Special:Search/{{PAGENAME}}|ohtsedh ihke dïhte bielie nomme]] sïjse jeatjebh bielieh jallh [{{fullurl:{{FULLPAGENAME}}|action=edit}} värrhtoedimmie dïhte bielie].',
-'usercssjsyoucanpreview' => "'''Tiipse:''' Nuhtjie 'Vuesehte åvte-vuesiehtidh' båaloe ihke pryövoe dov orre CSS/JS åvte spååredh.",
+'usercssyoucanpreview'   => "'''Tiipse:''' Nuhtjie 'Vuesehte åvte-vuesiehtidh' båaloe ihke pryövoe dov orre CSS åvte spååredh.",
+'userjsyoucanpreview'    => "'''Tiipse:''' Nuhtjie 'Vuesehte åvte-vuesiehtidh' båaloe ihke pryövoe dov orre JS åvte spååredh.",
 'updated'                => '(Orrestahteme)',
 'note'                   => "'''Galtege:'''",
 'previewnote'            => "'''Dïhte lea aktegh åvte-vuesiehtidh; värrhtoedimmieh ånta ijje sjïdtedh spååredh!'''",
@@ -294,11 +287,8 @@ Gïemhpes logge sïjse vihth männgan datne åtna låhka dïhte.',
 'copyrightwarning'       => "Tjaeleste gaajhke värrhtoedimmieh gåajkoe {{SITENAME}} lea ahte gïehtjele goh maam buektedh nuelesne $2 (vuajna $1 ihke detaaljeh). Bïjre datne ijje sïjhtedh dov tjaalege galka värrhtoedimmieh jallh kåpieeres minngesne jeatjebh daerpies voete, galka datne ijje tjaala daesnie.<br />
 Datne luhpede mijjieh aaj datne tjaala tjaalege jïjtje, jallh kåpieeret raejeste gaaltjie goh ijje vaarjele dejstie bäjjesereaktah, jallh plïerehke.<br />
 '''LISSEHTE IJJE OLKESE BÄJJESEREAKTAHVAARJELE ÏEBNE NAMHTAH LUHPIE!'''",
-'longpagewarning'        => "'''VAAROEHTIDH: Dïhte bielie lea $1 kilobyteh guhkie; såemies
-gaskeviermie-låhkoeh åtna tsagkeseh värrhtoedimmie bielih stoerre jallh guhkies enn 32 kb.
-Joekedidh värrhtoedimmie sïjse unnebe sektiovneh.'''",
-'templatesused'          => 'Maaleh nuhtjie nille dïhte bielie:',
-'templatesusedpreview'   => 'Maaleh nuhtjie sïjse dïhte åvte-vuesiehtidh:',
+'templatesused'          => '{{PLURAL:$1|Maal|Maler}}Maaleh nuhtjie nille dïhte bielie:',
+'templatesusedpreview'   => '{{PLURAL:$1|Maal|Maaleh}} nuhtjie sïjse dïhte åvte-vuesiehtidh:',
 'template-protected'     => '(vaarjeleme)',
 'template-semiprotected' => '(lehkie-vaarjelidh)',
 'nocreatetext'           => '{{SITENAME}} åtna gaertjiedidh nuepieh ahte skaepede orre bielieh.
@@ -308,7 +298,7 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 'viewpagelogs'        => 'Vuesehte loggeh ihke dïhte bielie',
 'currentrev'          => 'Daaletje gïehtjedamme',
 'revisionasof'        => 'Gïehtjedamme ihke $1',
-'revision-info'       => 'Gïehtjedamme raejeste dïhte $1; $2', # Additionally available: $3: revision id
+'revision-info'       => 'Gïehtjedamme raejeste dïhte $1; $2',
 'previousrevision'    => '←Båarasåabpoe gïehtjedamme',
 'nextrevision'        => 'Minngebe gïehtjedamme→',
 'currentrevisionlink' => 'Daaletje gïehtjedamme',
@@ -323,7 +313,7 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 
 # Revision feed
 'history-feed-title'          => 'Gïehtjedamme histovrije',
-'history-feed-item-nocomment' => '$1 dïhte $2', # user at time
+'history-feed-item-nocomment' => '$1 dïhte $2',
 
 # History merging
 'mergehistory-from' => 'Gaaltjie bielie:',
@@ -340,23 +330,29 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 'searchresults'    => 'Ohtsedh resultaateh',
 'searchresulttext' => 'Ihke jeenjebe bïevnesh bïjre ohtsedh {{SITENAME}}, vuejnedh [[{{MediaWiki:Helppage}}|{{int:help}}]].',
 'searchsubtitle'   => "Dov ohtsedh ihke '''[[:$1]]'''",
-'noexactmatch'     => "'''Dïhte gååvnese ijje bielie meatan nommej \"\$1\".''' Dov dorje [[:\$1|skaepede dïhte bielie]].",
-'prevn'            => 'övtebe $1',
-'nextn'            => 'minngeben $1',
-'viewprevnext'     => 'Vuesehth ($1) ($2) ($3)',
+'prevn'            => 'övtebe {{PLURAL:$1|$1}}',
+'nextn'            => 'minngeben {{PLURAL:$1|$1}}',
+'viewprevnext'     => 'Vuesehth ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url'   => 'Help:Sisvege',
 'powersearch'      => 'Ohtsedh',
 
 # Preferences page
-'preferences'        => 'Sïjsestäälningeh',
-'mypreferences'      => 'Mov sïjsesäälningeh',
-'changepassword'     => 'Värrhtoedimmie loevesbaakoe',
-'skin-preview'       => 'Åvte-vuesiehtidh',
-'math_unknown_error' => 'ammes båajhtede',
-'saveprefs'          => 'Spååredh',
-'searchresultshead'  => 'Ohtsedh',
-'timezonelegend'     => 'Tïjjedajve',
-'localtime'          => 'Byjrehks tïjje',
+'preferences'         => 'Sïjsestäälningeh',
+'mypreferences'       => 'Mov sïjsesäälningeh',
+'changepassword'      => 'Värrhtoedimmie loevesbaakoe',
+'skin-preview'        => 'Åvte-vuesiehtidh',
+'saveprefs'           => 'Spååredh',
+'searchresultshead'   => 'Ohtsedh',
+'timezonelegend'      => 'Tïjjedajve',
+'localtime'           => 'Byjrehks tïjje',
+'youremail'           => 'E-påaste:',
+'username'            => 'Nuhtjiennomme:',
+'uid'                 => 'Nuhtjien ID:',
+'yourrealname'        => 'Ov nomme:',
+'yourlanguage'        => 'Gïele:',
+'yournick'            => 'Nuhjiennomme:',
+'email'               => 'E-påaste',
+'prefs-help-realname' => 'Ov nomme galkedh ijje tjaeledh. Bïjre datne veeljeme tjaeledh dov ov nomme, båetedh dïhte nuhtjie ihke tjaeledh dov barkoe.',
 
 # User rights
 'editinguser' => "Värrhtoedimmie nuhtjien '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
@@ -378,7 +374,7 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 'nchanges'                       => '$1 {{PLURAL:$1|värrhtoedimmie|värrhtoedimmieh}}',
 'recentchanges'                  => 'Männgan värrhtoedimmieh',
 'recentchanges-feed-description' => 'Dåeriedidh männgan värrhtoedimmie sïjse wiki meatan dïhte feed.',
-'rcnote'                         => "Vuelen vuesehte {{PLURAL:$1|dïhte männgan värrhtoedimmie|dah männgan '''$1''' värrhtoedimmieh}} nuelesne dah {{PLURAL:$2|männgan biejjie|männgan '''$2''' biejjieh}}, ihke $3.",
+'rcnote'                         => "Vuelen vuesehte {{PLURAL:$1|dïhte männgan värrhtoedimmie|dah männgan '''$1''' värrhtoedimmieh}} nuelesne dah {{PLURAL:$2|männgan biejjie|männgan '''$2''' biejjieh}}, ihke $5, $4.",
 'rcnotefrom'                     => "Vuelelen vuesehte dah männgan '''$1''' värrhtoedimmieh männgan '''$2'''.",
 'rclistfrom'                     => 'Vuesehte orre värrhtoedimmieh aelkedh raejeste $1',
 'rcshowhideminor'                => '$1 ohtje värrhtoedimmie',
@@ -398,25 +394,27 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 
 # Recent changes linked
 'recentchangeslinked'          => 'Värrhtoedimmieh nille krïense bielieh',
+'recentchangeslinked-feed'     => 'Värrhtoedimmieh nille krïense bielieh',
+'recentchangeslinked-toolbox'  => 'Värrhtoedimmieh nille krïense bielieh',
 'recentchangeslinked-title'    => 'Värrhtoedimmie laktaseaddji gåajkoe "$1"',
 'recentchangeslinked-noresult' => 'Ijje kïrense bielieh värrhtoedimmie nuelesne dïhte veeljeme tïjje-boelhke.',
-'recentchangeslinked-summary'  => "Dïhte joekoelaakan bielie lästoe dah minngemes värrhtoedimmieh nille bielieh goh lea lïenghke. Bielieh nille dov sïektjedhlästoe lea '''buajtehks'''.",
+'recentchangeslinked-summary'  => "Dïhte joekoelaakan bielie lästoe dah minngemes värrhtoedimmieh nille bielieh goh lea lïenghke. Bielieh [[Special:Watchlist|nille dov]] sïektjedhlästoe lea '''buajtehks'''.",
 
 # Upload
-'upload'           => 'Sadde guvvie',
-'uploadbtn'        => 'Sadde baalka',
-'uploadlogpage'    => 'Sadde logge',
-'filename'         => 'Guvvienomme',
-'filesource'       => 'Gaaltjie',
-'fileexists-thumb' => "<center>'''Lea-guvvie'''</center>",
-'savefile'         => 'Spååredh guvvie',
-'uploadedimage'    => 'sadde "[[$1]]"',
-'uploadvirus'      => 'Guvvie tjeekehdidh viirus! Bïevnesh: $1',
-'sourcefilename'   => 'Gaaltjie guvvienomme',
+'upload'         => 'Sadde guvvie',
+'uploadbtn'      => 'Sadde baalka',
+'uploadlogpage'  => 'Sadde logge',
+'filename'       => 'Guvvienomme',
+'filesource'     => 'Gaaltjie',
+'savefile'       => 'Spååredh guvvie',
+'uploadedimage'  => 'sadde "[[$1]]"',
+'uploadvirus'    => 'Guvvie tjeekehdidh viirus! Bïevnesh: $1',
+'sourcefilename' => 'Gaaltjie guvvienomme',
 
 'upload-file-error' => 'Sjisjnjie båajhtode',
 
-'license' => 'Liseense',
+'license'        => 'Liseense',
+'license-header' => 'Liseense',
 
 # Special:ListFiles
 'listfiles_search_for' => 'Ohtsedh ihke guvvie nomme:',
@@ -427,6 +425,7 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 'listfiles_size'       => 'Stoerre',
 
 # File description page
+'file-anchor-link'          => 'Baalka',
 'filehist'                  => 'Baalka histovrije',
 'filehist-help'             => 'Diedtedh nille biejjie ihke vuajna man baalkan lij bealese dïhte tïjje.',
 'filehist-current'          => 'daaletje',
@@ -436,11 +435,9 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 'filehist-filesize'         => 'Guvvie stoerre',
 'filehist-comment'          => 'Lahtestimmie',
 'imagelinks'                => 'Lïenghkeh',
-'linkstoimage'              => 'Tjuovvovasj bielieh lïenghkeh gåajkoe dïhte baalka:',
+'linkstoimage'              => 'Tjuovvovasj {{PLURAL:$1|side|$1 sider}} bielieh lïenghkeh gåajkoe dïhte baalka:',
 'nolinkstoimage'            => 'Dïhte lea ijje bielieh goh nuhtjie dïhte baalka.',
-'sharedupload'              => 'Dïhte baalka lea sadde goh juaka jih dorje sjädta nuhtjie dejstie jeatjebh prosjekte.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'noimage'                   => 'Ijje baalka meatan dïhte nomme gååvnese, dov dorje $1.',
-'noimage-linktext'          => 'sadde dïhte',
+'sharedupload'              => 'Dïhte baalka lea $1 sadde goh juaka jih dorje sjädta nuhtjie dejstie jeatjebh prosjekte.',
 'uploadnewversion-linktext' => 'Sadde orre låhkoe dejstie dïhte baalka',
 
 # MIME search
@@ -552,10 +549,7 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 # Watchlist
 'watchlist'         => 'Mov sïektjedhlästoe',
 'mywatchlist'       => 'Mov sïektjedhlästoe',
-'watchlistfor'      => "(ihke '''$1''')",
-'addedwatch'        => 'Lissiehtidh gåajkoe sïektjedhlästoe',
-'removedwatch'      => 'Sihkojuvvon raejeste sïektjedhlästoe',
-'removedwatchtext'  => 'Bielie "[[:$1]]" lea sihkojuvvon raejeste dov sïektjedhlästoe.',
+'removedwatchtext'  => 'Bielie "[[:$1]]" lea sihkojuvvon raejeste [[Special:Watchlist|dov sïektjedhlästoe]].',
 'watch'             => 'Sïektjedh',
 'watchthispage'     => 'Sïektjedh dïhte bielie',
 'unwatch'           => 'Ov-sïektjedh',
@@ -574,7 +568,7 @@ Dov dorje värrhtoedimmie gååvnese bielieh, jallh [[Special:UserLogin|logge s
 'deletepage'            => 'Tjåegkedh bielie',
 'historywarning'        => 'Vaaroehtidh: Bielie datne gïehtele ahte sihkut åtna histovrije:',
 'actioncomplete'        => 'Deahpadimmie voerkes',
-'deletedtext'           => '"<nowiki>$1</nowiki>" lea sihkojuvvon.
+'deletedtext'           => '"$1" lea sihkojuvvon.
 Vuajna $2 ihke galtege bïjre männgan sihkojuvvonh.',
 'deletedarticle'        => 'sihkoj "[[$1]]"',
 'dellogpage'            => 'Sihkkun logge',
@@ -593,8 +587,7 @@ Vuajna $2 ihke galtege bïjre männgan sihkojuvvonh.',
 'protectexpiry'               => 'Boarasnuvve:',
 'protect_expiry_invalid'      => 'Ov-jiltiige buaorasjnuvvenaigi.',
 'protect_expiry_old'          => 'Boarasnuvvenaigi lea vaesedh.',
-'protect-unchain'             => 'Tjuevtedh jåhtaluhpie',
-'protect-text'                => "Daesnie dorje datne vuajna jih värrhtoedimmie vaarjelidhdaltese dejstie bielie '''<nowiki>$1</nowiki>'''.",
+'protect-text'                => "Daesnie dorje datne vuajna jih värrhtoedimmie vaarjelidhdaltese dejstie bielie '''$1'''.",
 'protect-locked-access'       => "Dov nuhtjien åtna ijje luhpie gåajkoe värrhtoedimmie tjaeleste-vaarjelidh.
 Daaletje tjaeleste-vaarjelidh sïjsestäälninge ihke bielie '''$1''' lea:",
 'protect-default'             => '(åvte-veeljeme)',
@@ -605,7 +598,7 @@ Daaletje tjaeleste-vaarjelidh sïjsestäälninge ihke bielie '''$1''' lea:",
 'protect-expiring'            => 'boarasnuvve $1 (UTC)',
 'protect-cascade'             => 'Vaarjelidh bielieh guosket sïjse dïhte bielie (viidit suodjaluse)',
 'protect-cantedit'            => 'Datne dorje ijje värrhtoedimmie vaarjelidhdaltese ihke dïhte bielie, ihke datne ijja åtna luhpie ahte värrhtoedimmie dïhte.',
-'protect-expiry-options'      => '2 täjmoe:2 hours,1 biejjie:1 day,3 biejjie:3 days,1 våhkoe:1 week,2 våhkoe:2 weeks,1 aske:1 month,3 aske:3 months,6 aske:6 months,1 jaepie:1 year,gietjieloeves:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '2 täjmoe:2 hours,1 biejjie:1 day,3 biejjie:3 days,1 våhkoe:1 week,2 våhkoe:2 weeks,1 aske:1 month,3 aske:3 months,6 aske:6 months,1 jaepie:1 year,gietjieloeves:infinite',
 'restriction-type'            => 'Permisjovne:',
 'restriction-level'           => 'Restriksjovne daltese:',
 
@@ -637,6 +630,7 @@ Daaletje tjaeleste-vaarjelidh sïjsestäälninge ihke bielie '''$1''' lea:",
 
 'sp-contributions-newbies-sub' => 'Ihke orre nuhtjienh',
 'sp-contributions-blocklog'    => 'Tjöödtjehtidh logge',
+'sp-contributions-talk'        => 'Digkiedimmie',
 'sp-contributions-username'    => 'IP Tjaalesijjie jallh nuhtjiennomme:',
 'sp-contributions-submit'      => 'Ohtsedh',
 
@@ -653,20 +647,18 @@ Daaletje tjaeleste-vaarjelidh sïjsestäälninge ihke bielie '''$1''' lea:",
 'whatlinkshere-links' => '← lïenghkeh',
 
 # Block/unblock
-'blockip'              => 'Tjöödtjehtidh nuhtjien',
-'ipaddress'            => 'IP Tjaalesijjie:',
-'ipadressorusername'   => 'IP Tjaalesijjie jallh nuhtjiennomme:',
-'ipbother'             => 'Jeatjebh tïjje:',
-'ipboptions'           => '2 täjmoe:2 hours,1 biejjie:1 day,3 biejjie:3 days,1 våhkoe:1 week,2 våhkoe:2 weeks,1 aske:1 month,3 aske:3 months,6 aske:6 months,1 jaepie:1 year,gietjieloeves:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'       => 'jeatjebh',
-'ipblocklist'          => 'Lästoe bijjelen tjöödtjehtidh IP tjaalesijjieh jih nuhtjiennommeh',
-'ipblocklist-username' => 'Nuhtjiennomme jallh IP tjaalesijjie:',
-'ipblocklist-submit'   => 'Ohtsedh',
-'blocklink'            => 'tjöödtjehtidh',
-'unblocklink'          => 'ov-tjöödtjehtidh',
-'contribslink'         => 'dåarjoeh',
-'blocklogpage'         => 'Tjöödtjehtidh logge',
-'blocklogentry'        => 'blåhkedidh "[[$1]]" $2 $3',
+'blockip'            => 'Tjöödtjehtidh nuhtjien',
+'ipadressorusername' => 'IP Tjaalesijjie jallh nuhtjiennomme:',
+'ipbother'           => 'Jeatjebh tïjje:',
+'ipboptions'         => '2 täjmoe:2 hours,1 biejjie:1 day,3 biejjie:3 days,1 våhkoe:1 week,2 våhkoe:2 weeks,1 aske:1 month,3 aske:3 months,6 aske:6 months,1 jaepie:1 year,gietjieloeves:infinite',
+'ipbotheroption'     => 'jeatjebh',
+'ipblocklist'        => 'Lästoe bijjelen tjöödtjehtidh IP tjaalesijjieh jih nuhtjiennommeh',
+'ipblocklist-submit' => 'Ohtsedh',
+'blocklink'          => 'tjöödtjehtidh',
+'unblocklink'        => 'ov-tjöödtjehtidh',
+'contribslink'       => 'dåarjoeh',
+'blocklogpage'       => 'Tjöödtjehtidh logge',
+'blocklogentry'      => 'blåhkedidh "[[$1]]" $2 $3',
 
 # Developer tools
 'lockdb'            => 'Tjuevtedh daatabaase',
@@ -766,11 +758,6 @@ Gïemhpes veeljeme jeatjebh nomme.',
 'siteuser'  => '{{SITENAME}} nuhtjien $1',
 'siteusers' => '{{SITENAME}} nuhtjien(h) $1',
 
-# Info page
-'infosubtitle' => 'Bïevnesh ihke bielie',
-'numedits'     => 'Låhkoe värrhtoedimmieh (bielie): $1',
-'numtalkedits' => 'Låhkoe värrhtoedimmieh (dïjvaldidh bielie): $1',
-
 # Patrol log
 'patrol-log-auto' => '(jïjtsistie)',
 
@@ -779,12 +766,11 @@ Gïemhpes veeljeme jeatjebh nomme.',
 'nextdiff'     => 'Minngebe joekehts →',
 
 # Media information
-'file-info'            => '(baalka stoerre: $1, MIME-vuekie: $2)',
-'file-info-size'       => '($1 × $2 pixel, baalka stoerre: $3, MIME-vuekie: $4)',
-'file-nohires'         => '<small>Ijje jïlle bäjjeselöösninge jaksoes.</small>',
-'svg-long-desc'        => '(SVG baalka, maadth-stoerre $1 × $2 pixel, baalka stoerre: $3)',
-'show-big-image'       => 'Dïeves stoerre',
-'show-big-image-thumb' => '<small>Stoerre ihke dïhte vuesiehtidh: $1 × $2 pixel</small>',
+'file-info'      => 'baalka stoerre: $1, MIME-vuekie: $2',
+'file-info-size' => '$1 × $2 pixel, baalka stoerre: $3, MIME-vuekie: $4',
+'file-nohires'   => '<small>Ijje jïlle bäjjeselöösninge jaksoes.</small>',
+'svg-long-desc'  => 'SVG baalka, maadth-stoerre $1 × $2 pixel, baalka stoerre: $3',
+'show-big-image' => 'Dïeves stoerre',
 
 # Special:NewFiles
 'newimages' => 'Gallerije dejstie orre baalkah',
@@ -802,7 +788,13 @@ Jeatjebh dajveh lea gaptjedh goh sïejhme, bine vuesehte gåessie taabelle stoer
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength', # Do not translate list items
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # EXIF tags
 'exif-imagewidth'         => 'Gamte',
@@ -841,14 +833,12 @@ Jeatjebh dajveh lea gaptjedh goh sïejhme, bine vuesehte gåessie taabelle stoer
 
 # External editor support
 'edit-externally'      => 'Värrhtoedimmie dïhte baalka meatan ehksteerne applikasjovne',
-'edit-externally-help' => 'Vuajna [http://www.mediawiki.org/wiki/Manual:External_editors instalasjovne instruksjovne] ihke vielie bïevnesh.',
+'edit-externally-help' => 'Vuajna [//www.mediawiki.org/wiki/Manual:External_editors instalasjovne instruksjovne] ihke vielie bïevnesh.',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'gaajhke',
-'imagelistall'     => 'gaajhke',
-'watchlistall2'    => 'gaajhke',
-'namespacesall'    => 'gaajhke',
-'monthsall'        => 'gaajhke',
+'watchlistall2' => 'gaajhke',
+'namespacesall' => 'gaajhke',
+'monthsall'     => 'gaajhke',
 
 # Scary transclusion
 'scarytranscludetoolong' => '[URL lea ihke guhkie; gaatelassjedh]',
@@ -884,7 +874,7 @@ Jeatjebh dajveh lea gaptjedh goh sïejhme, bine vuesehte gåessie taabelle stoer
 'unknown_extension_tag' => 'Ammes ekshtensjovne lissie "$1"',
 
 # Special:Version
-'version' => 'Låhkoe', # Not used as normal message but as header for the special page itself
+'version' => 'Låhkoe',
 
 # Special:SpecialPages
 'specialpages' => 'Joekoen bielieh',
