@@ -44,11 +44,13 @@ $messages = array(
 'november-gen'  => 'Mbudzi',
 'december-gen'  => 'Zvita',
 
-'cancel'         => 'Kanzura',
+'cancel'     => 'Kanzura',
+'mytalk'     => 'Hurukuro dzangu',
+'navigation' => 'Banguranyika',
+
+# Cologne Blue skin
 'qbedit'         => 'Chinja',
 'qbspecialpages' => 'Mapeji akakosha',
-'mytalk'         => 'Hurukuro dzangu',
-'navigation'     => 'Banguranyika',
 
 'help'             => 'Rubatsiro',
 'search'           => 'Tsvaga',
@@ -86,21 +88,19 @@ $messages = array(
 'viewsource' => 'Wona mabviro',
 
 # Login and logout pages
-'welcomecreation'    => '= Tigashire, $1! == 
-
-Akaunzi yako yagadzirwa. Usakanganwe kuchinga mapreferences ako eWikipedia.',
+'welcomecreation'    => '== Tigashire, $1! ==
+Akaunzi yako yagadzirwa.
+Usakanganwe kuchinga [[Special:Preferences|mapreferences ako {{SITENAME}}]].',
 'yourname'           => 'Zita:',
 'yourpassword'       => 'Password:',
 'yourpasswordagain'  => 'Nyorazve password:',
-'remembermypassword' => 'Ndiyeuke',
+'remembermypassword' => 'Ndiyeuke (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'              => 'Gamuchirwa',
 'userlogin'          => 'Gamuchirwa / Gadzira Akaunzi',
 'logout'             => 'Chibuda',
 'userlogout'         => 'Chibuda',
 'notloggedin'        => 'Hauna kugamuchirwa',
 'createaccount'      => 'Gadzira Akaunzi',
-'youremail'          => 'E-mail:',
-'username'           => 'Zita:',
 
 # Edit pages
 'summary'     => 'Muchidimbu:',
@@ -118,12 +118,16 @@ Akaunzi yako yagadzirwa. Usakanganwe kuchinga mapreferences ako eWikipedia.',
 'prefsnologin'      => 'Hauna kugamuchirwa',
 'prefs-rc'          => 'Zvaba Kuchinjwa',
 'searchresultshead' => 'Tsvaga',
+'youremail'         => 'E-mail:',
+'username'          => 'Zita:',
 
 # Recent changes
 'recentchanges' => 'Zvaba Kuchinjwa',
 
 # Recent changes linked
-'recentchangeslinked' => 'Zvinoenderana nezvachinjwa',
+'recentchangeslinked'         => 'Zvinoenderana nezvachinjwa',
+'recentchangeslinked-feed'    => 'Zvinoenderana nezvachinjwa',
+'recentchangeslinked-toolbox' => 'Zvinoenderana nezvachinjwa',
 
 # Upload
 'upload'          => 'Isa fayera',
