@@ -52,12 +52,14 @@ $messages = array(
 'mytalk'     => 'Leqephe la ka la moqoqo',
 'navigation' => 'Eya ho',
 
+# Cologne Blue skin
+'faq' => 'Dipotso-mehla',
+
 'returnto'       => 'Kgutlela ho $1.',
 'tagline'        => 'E tswa ho {{SITENAME}}',
 'search'         => 'Fuputsa',
 'history'        => 'Nalane',
 'history_short'  => 'Nalane',
-'info_short'     => 'Tlhahiso-leseding',
 'newpage'        => 'Leqephe le letjha',
 'talkpage'       => 'Qoqa ka leqephe lena',
 'talk'           => 'Moqoqo',
@@ -66,7 +68,6 @@ $messages = array(
 'jumptosearch'   => 'phuputso',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'faq'                  => 'Dipotso-mehla',
 'mainpage'             => 'Leqephe la pele',
 'mainpage-description' => 'Leqephe la pele',
 'portal'               => 'Potjho e kopano',
@@ -83,7 +84,7 @@ $messages = array(
 
 # Login and logout pages
 'yourpasswordagain'  => 'Ngola lepetjo hape',
-'remembermypassword' => 'O nkgopole',
+'remembermypassword' => 'O nkgopole (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'nologinlink'        => 'Ingodisetse',
 'createaccount'      => 'Ingodisetse',
 'gotaccount'         => "O se o ingodisitse? '''$1'''.",
@@ -91,7 +92,7 @@ $messages = array(
 'badretype'          => 'Mapetjo a mabedi o a ngotseng ha a tshwane.',
 'mailmypassword'     => 'Nthomele password ya ka ka email',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => 'Lepetjo la kgale:',
 'newpassword' => 'Lepetjo le letjha:',
 'retypenew'   => 'Ngola lepetjo le letjha hape:',
@@ -132,14 +133,16 @@ $messages = array(
 
 # Special:Categories
 'categories'         => 'Mekga',
-'categoriespagetext' => 'Wiki e na le mekga ena',
+'categoriespagetext' => 'Wiki e na le mekga ena.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # E-mail user
 'emailuser'     => 'Romela motho enwa email',
-'emailfrom'     => 'E tswa ho',
-'emailto'       => 'Ho',
-'emailsubject'  => 'Ka',
-'emailmessage'  => 'O re',
+'emailfrom'     => 'E tswa ho:',
+'emailto'       => 'Ho:',
+'emailsubject'  => 'Ka:',
+'emailmessage'  => 'O re:',
 'emailsend'     => 'E romele',
 'emailsent'     => 'E rometswe',
 'emailsenttext' => 'Email ya molaetsa wa hao e se e rometswe.',
@@ -157,7 +160,4 @@ $messages = array(
 'allmessagesdefault' => 'Se neng se ngotswe pele',
 'allmessagescurrent' => 'Se ngotsweng hona jwale',
 
-# Info page
-'infosubtitle' => 'Tlhahiso-leseding ka leqephe',
-
 );
