@@ -50,10 +50,12 @@ $messages = array(
 'may'       => 'ሜይ',
 'jun'       => 'ጁን',
 
-'about'         => 'ብዛዕባ ብጠቅላላ',
+'about'  => 'ብዛዕባ ብጠቅላላ',
+'mypage' => 'ፅሑፈይ',
+
+# Cologne Blue skin
 'qbpageoptions' => 'ፅሑፍዚ',
 'qbmyoptions'   => 'ፅሑፋተይ',
-'mypage'        => 'ፅሑፈይ',
 
 'help'          => 'ፍንጪ',
 'search'        => 'ድሉይ',
@@ -79,9 +81,6 @@ $messages = array(
 
 # Login and logout pages
 'yourname'           => 'ናይ ኣባል ሽም:',
-'youremail'          => 'ኢ-መይል:',
-'yourlanguage'       => 'ቋንቋ:',
-'email'              => 'ኢ-መይል',
 'loginlanguagelabel' => 'ቋንቋ: $1',
 
 # Edit pages
@@ -90,11 +89,11 @@ $messages = array(
 
 # History pages
 'next'        => 'ዝቕጽል',
-'historysize' => '($1 ባይታት)',
+'historysize' => '($1 {{PLURAL:$1|ባይታት|ባይታት}})',
 
 # Search results
-'prevn'       => 'ናይ ቀደም $1',
-'nextn'       => 'ዝቕጽል $1',
+'prevn'       => 'ናይ ቀደም {{PLURAL:$1|$1}}',
+'nextn'       => 'ዝቕጽል {{PLURAL:$1|$1}}',
 'powersearch' => 'ድሉይ',
 
 # Preferences page
@@ -103,7 +102,10 @@ $messages = array(
 'saveprefs'         => 'ኣቐምጥ',
 'searchresultshead' => 'ድሉይ',
 'savedprefs'        => 'ዘቕረብኩሞ መርኣይ ብትክክል ተቀሚጡ ኣሎ።',
-'files'             => 'ምስልታት',
+'prefs-files'       => 'ምስልታት',
+'youremail'         => 'ኢ-መይል:',
+'yourlanguage'      => 'ቋንቋ:',
+'email'             => 'ኢ-መይል',
 
 # Groups
 'group'       => 'ብሓበር:',
@@ -124,6 +126,9 @@ $messages = array(
 'listfiles_name' => 'ሽም',
 'listfiles_user' => 'ኣባል',
 
+# File description page
+'file-anchor-link' => 'ምስሊ',
+
 # Miscellaneous special pages
 'nbytes'            => '$1 {{PLURAL:$1|ባይት|ባይታት}}',
 'longpages'         => 'ነዋሕቲ ፅሑፋት',
@@ -146,9 +151,6 @@ $messages = array(
 'allpagesnext'   => 'ዝቕጽል',
 'allpagessubmit' => 'ኪድ',
 
-# Watchlist
-'watchlistfor' => "(ን'''$1''')",
-
 # Protect
 'pagesize' => '(ባይታት)',
 
