@@ -1,5 +1,5 @@
 <?php
-/** Tonga (lea faka-Tonga)
+/** Tongan (lea faka-Tonga)
  *
  * See MessagesQqq.php for message documentation incl. usage of parameters
  * To improve a translation please visit http://translatewiki.net
@@ -16,7 +16,7 @@ $messages = array(
 # User preference toggles
 'tog-underline'            => 'Ngaahi fehokotaki ʻoku laineʻi ʻi lalo:',
 'tog-highlightbroken'      => 'Ngaohi ʻa e ngaahi fehokotaki maumau ʻoku <a href="" class="new">pehē</a> (meʻa kehe ʻoku pehē <a href="" class="internal">?</a>).',
-'tog-rememberpassword'     => 'Manatuʻi ʻeku kau-ki-ai ʻi he komipiuta ʻeni',
+'tog-rememberpassword'     => 'Manatuʻi ʻeku kau-ki-ai ʻi he komipiuta ʻeni (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'       => 'Tānaki ngaahi peesi ʻoku fakatupu ʻe au ki he hokohoko leʻo',
 'tog-watchdefault'         => 'Tānaki ngaahi peesi ʻoku fatu ʻe au ki he hokohoko leʻo',
 'tog-watchmoves'           => 'Tānaki ki heʻeku hokohoko leʻo ʻa e ngaahi peesi kuo ʻunu ʻe au',
@@ -96,25 +96,29 @@ $messages = array(
 'subcategories'            => 'Ngaahi faʻahinga siʻi',
 'category-empty'           => "''Ko e faʻahinga ʻeni ʻoku ʻikai ʻi ai haʻane kupu pe ʻata.''",
 'hidden-categories'        => 'Faʻahinga toi',
-'hidden-category-category' => 'Ngaahi faʻahinga toi', # Name of the category where hidden categories will be listed
+'hidden-category-category' => 'Ngaahi faʻahinga toi',
 'listingcontinuesabbrev'   => ' hoko',
 
-'about'          => 'Kau ki',
-'article'        => 'Peesi kakano',
-'newwindow'      => '(fakaava ʻi he matapā foʻou)',
-'cancel'         => 'Kaniseli',
+'about'         => 'Kau ki',
+'article'       => 'Peesi kakano',
+'newwindow'     => '(fakaava ʻi he matapā foʻou)',
+'cancel'        => 'Kaniseli',
+'moredotdotdot' => 'Hoko...',
+'mypage'        => 'Peesi ʻaʻaku',
+'mytalk'        => 'Alea ʻaʻaku',
+'anontalk'      => 'Alea maʻa e IP´ ni',
+'navigation'    => 'ʻai taumuʻa ki he…',
+'and'           => '&#32;mo e',
+
+# Cologne Blue skin
 'qbfind'         => 'Kumi',
 'qbbrowse'       => 'Palausa',
 'qbedit'         => 'Fatu',
 'qbpageoptions'  => 'Peesi koʻeni',
 'qbmyoptions'    => 'Peesi ʻaʻaku',
 'qbspecialpages' => 'Ngaahi peesi makehe',
-'moredotdotdot'  => 'Hoko...',
-'mypage'         => 'Peesi ʻaʻaku',
-'mytalk'         => 'Alea ʻaʻaku',
-'anontalk'       => 'Alea maʻa e IP´ ni',
-'navigation'     => 'ʻai taumuʻa ki he…',
-'and'            => '&#32;mo e',
+'faq'            => 'Fehuʻi faʻa eke',
+'faqpage'        => 'Project:Fehuʻi faʻa eke',
 
 'errorpagetitle'    => 'Halaʻi',
 'returnto'          => 'Foki ki he $1',
@@ -127,7 +131,6 @@ $messages = array(
 'history'           => 'Hisitōlia ʻo e pēsí',
 'history_short'     => 'Hisitōlia',
 'updatedmarker'     => 'Kuo fakafoʻoua talu ai mei heʻeku ʻaʻahi',
-'info_short'        => 'Fakamatala',
 'printableversion'  => 'Paaki',
 'permalink'         => 'Fehokotaki taumaʻu',
 'print'             => 'Paaki',
@@ -170,14 +173,11 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Kau ki: {{SITENAME}}',
 'aboutpage'            => 'Project:ʻo kau ki',
-'copyrightpagename'    => 'Foʻi mafai ke pulusi maʻa e {{SITENAME}}',
 'currentevents'        => 'Ngaahi ongoongo',
 'currentevents-url'    => 'Project:Ongoongo taka',
 'disclaimers'          => 'Ngaahi fakaʻataʻatā',
 'disclaimerpage'       => 'Project:Fakaʻataʻatā lūkufua',
 'edithelp'             => 'Tokoni ki he fatu',
-'faq'                  => 'Fehuʻi faʻa eke',
-'faqpage'              => 'Project:Fehuʻi faʻa eke',
 'mainpage'             => 'Peesi tali fiefia',
 'mainpage-description' => 'Peesi tali fiefia',
 'portal'               => 'Fale fakataha',
@@ -229,8 +229,6 @@ $messages = array(
 # General errors
 'error'                => 'Halaʻi',
 'databaseerror'        => 'Halaʻi tānekingaʻilo',
-'nodb'                 => 'Naʻe ʻikai lava fili ʻa e tānekingaʻilo $1',
-'cachederror'          => 'ʻOku ʻasi ʻi lalo ʻa e fafaʻo ʻo e peesi naʻa ke kole, pea mahalo pē ʻoku ʻikai fakaonopooni.',
 'laggedslavemode'      => 'Tokanga: Mahalo pē ʻoku ʻikai ha toki fakafoʻou ʻi loto peesi.',
 'readonly'             => 'ʻOku lokaʻi ʻa e tānekingaʻilo',
 'readonlytext'         => 'ʻOku lokaʻi ʻa e tānekingaʻilo he taimí ni (ʻoku ikai te ke lava fatu) maʻa e monomono fakatānekingaʻilo tuʻumaʻu. ʻOsi ia ʻe foki ia ki hono faʻafai.
@@ -260,7 +258,6 @@ Eke: $2",
 'namespaceprotected'   => "ʻOku ʻikai ngofua ke ke fatu ʻa e ngaahi kupu ʻi he vā hingoa '''$1'''.",
 
 # Login and logout pages
-'logouttitle'                => 'ʻAlu mamaʻo ʻo e ʻetita',
 'logouttext'                 => "'''Kuo ʻalu mamaʻo koe he taimí ni.'''
 
 E lava te ke hoko atu ʻo ngāueʻaki he {{SITENAME}} tatau mo e ʻetita taʻehingoa, pe te ke kau-ki-ai mo e hingoa tatau pe hingoa kehe.
@@ -268,11 +265,10 @@ Tokanga, mahalo pē ʻe ʻi ai ha ngaahi peesi ʻoku ʻasi ko koe kei kau-ki-ai
 'welcomecreation'            => '== Tali fiefia, $1! ==
 
 Kuo fakatupu hoʻo tohi kau-ki-ai. ʻOua ʻe ngalo ke liliu hoʻo faʻiteliha {{SITENAME}}.',
-'loginpagetitle'             => 'Kau-ki-ai ʻo e ʻetita',
 'yourname'                   => 'Hingoa ʻetita',
 'yourpassword'               => 'Leatapu',
 'yourpasswordagain'          => 'Toe ʻai leatapu',
-'remembermypassword'         => 'Manatuʻi au',
+'remembermypassword'         => 'Manatuʻi au (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => 'ho ngāueʻanga',
 'login'                      => 'Kau ki ai',
 'nav-login-createaccount'    => 'Kau ki ai',
@@ -288,24 +284,14 @@ Kuo fakatupu hoʻo tohi kau-ki-ai. ʻOua ʻe ngalo ke liliu hoʻo faʻiteliha {{
 'gotaccountlink'             => 'Kau ki ai',
 'createaccountmail'          => 'ʻi he tohila',
 'badretype'                  => 'ʻOku kehe hoʻo ongo leatapu.',
-'youremail'                  => 'Tohila:',
-'username'                   => 'Ko e ʻetita hono hingoa:',
-'uid'                        => 'hono fika:',
-'yourrealname'               => 'Hingoa moʻoni:',
-'yourlanguage'               => 'Lea:',
-'yourvariant'                => 'Faikeheʻi',
-'yournick'                   => 'Hingoa tenetene:',
-'badsig'                     => 'Ko e fakamoʻoni ʻota ʻoku taʻeʻaonga; siviʻi ngaahi tikite HTML.',
-'email'                      => 'Tohila',
 'loginerror'                 => 'Halaʻi kau-ki-ai',
-'prefs-help-email'           => 'Tohila (tohi-ʻuhila, e-mail) fakafaʻiteliha: ʻE fakamafeiaʻi ʻa e kau ʻetita ʻo lave kia te koe, ngāueʻaki hoʻo peesi pe peesi-alea, taʻe ʻi ai haʻanau ʻilo pe ko hai koe.',
 'nocookiesnew'               => 'Kuo fakatupu hoʻo tohi-kau-ki-ai, kae teʻeki ke kau-ki-ai. ʻOku ngāueʻaki mo e foʻi keke ʻe he {{SITENAME}} ʻi he kau-ki-ai ʻo e kau ʻetita. Naʻa ke fakataʻeʻaongaki ʻa e ngaahi foʻi keke. ʻE fakamafeia kinautolu pea te ke kau-ki-ai mo ho hingoa tenetene foʻou mo hono tapulea.',
 'nocookieslogin'             => 'ʻOku ngāueʻaki mo e foʻi keke ʻe he {{SITENAME}} ʻi he kau-ki-ai ʻo e kau ʻetita. Naʻa ke fakataʻeʻaongaki ʻa e ngaahi foʻi keke. ʻE fakamafeia kinautolu pea te ke toe feinga.',
 'noname'                     => 'Naʻe ʻikai te ke ʻoatu hao hingoa ʻetita ʻoku totonu.',
 'loginsuccesstitle'          => 'Kuo ola ʻa e kau-ki-ai',
 'loginsuccess'               => "'''ʻOku ke kau-ki-ai he taimí ni ki he {{SITENAME}} hangē \"\$1\".'''",
 'nosuchuser'                 => 'ʻOku ʻikai ʻi ai ha ʻetita mo hono hingoa "$1". Sivi hoʻo sipela pe [[Special:UserLogin/signup|fakatupu haʻo kau-ki-ai foʻou]].',
-'nosuchusershort'            => 'ʻOku ʻikai ʻi ai ha ʻetita mo hono hingoa "<nowiki>$1</nowiki>". Sivi hoʻo sipela.',
+'nosuchusershort'            => 'ʻOku ʻikai ʻi ai ha ʻetita mo hono hingoa "$1". Sivi hoʻo sipela.',
 'nouserspecified'            => 'ʻOku pau te ke ʻoatu ha hingoa ʻo e ʻetita.',
 'wrongpassword'              => 'ʻOku ʻikai totonu ʻa e leatapu, kātaki ʻe toki feinga.',
 'wrongpasswordempty'         => 'Naʻe maha ʻa e tapulea, kātaki ʻe toki feinga.',
@@ -329,7 +315,7 @@ Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatap
 'accountcreatedtext'         => 'Kuo fakatupu ʻa e tohi kau-ki-ai maʻa $1.',
 'loginlanguagelabel'         => 'Lea: $1',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => 'Ko e leatapu motuʻa:',
 'newpassword' => 'Ko e leatapu foʻou:',
 'retypenew'   => 'Toe ʻai leatapu foʻou:',
@@ -345,7 +331,6 @@ Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatap
 'extlink_tip'     => 'Fehokotaki ki tuʻa (manatuʻi ko e fakapipikimuʻa — http://)',
 'headline_sample' => 'Mataʻitohi tuʻumuʻa',
 'headline_tip'    => 'Tuʻumuʻa fakatuʻunga hono 2',
-'math_tip'        => "Kupuʻilea fakamatematika ''(LaTex)''",
 'nowiki_sample'   => 'Hulumaki ʻa e ʻū mataʻitohi taʻengaohi ʻi heni',
 'nowiki_tip'      => "taʻetokaʻi ngaohi ''wiki''",
 'sig_tip'         => 'Ko e fakamoʻoniʻi ʻaʻau mo hono taimi',
@@ -368,7 +353,6 @@ Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatap
 'blockededitsource'       => "ʻOku ʻasi ʻi lalo ʻa e tohi ʻo '''hoʻo ngaahi fatu''' ki he '''$1''':",
 'whitelistedittitle'      => 'ʻOku pau ke kau ki ai ke fatuʻi',
 'whitelistedittext'       => 'ʻOku pau te ke $1 kapau te ke fiefatu ʻa e ngaahi kupu.',
-'confirmedittitle'        => 'ʻOku pau ʻe fakaʻmoʻoniʻi hoʻo tohila kapau te ke fieʻetita',
 'confirmedittext'         => 'ʻOku pau te ke fakamoʻoniʻi ho tuʻasila tohila ʻi muʻa hoʻo fatu kupu. Kātaki ʻe fakamoʻoniʻi ia ngāueʻaki hoʻo [[Special:Preferences|faʻiteliha]] fakaʻetita.',
 'loginreqtitle'           => 'ʻOku pau te ke kau ki ai',
 'loginreqlink'            => 'kau ki ai',
@@ -392,7 +376,7 @@ Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatap
 Ko e konga ʻi olunga, ko e kupu ia he onopooni.
 Ko e konga ʻi lalo, ko hoʻo ngaahi liliu ia.
 ʻE pau te ke fakataha hoʻo liliu ʻi loto ʻo e kupu ʻoku tuʻu.
-Ko e konga ʻi olunga, ko e '''konga pē ʻe taha''' ʻe haofaki ʻi he lomiʻi ʻo e meʻalolomi \"haofaki e pēsí\".",
+Ko e konga ʻi olunga, ko e '''konga pē ʻe taha''' ʻe haofaki ʻi he lomiʻi ʻo e meʻalolomi \"{{int:savearticle}}\".",
 'yourtext'                => 'tohi ʻaʻau',
 'storedversion'           => 'Ko e paaki kuo tuku',
 'editingold'              => "'''FAKATOKANGA: ʻOku ke fatu ʻi he paaki fakaonoʻaho ʻo e pēsi. Kapau te ke haofaki ia, ʻe mole ʻa e ngaahi liliu kotoa talu mei ai.'''",
@@ -418,7 +402,7 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'nohistory'           => 'ʻOku ʻikai ʻi ai ha hisitōlia fatu maʻa e kupú ni.',
 'currentrev'          => 'Paaki taka',
 'revisionasof'        => 'Paaki he ko $1',
-'revision-info'       => 'Paaki he ko $1 fai ʻe $2', # Additionally available: $3: revision id
+'revision-info'       => 'Paaki he ko $1 fai ʻe $2',
 'previousrevision'    => '←Paaki motuʻa ange',
 'nextrevision'        => 'Paaki foʻou ange→',
 'currentrevisionlink' => 'Paaki taka',
@@ -427,7 +411,6 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'last'                => 'fakamuimui',
 'histlegend'          => 'Konga faikehekehe: fakaʻilongaʻi ʻa e ngaahi puha fakaletio ʻo e ngaahi paaki ʻo fakatatau pea lomiʻi.<br />
 ʻAtungatala: (taka) = ngaahi lilu mo e paaki taka, (mui) = ngaahi liliu mo paaki naʻe fetongi, s = fatu siʻi.',
-'deletedrev'          => '[kuo tāmateʻi]',
 'histfirst'           => 'Fakamuʻa taha',
 'histlast'            => 'Fakamuimui taha',
 
@@ -454,10 +437,9 @@ Ko e ʻuhinga loka ko e $1 ia.",
 # Search results
 'searchresults'             => 'kumi hono ʻātunga',
 'searchresults-title'       => 'kumi "$1" hono ʻātunga',
-'noexactmatch'              => "'''ʻOku ʻikai ʻi ai ha kupu mo hono ʻuluʻitohi \"\$1\".''' ʻOku lava ke ke [[:\$1|fakatupu he kupú ni]].",
-'prevn'                     => '$1 ki muʻa',
-'nextn'                     => '$1 hoko',
-'viewprevnext'              => 'Vakai ki he ($1) ($2) ($3).',
+'prevn'                     => '{{PLURAL:$1|$1}} ki muʻa',
+'nextn'                     => '{{PLURAL:$1|$1}} hoko',
+'viewprevnext'              => 'Vakai ki he ($1 {{int:pipe-separator}} $2) ($3).',
 'search-suggest'            => 'Mahalo pē naʻa ke fiemaʻu: $1',
 'search-interwiki-more'     => '(lahi ange)',
 'search-mwsuggest-enabled'  => 'mo e fokotuʻu atu',
@@ -474,15 +456,10 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'mypreferences'         => 'faʻiteliha ʻaʻaku',
 'prefsnologin'          => 'ʻOku ʻikai kau ki ai',
 'changepassword'        => 'Liliu hoʻo leatapu',
-'skin'                  => 'Kili',
+'prefs-skin'            => 'Kili',
 'skin-preview'          => 'Vakai pē',
-'math'                  => 'Matematika',
-'dateformat'            => 'Ngaohi ʻo e ʻaho',
 'datedefault'           => 'ʻIkai ha faʻiteliha',
-'datetime'              => 'ʻAho mo e taimi',
-'math_unknown_error'    => 'hala taʻeʻiloa',
-'math_unknown_function' => 'lakanga taʻeʻiloa',
-'math_bad_output'       => 'ʻOku ʻikai lava ʻo tohi pe fakatupu ʻa e takafi maʻa e fua matematika',
+'prefs-datetime'        => 'ʻAho mo e taimi',
 'prefs-personal'        => 'Fōtunga fakatafaʻaki',
 'prefs-rc'              => 'Ngaahi toki liliu',
 'prefs-watchlist'       => 'Hokohoko leʻo',
@@ -491,14 +468,13 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'prefs-misc'            => 'Kehekehe',
 'saveprefs'             => 'Haofaki',
 'resetprefs'            => 'Fakafoki',
-'textboxsize'           => 'ʻOku fatu',
+'prefs-editing'         => 'ʻOku fatu',
 'rows'                  => 'Ngaahi ʻotu:',
 'columns'               => 'Vahaʻa laini:',
 'searchresultshead'     => 'Kumi',
 'recentchangescount'    => 'Ngaahi ʻuluʻitohi ʻoku ʻasi ʻi he toki liliu, hisitōlia peesi, mo e hokohoko:',
 'savedprefs'            => 'Kuo haofaki hoʻo faʻiteliha.',
 'timezonelegend'        => 'Feituʻu taimi',
-'timezonetext'          => 'Ko e lahi ʻo e ngaahi houa ʻoku faikehekehe hoʻo taimi fakakolo mei he taimi māmani.',
 'localtime'             => 'Taimi fakafeituʻu:',
 'timezoneoffset'        => 'Ngaahi houa ʻo e faikehekehe:',
 'servertime'            => 'Taimi ʻo e tauhia:',
@@ -506,7 +482,17 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'allowemail'            => 'Fakamafeiaʻi ʻa e tohila mei he kau ʻetita ʻe taha',
 'defaultns'             => 'Kumi ʻi he vā hingoa fakatuʻunga:',
 'default'               => 'tuʻunga',
-'files'                 => 'Ngaahi faile',
+'prefs-files'           => 'Ngaahi faile',
+'youremail'             => 'Tohila:',
+'username'              => 'Ko e ʻetita hono hingoa:',
+'uid'                   => 'hono fika:',
+'yourrealname'          => 'Hingoa moʻoni:',
+'yourlanguage'          => 'Lea:',
+'yourvariant'           => 'Faikeheʻi',
+'yournick'              => 'Hingoa tenetene:',
+'badsig'                => 'Ko e fakamoʻoni ʻota ʻoku taʻeʻaonga; siviʻi ngaahi tikite HTML.',
+'email'                 => 'Tohila',
+'prefs-help-email'      => 'Tohila (tohi-ʻuhila, e-mail) fakafaʻiteliha: ʻE fakamafeiaʻi ʻa e kau ʻetita ʻo lave kia te koe, ngāueʻaki hoʻo peesi pe peesi-alea, taʻe ʻi ai haʻanau ʻilo pe ko hai koe.',
 
 # Groups
 'group'            => 'Pupunga:',
@@ -549,12 +535,13 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'rc-enhanced-hide'   => 'Toi ngaahi ʻeu',
 
 # Recent changes linked
-'recentchangeslinked' => 'Ngaahi liliu fekauʻaki',
+'recentchangeslinked'         => 'Ngaahi liliu fekauʻaki',
+'recentchangeslinked-feed'    => 'Ngaahi liliu fekauʻaki',
+'recentchangeslinked-toolbox' => 'Ngaahi liliu fekauʻaki',
 
 # Upload
 'upload'                      => 'Hiki hake ʻa e faile',
 'uploadbtn'                   => 'Hiki hake',
-'reupload'                    => 'Toe hiki hake',
 'reuploaddesc'                => 'Foki ki he foomu hiki',
 'uploadnologin'               => 'Teʻeki kau ki ai',
 'uploadnologintext'           => 'ʻOku pau ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fiehiki hake ha faile.',
@@ -577,21 +564,21 @@ Ko e ʻuhinga loka ko e $1 ia.",
 [[$1|thumb]]",
 'fileexists-forbidden'        => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē, pea ʻe ʻikai lava liliu; fakamolemole ʻe foki pea hiki hake ʻa e failé ni mo e ha hingoa foʻou. [[File:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē ʻi he kalasi vahevahe; fakamolemole ʻe foki pea hiki hake ʻa e failé ni mo e ha hingoa foʻou. [[File:$1|thumb|center|$1]]',
-'successfulupload'            => 'Kuo ola ʻa e hiki hake',
 'uploadwarning'               => 'Tokanga hiki hake',
 'savefile'                    => 'Haofaki faitaá ni',
 'uploadedimage'               => '"[[$1]]" ʻosi hiki hake',
 'uploaddisabled'              => 'ʻOku fakataʻeʻaongaʻi ʻa e ngaahi hiki hake',
 'uploaddisabledtext'          => 'ʻOku fakataʻeʻaongaʻi ha ngaahi hiki hake ʻi heni.',
-'uploadcorrupt'               => 'ʻOku kovi ʻa e failé ni pe ʻoku halaʻi hono fakalōloa. Kātaki, sivi ia pea foki hiki hake ia.',
 'uploadvirus'                 => 'ʻOku ʻi ai ha vailasi ʻi he failé ni! ʻŪ kiʻi meʻa: $1',
 'sourcefilename'              => 'Hingoa ʻo e faile tupunga:',
 'destfilename'                => 'Hingoa ʻo e faile ʻe ʻalu ki ai:',
 'watchthisupload'             => 'Leʻo he pēsí ni',
 'filewasdeleted'              => 'Kuo hiki hake ʻa e faile mo e hingoa ʻeni pea naʻe tāmateʻi ia. Kuo pau te ke vakai ki he $1 ʻi muʻa haʻo feinga ʻo toe hiki hake ia.',
+'upload-success-subj'         => 'Kuo ola ʻa e hiki hake',
 
-'license'   => 'Laiseni:',
-'nolicense' => 'ʻIkai fili ha taha',
+'license'        => 'Laiseni:',
+'license-header' => 'Laiseni:',
+'nolicense'      => 'ʻIkai fili ha taha',
 
 # Special:ListFiles
 'listfiles_search_for'  => 'Kumi ki he hingoa ʻo e faitā:',
@@ -604,15 +591,12 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'listfiles_description' => 'Fakamahino',
 
 # File description page
+'file-anchor-link'          => 'Faitā',
 'filehist-datetime'         => 'ʻAho/Taimi',
 'filehist-user'             => 'Ko e ʻetita',
 'imagelinks'                => 'Ngaahi fehokotaki',
 'linkstoimage'              => 'ʻOku fehokotaki ʻa e peesi ʻe $1 ki he failé ni:',
 'nolinkstoimage'            => 'ʻOku ʻikai ha ngaahi peesi fehokotaki ki he faitaá ni.',
-'shareduploadwiki'          => 'Kātaki, vakai ki he $1 mo hano ongoongo lahi ange.',
-'shareduploadwiki-linktext' => 'Peesi ʻo e faile hono fakamahino',
-'noimage'                   => 'ʻOku ʻikai ʻi ai ha faile mo e hingoa koʻeni, ʻe fakatupu koe $1.',
-'noimage-linktext'          => 'hiki hake ʻe taha',
 'uploadnewversion-linktext' => 'Hiki hake ʻa e paaki foʻou ʻo e failé ni.',
 
 # File reversion
@@ -736,7 +720,9 @@ Ko e ʻuhinga loka ko e $1 ia.",
 
 # Special:Categories
 'categories'         => 'Faʻahinga',
-'categoriespagetext' => 'ʻOku ʻi ai ha ngaahi faʻahinga pehē.',
+'categoriespagetext' => 'ʻOku ʻi ai ha ngaahi faʻahinga pehē.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # Special:DeletedContributions
 'deletedcontributions'       => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',
@@ -776,16 +762,13 @@ Ko e ʻuhinga loka ko e $1 ia.",
 # Watchlist
 'watchlist'            => 'Hokohoko leʻo ʻaʻaku',
 'mywatchlist'          => 'Hokohoko leʻo ʻaʻaku',
-'watchlistfor'         => "(maʻa e '''$1''')",
 'nowatchlist'          => 'ʻOku ʻikai ha meʻa ʻi hoʻo hokohoko leʻo.',
 'watchlistanontext'    => 'Kātaki, ʻe $1 kapau te ke fievakai pe fiefatu ha ngaahi meʻa ʻi hoʻo hokohoko leʻo.',
 'watchnologin'         => 'Teʻeki kau ki ai',
 'watchnologintext'     => 'ʻOku pau te ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fieliliu hoʻo hokohoko leʻo.',
-'addedwatch'           => 'Kuo tānaki ki hoʻo hokohoko leʻo',
 'addedwatchtext'       => 'Ko e peesi "[[:$1]]" naʻe tānaki ia ki hoʻo [[Special:Watchlist|hokohoko leʻo]]. Ko e ngaahi liliu ʻo e kahaʻu ʻi he pēsí ni mo hono peesi aleá, ʻe ʻoatu ʻi heni mo ʻasi mai  ʻi he hokohoko ʻo e [[Special:RecentChanges|ngaahi toki liliu]], ʻoku sinolahi ke fanāfotu.
 
 Kapau ʻaho ʻe taha, te ke fietoʻo ʻa e pēsí mei hoʻo hokohoko leʻo, lomiʻi "taʻeleʻo" ʻi he pā tafaʻaki.',
-'removedwatch'         => 'Kuo toʻo mei he hokohoko leʻo',
 'removedwatchtext'     => 'Kuo toʻo ʻa e peesi "[[:$1]]" mei hoʻo hokohoko leʻo.',
 'watch'                => 'Leʻo',
 'watchthispage'        => 'Leʻo he pēsí ni',
@@ -820,7 +803,7 @@ Kapau ʻaho ʻe taha, te ke fietoʻo ʻa e pēsí mei hoʻo hokohoko leʻo, lomi
 'historywarning'    => 'Tokanga: ko e peesi te ke fietāmateʻi, ʻoku ʻi ai haʻane histolia.',
 'confirmdeletetext' => 'Te ke tāmateʻi, ʻikai ala fūlihi, ʻa e peesi pe faitā mo hono hisitōlia kātoa mei he tānekingaʻilo. Kātaki fakamoʻoniʻi ʻoku sai ia, ʻoku ke ʻilo ʻa e fua, pea ʻoku ke fai pehē ototaha ia mo e [[{{MediaWiki:Policy-url}}]].',
 'actioncomplete'    => 'ʻOsi ngāue',
-'deletedtext'       => 'Kuo tāmateʻi "<nowiki>$1</nowiki>"
+'deletedtext'       => 'Kuo tāmateʻi "$1"
 Vakai ki he $2 maʻa e fakamatala ʻo e ngaahi toki tāmateʻi.',
 'deletedarticle'    => 'ʻosi tamateʻi "[[$1]]"',
 'dellogpage'        => 'Tohinoa ʻo e tāmateʻi',
@@ -838,7 +821,7 @@ Vakai ki he $2 maʻa e fakamatala ʻo e ngaahi toki tāmateʻi.',
 'alreadyrolled'  => 'ʻOku ʻikai lava teka hifo ʻa e fatu fakamuimui ʻo e [[:$1]] ʻe [[User:$2|$2]] ([[User talk:$2|Alea]]); ko e tokotaha ʻe taha naʻe fatu pe fatu teka hifo ʻa e peesi.
 
 Ko e fatu fakamuimui naʻe fatu ʻe [[User:$3|$3]] ([[User talk:$3|Alea]]).',
-'editcomment'    => "Ko e fakamatala fatu naʻe \"''\$1''\" ia.", # only shown if there is an edit comment
+'editcomment'    => "Ko e fakamatala fatu naʻe \"''\$1''\" ia.",
 
 # Protect
 'protectlogpage'      => 'Tohinoa ʻo e maluʻi',
@@ -882,6 +865,9 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'mycontris'     => 'Foaki ʻaʻaku',
 'uctop'         => ' (ʻi ʻolunga)',
 
+'sp-contributions-deleted' => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',
+'sp-contributions-talk'    => 'Alea',
+
 # What links here
 'whatlinkshere'       => 'Ngaahi fehokotaki ki heni',
 'linkshere'           => 'ʻOku fehokotaki ki heni ʻa e ngaahi peesi:',
@@ -893,11 +879,9 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 # Block/unblock
 'blockip'              => 'Taʻofia ʻa e ʻetita',
 'blockiptext'          => 'Ngāueʻaki ʻa e foomu ʻi lalo ʻe taʻofia ʻa e ngofua tohi ʻo e tuʻasila IP pe hingoa ʻetita ʻe taha. ʻOku pau ʻe fai pehē ʻi he taʻofi laukovi pē, lototaha ia mo e [[{{MediaWiki:Policy-url}}|founga]]. Fakafonu ʻi lalo ʻa e ʻuhinga totonu (fakafuaʻaki, lau ki he ngaahi peesi naʻe laukovi).',
-'ipaddress'            => 'Tuʻasila IP',
 'ipadressorusername'   => 'Tuʻasila IP pe hingoa ʻo e ʻetita',
 'ipbexpiry'            => 'Mate',
 'ipbreason'            => 'ʻUhinga',
-'ipbanononly'          => 'Taʻofia ʻa e kau ʻetita taʻehingoa pē',
 'ipbcreateaccount'     => 'Taʻofia ʻa e fakatupu ʻo ha tohi kau-ki-ai',
 'ipbsubmit'            => 'Taʻofia ʻa e ʻetitá ni',
 'ipbother'             => 'Fuoloa kehe',
@@ -911,9 +895,8 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'ipusubmit'            => 'Taʻetaʻofia ʻa e ʻetitá ni',
 'unblocked'            => 'Kuo taʻetaʻofia ʻa [[User:$1|$1]]',
 'ipblocklist'          => 'Hokohoko ʻo e ngaahi tuʻasila IP mo e hingoa ʻo e ʻetita kuo taʻofi',
-'blocklistline'        => '$1, $2 taʻofi $3 ($4)',
 'infiniteblock'        => 'taʻengata',
-'expiringblock'        => 'ʻE mate ia $1',
+'expiringblock'        => 'ʻE mate ia $1 $2',
 'anononlyblock'        => 'taʻehingoa pē',
 'createaccountblock'   => 'ʻOku taʻofia ʻa e fakatupu ʻa e tohi-kau-ki-ai',
 'blocklink'            => 'taʻofi',
@@ -922,7 +905,7 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'autoblocker'          => 'ʻOku taʻofi ʻiate ia pe, koeʻuhi ko hoʻo tuaʻasila IP naʻe ngāueʻaki ia ʻe he ʻetita "[[User:$1|$1]]". Ko e ʻuhinga maʻa e taʻofi ʻo $1 ko "\'\'\'$2\'\'\'" ia.',
 'blocklogpage'         => 'Tohinoa ʻo e taʻofi',
 'blocklogentry'        => 'taʻofia [[$1]] mo ha fuoloa $2 $3',
-'blocklogtext'         => 'Ko e tohinoa ʻeni ʻo e ngāue ʻo e ngaahi taʻofi mo e taʻetaʻofi ʻo e kau ʻetita. ʻOku ʻikai ʻasi ha ngaahi tuʻasila IP ʻoku taʻofi ngaue ʻia te ia pē. Vakai ki he [[Special:IPBlockList|hokohoko taʻofi IP]] kapau te ke fiemaʻu ʻa e hokohoko ʻo e ngaahi taʻofi taka kotoa.',
+'blocklogtext'         => 'Ko e tohinoa ʻeni ʻo e ngāue ʻo e ngaahi taʻofi mo e taʻetaʻofi ʻo e kau ʻetita. ʻOku ʻikai ʻasi ha ngaahi tuʻasila IP ʻoku taʻofi ngaue ʻia te ia pē. Vakai ki he [[Special:BlockList|hokohoko taʻofi IP]] kapau te ke fiemaʻu ʻa e hokohoko ʻo e ngaahi taʻofi taka kotoa.',
 'unblocklogentry'      => 'taʻetaʻofia $1',
 'range_block_disabled' => 'ʻOku fakataʻeʻaongaʻi ʻa e fakatupu fakapule-fakafounga ʻo ngaahi taʻofi fakavā.',
 'ipb_expiry_invalid'   => 'ʻOku taʻeʻaongaʻi ʻa e taimi ki he mate.',
@@ -997,8 +980,6 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'allmessagescurrent'        => 'Tohi lolotonga',
 'allmessagestext'           => "Ko e hokohoko ʻeni ʻo e ngaahi tala fakafounga kātoa ʻi he vā hingoa ''MediaWiki''.",
 'allmessagesnotsupportedDB' => "ʻOku ʻikai ngāueʻaki mo e '''{{ns:special}}:Allmessages''' koeʻuhi ʻoku kamosiʻi mate ʻa e '''\$wgUseDatabaseMessages'''.",
-'allmessagesfilter'         => 'Meʻasivi ki he hingoa ʻo e tala:',
-'allmessagesmodified'       => 'ʻAsi mai meʻa kuo liliu pē',
 
 # Thumbnails
 'filemissing' => 'ʻOku pulia ʻa e faile',
@@ -1051,17 +1032,6 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 # Spam protection
 'spamprotectionmatch' => 'Naʻe kamosi ʻemau meʻasivi tohila ʻe he ngaahi mataʻitohi koʻeni: $1',
 
-# Info page
-'infosubtitle' => 'Fakamatala ki he peesi',
-
-# Math options
-'mw_math_png'    => 'Fai PNG taimi kotoa',
-'mw_math_simple' => 'Fai HTML kapau faingofua ʻaupito, pe toe PNG',
-'mw_math_html'   => 'Fai HTML kapau malava, pe toe PNG',
-'mw_math_source' => "Fakatoe ʻi he ''TeX'' maʻa e ngaahi palausa tohi pē",
-'mw_math_modern' => 'ʻOku fakahinohino maʻa e palausa fakaonopooni.',
-'mw_math_mathml' => 'Fai MathML kapau malava (fakatotolo)',
-
 # Patrolling
 'rcpatroldisabled' => 'ʻOku fakataʻeʻaʻongaʻi ʻa e leʻo ʻo e ngaahi toki liliu',
 
@@ -1073,11 +1043,10 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 'nextdiff'     => 'Faikehe hoko →',
 
 # Media information
-'imagemaxsize'         => 'Fakangatangata ngaahi faitā ʻi he ʻū peesi fakamahino ki he:',
-'file-info'            => 'Ko e faile hono lahi: $1, faʻahinga MIME: $2',
-'file-nohires'         => '<small>ʻOku ʻikai ʻi ai ha faitā auiiki.</small>',
-'show-big-image'       => 'ʻAsi ʻa e faitā auiiki',
-'show-big-image-thumb' => '<small>Vakai pē ʻi hono lahi: $1 x $2 tefitoʻifaitā</small>',
+'imagemaxsize'   => 'Fakangatangata ngaahi faitā ʻi he ʻū peesi fakamahino ki he:',
+'file-info'      => 'Ko e faile hono lahi: $1, faʻahinga MIME: $2',
+'file-nohires'   => '<small>ʻOku ʻikai ʻi ai ha faitā auiiki.</small>',
+'show-big-image' => 'ʻAsi ʻa e faitā auiiki',
 
 # Special:NewFiles
 'newimages'             => 'Fakaʻaliʻali ʻo e ngaahi faitā foʻou',
@@ -1095,11 +1064,9 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 # EXIF tags
 'exif-xresolution'                 => 'Auiiki fakalava',
 'exif-yresolution'                 => 'Auiiki tuʻutonu',
-'exif-resolutionunit'              => 'ʻUniti auiiki ʻo e X mo e Y',
 'exif-jpeginterchangeformatlength' => 'ʻŪ valu meʻaʻilo JPEG',
 'exif-make'                        => 'Ko e tokotaha faʻu ʻo e meʻafaitā',
 'exif-artist'                      => 'Tokotaha faitā',
-'exif-makernote'                   => 'Tohi nounou ʻo e tokotaha faʻu',
 'exif-usercomment'                 => 'Fakamatala ʻo e ʻetita',
 'exif-brightnessvalue'             => 'Ngingila',
 'exif-lightsource'                 => 'Malama',
@@ -1192,7 +1159,7 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 'exif-gpslongitude-e' => 'Longitute hahake',
 'exif-gpslongitude-w' => 'Longitute hihifo',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-k' => 'Kilomita ki he houa',
 'exif-gpsspeed-m' => 'Maile he houa',
 
@@ -1202,13 +1169,11 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 
 # External editor support
 'edit-externally'      => 'Fatuʻi ʻa e failé ni ngāueʻaki mo e polokalama ʻi tuʻa',
-'edit-externally-help' => 'Vakai ki he [http://www.mediawiki.org/wiki/Manual:External_editors fakahinohino ki he fokotuʻu] maʻa toe fakamatala.',
+'edit-externally-help' => 'Vakai ki he [//www.mediawiki.org/wiki/Manual:External_editors fakahinohino ki he fokotuʻu] maʻa toe fakamatala.',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'kotoa',
-'imagelistall'     => 'kotoa',
-'watchlistall2'    => 'kātoa',
-'namespacesall'    => 'vā kotoa',
+'watchlistall2' => 'kātoa',
+'namespacesall' => 'vā kotoa',
 
 # E-mail address confirmation
 'confirmemail'            => 'Fakamoʻoniʻi ho tuʻasila tohila',
@@ -1272,7 +1237,7 @@ Kātaki fakapapauʻi te ke fie toe fatu ʻa e kupu ni.",
 'watchlisttools-raw'  => 'Fatu ʻa e hokohoko leʻo taʻengaohi',
 
 # Special:Version
-'version' => 'Paaki', # Not used as normal message but as header for the special page itself
+'version' => 'Paaki',
 
 # Special:FilePath
 'filepath'        => 'Hala ki he faile',
