@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Andrijko Z.
  * @author Krice from Tyvanet.com
  * @author Sborsody
  * @author friends at tyvawiki.org
@@ -14,26 +15,34 @@
  */
 
 $namespaceNames = array(
-	NS_MEDIA            => 'Медиа', //Media
-	NS_SPECIAL          => 'Тускай', //Special
-	NS_MAIN	            => '',
-	NS_TALK	            => 'Чугаа', //Talk
-	NS_USER             => 'Aжыглакчы', //User
-	NS_USER_TALK        => 'Aжыглакчы_чугаа', //User_talk
-	# NS_PROJECT set by $wgMetaNamespace
-	NS_PROJECT_TALK     => '$1_чугаа', //_talk
-	NS_FILE             => 'Чурук', //Image
-	NS_FILE_TALK        => 'Чурук_чугаа', //Image_talk
-	NS_MEDIAWIKI        => 'МедиаВики', //MediaWiki
-	NS_MEDIAWIKI_TALK   => 'МедиаВики_чугаа', //MediaWiki_talk
-	NS_TEMPLATE         => 'Хээ', //Template
-	NS_TEMPLATE_TALK    => 'Хээ_чугаа', //Template_talk
-	NS_HELP             => 'Дуза', //Help
-	NS_HELP_TALK        => 'Дуза_чугаа', //Help_talk
-	NS_CATEGORY         => 'Бөлүк', //Category
-	NS_CATEGORY_TALK    => 'Бөлүк_чугаа', //Category_talk
+	NS_MEDIA            => 'Медиа',
+	NS_SPECIAL          => 'Тускай',
+	NS_TALK             => 'Чугаа',
+	NS_USER             => 'Aжыглакчы',
+	NS_USER_TALK        => 'Aжыглакчы_чугаазу',
+	NS_PROJECT_TALK     => '$1_чугаазу',
+	NS_FILE             => 'Файл',
+	NS_FILE_TALK        => 'Файл_чугаазу',
+	NS_MEDIAWIKI        => 'МедиаВики',
+	NS_MEDIAWIKI_TALK   => 'МедиаВики_чугаазу',
+	NS_TEMPLATE         => 'Хээ',
+	NS_TEMPLATE_TALK    => 'Хээ_чугаазу',
+	NS_HELP             => 'Дуза',
+	NS_HELP_TALK        => 'Дуза_чугаазу',
+	NS_CATEGORY         => 'Бөлүк',
+	NS_CATEGORY_TALK    => 'Бөлүк_чугаазу',
 );
 
+$namespaceAliases = array(
+	'Aжыглакчы_чугаа' => NS_USER_TALK,
+	'$1_чугаа'        => NS_PROJECT_TALK,
+	'Чурук'           => NS_FILE,
+	'Чурук_чугаа'     => NS_FILE_TALK,
+	'МедиаВики_чугаа' => NS_MEDIAWIKI_TALK,
+	'Хээ_чугаа'       => NS_TEMPLATE_TALK,
+	'Дуза_чугаа'      => NS_HELP_TALK,
+	'Бөлүк_чугаа'     => NS_CATEGORY_TALK,
+);
 
 $bookstoreList = array(
 	'ОЗОН' => 'http://www.ozon.ru/?context=advsearch_book&isbn=$1',
@@ -49,11 +58,14 @@ $fallback8bitEncoding = "windows-1251";
 
 $messages = array(
 # User preference toggles
-'tog-highlightbroken'  => '<a href="" class="new">Бо ышкаш</a> бузук холбааларны форматтап ирги.  (азы: бо ышкаш<a href="" class="internal">?</a>).',
-'tog-hideminor'        => 'Сөөлгү өскерлиишкиннер арында бичии өскерлиишкиннерни чажырар',
-'tog-showtoolbar'      => 'Өскертир херекселдерни көргүзер (JavaScript)',
-'tog-editondblclick'   => 'Арынны өскертирде ийи катап базар (JavaScript)',
-'tog-rememberpassword' => 'Мени сактып алыр',
+'tog-highlightbroken'    => '<a href="" class="new">Бо ышкаш</a> бузук холбааларны форматтап ирги.  (азы: бо ышкаш<a href="" class="internal">?</a>).',
+'tog-hideminor'          => 'Сөөлгү өскерлиишкиннер арында бичии өскерлиишкиннерни чажырар',
+'tog-showtoolbar'        => 'Өскертир херекселдерни көргүзер (JavaScript)',
+'tog-editondblclick'     => 'Арынны өскертирде ийи катап базар (JavaScript)',
+'tog-rememberpassword'   => 'Remember my login on this computer (for a maximum of $1 {{PLURAL:$1|day|days}})',
+'tog-watchlisthideown'   => 'Хайгаарылга даңзызындан мээң өскерлиишкиннерымны чажырары',
+'tog-watchlisthidebots'  => 'Хайгаарылга даңзызындан роботтарның өскерлиишкиннерын чажырары',
+'tog-watchlisthideminor' => 'Хайгаарылга даңзызындан бичии өскерлиишкиннерны чажырары',
 
 'underline-always'  => 'Кезээде',
 'underline-never'   => 'Кажан-даа',
@@ -105,34 +117,46 @@ $messages = array(
 'dec'           => '12.ай',
 
 # Categories related messages
-'pagecategories'           => '{{PLURAL:$1|Бөлүк|Бөлүктер}}',
-'category_header'          => '"$1" деп бөлүкте арыннар',
-'subcategories'            => 'Бичии бөлүктер',
-'category-media-header'    => '"$1" деп бөлүкте медиа',
-'category-empty'           => "''Амгы бо бөлүкте медиа база арыннар чок.''",
-'hidden-categories'        => '{{PLURAL:$1|Чажыт бөлүк|Чажыт бөлүктер}}',
-'hidden-category-category' => 'Чажыт бөлүктер', # Name of the category where hidden categories will be listed
+'pagecategories'                => '{{PLURAL:$1|Бөлүк|Бөлүктер}}',
+'category_header'               => '"$1" деп бөлүкте арыннар',
+'subcategories'                 => 'Бичии бөлүктер',
+'category-media-header'         => '"$1" деп бөлүкте медиа',
+'category-empty'                => "''Амгы бо бөлүкте медиа база арыннар чок.''",
+'hidden-categories'             => '{{PLURAL:$1|Чажыт бөлүк|Чажыт бөлүктер}}',
+'hidden-category-category'      => 'Чажыт бөлүктер',
+'category-subcat-count-limited' => 'Бо бөлүк {{PLURAL:$1|бир|$1}} бичии бөлүктүү.',
+'listingcontinuesabbrev'        => '(уланчы)',
 
-'about'          => 'Дугайында',
-'article'        => 'Допчу арын',
-'newwindow'      => '(чаа көзенээ ажыытынар)',
-'cancel'         => 'Соксаары',
-'qbfind'         => 'Тывары',
+'about'         => 'Дугайында',
+'article'       => 'Допчу арын',
+'newwindow'     => '(чаа көзенээ ажыытынар)',
+'cancel'        => 'Соксаары',
+'moredotdotdot' => 'Артык...',
+'mypage'        => 'Мээң арыным',
+'mytalk'        => 'Мээң чугаам',
+'anontalk'      => 'Бо ИП-адрестиң чугаа',
+'navigation'    => 'Навигация',
+'and'           => '&#32;болгаш',
+
+# Cologne Blue skin
+'qbfind'         => 'Дилээри',
 'qbbrowse'       => 'Каралаары',
 'qbedit'         => 'Өскертир',
 'qbpageoptions'  => 'Бо арын',
 'qbmyoptions'    => 'Мээң арыннарым',
 'qbspecialpages' => 'Тускай арыннар',
-'moredotdotdot'  => 'Ам-даа...',
-'mypage'         => 'Мээң арыным',
-'mytalk'         => 'Мээң чугаалажырым',
-'anontalk'       => 'Бо ИП-адрестиң чугаа',
-'navigation'     => 'Навигация',
-'and'            => '&#32;болгаш',
+
+# Vector skin
+'vector-action-delete'  => 'Ырадыры',
+'vector-action-move'    => 'Шимчээри',
+'vector-action-protect' => 'Камгалаары',
+'vector-view-edit'      => 'Өскертири',
+'vector-view-history'   => 'Төөгүнү көөрү',
+'vector-view-view'      => 'Номчууру',
 
 'errorpagetitle'    => 'Алдаг',
 'returnto'          => '$1 деп арынже эглири.',
-'tagline'           => '{{grammar:ablative|{{SITENAME}}}}',
+'tagline'           => '{{SITENAME}} деп веб-сайттен',
 'help'              => 'Дуза',
 'search'            => 'Дилээри',
 'searchbutton'      => 'Дилээри',
@@ -140,50 +164,52 @@ $messages = array(
 'searcharticle'     => 'Күүcедири',
 'history'           => 'Арынның Төөгүзү',
 'history_short'     => 'Төөгү',
-'info_short'        => 'Медеглел',
 'printableversion'  => 'Саазынга үндүрерин көөрү',
 'permalink'         => 'Үргүлчү холбаа',
 'print'             => 'Саазынга үндүрер',
+'view'              => 'Көөрү',
 'edit'              => 'Өскертири',
-'create'            => 'Кылыры',
+'create'            => 'Чогаадыры',
 'editthispage'      => 'Бо арынны өскертири',
-'create-this-page'  => 'Бо арынны кылыр',
-'delete'            => 'Ап каары',
-'deletethispage'    => 'Бо арынны ап каар',
+'create-this-page'  => 'Бо арынны чогаадыры',
+'delete'            => 'Ырадыры',
+'deletethispage'    => 'Бо арынны ырадыры',
 'protect'           => 'Камгалаары',
 'protect_change'    => 'өскертири',
 'protectthispage'   => 'Бо арынны камгалаар',
-'unprotect'         => 'Камгалалды ап каар',
-'unprotectthispage' => 'Бо арынның камгалалын ап каар',
+'unprotect'         => 'Камгалалды ырадыры',
+'unprotectthispage' => 'Бо арынның камгалалын ырадыры',
 'newpage'           => 'Чаа арын',
 'talkpage'          => 'Бо арын дугайында чугаалажыры',
 'talkpagelinktext'  => 'Чугаалажыры',
 'specialpage'       => 'Тускай арын',
 'personaltools'     => 'Хууда херекселдер',
 'postcomment'       => 'Чаа салбыр',
-'articlepage'       => 'Допчу арынны көөр',
+'articlepage'       => 'Допчу арынны көөрү',
 'talk'              => 'Чугаалажыры',
 'views'             => 'Көрүштер',
 'toolbox'           => 'Херекселдер',
-'userpage'          => 'Ажыглакчының арынын көөр',
-'projectpage'       => 'Проект арынын көөр',
-'imagepage'         => 'Файл арнызын көөр',
-'mediawikipage'     => 'Чагаа арынын көөр',
-'templatepage'      => 'Хээ арынын көөр',
-'viewhelppage'      => 'Дуза арынын көөр',
+'userpage'          => 'Ажыглакчының арынын көөрү',
+'projectpage'       => 'Проект арынын көөрү',
+'imagepage'         => 'Файлдың арынын көөрү',
+'mediawikipage'     => 'Чагаа арынын көөрү',
+'templatepage'      => 'Хээ арынын көөрү',
+'viewhelppage'      => 'Дуза арынын көөрү',
 'categorypage'      => 'Бөлүктүң арынын көөрү',
-'viewtalkpage'      => 'Чугаалажырыны көөр',
+'viewtalkpage'      => 'Чугааны көөрү',
 'otherlanguages'    => 'Өске дылдарга',
-'lastmodifiedat'    => 'Бо арын сөөлгү каттап $2, $1 өскерилген.', # $1 date, $2 time
+'lastmodifiedat'    => 'Бо арын сөөлгү каттап $2, $1 өскерилген.',
 'jumptonavigation'  => 'навигация',
 'jumptosearch'      => 'дилээри',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}} дугайында',
 'aboutpage'            => 'Project:Дугайында',
+'copyrightpage'        => '{{ns:project}}:Чогаалчының эргелери',
 'currentevents'        => 'Амгы үеде болуушкуннар',
 'currentevents-url'    => 'Project:Амгы үеде болуушкуннар',
-'disclaimers'          => 'Ажыглаарынка чомпээрежил',
+'disclaimers'          => 'Ажыглаарынка чомпээрежилдер',
+'disclaimerpage'       => 'Project:Ажыглаарынка чомпээрежил',
 'edithelp'             => 'Өскертиринге дуза',
 'edithelppage'         => 'Help:Өскертири',
 'helppage'             => 'Help:Допчузу',
@@ -228,53 +254,44 @@ $messages = array(
 
 # Main script and global functions
 'nosuchaction'      => 'Ындыг ажыл чок',
-'nosuchspecialpage' => 'Ындыг арын чок',
+'nosuchspecialpage' => 'Ындыг тускай арын чок',
 
 # General errors
 'error'              => 'Алдаг',
 'databaseerror'      => 'Медээ шыгжамыры алдаг',
-'noconnect'          => 'Буруулуг болдувус! Викиде чамдык техниктиг бергедээшкиннер бар болганындан database серверинче коштунмаан. <br />
-$1',
 'laggedslavemode'    => 'Оваарымчалыг: Бо арында чаартыышкыннар чок болуп болур',
 'readonly'           => 'шоочалаарынга медээ шыгжамыры',
+'missingarticle-rev' => '(үндүрериниң саны: $1)',
 'internalerror'      => 'Иштики алдаг',
 'internalerror_info' => 'Иштики алдаг: $1',
 'badtitle'           => 'Багай ат',
 'viewsource'         => 'Бажы көөрү',
 
 # Login and logout pages
-'logouttitle'        => 'Ажыглакчы үнери',
-'loginpagetitle'     => 'Ажыглакчы кирери',
-'yourname'           => 'Aжыглакчының ады',
-'yourpassword'       => 'Чажыт сөс',
-'remembermypassword' => 'Адымны сактып алыры',
-'login'              => 'Кирери',
-'userlogin'          => 'Кирери / кирерини чогаадып кылыры',
-'logout'             => 'Үнери',
-'userlogout'         => 'Үнери',
-'notloggedin'        => 'Кирери евес',
-'nologinlink'        => 'Кирерини чогаадып кылыры',
-'createaccount'      => 'Кирерини чогаадып кылыр',
-'gotaccountlink'     => 'Кирер',
-'createaccountmail'  => 'е-чагаа-биле',
-'badretype'          => 'Силерниң парлаан чажыт созуңер таарышпас.',
-'userexists'         => 'Силерниң парлаан адыңар амгы уеде ажыглаттынып турар. өске аттан шилип алыңар.',
-'youremail'          => 'Э-чагааңар:',
-'username'           => 'Aжыглакчының ады:',
-'yourrealname'       => 'Шын адыңар *',
-'yourlanguage'       => 'Дылыңар:',
-'yournick'           => 'Шола ат:',
-'gender-male'        => 'Эр',
-'gender-female'      => 'Кыс',
-'email'              => 'Э-чагаа',
-'loginerror'         => 'Багай кирери',
-'loginsuccesstitle'  => 'Чедимчелиг кирери',
-'mailmypassword'     => 'Меңээ чаа чажыт сөсту чорудаары',
-'accountcreated'     => 'Кирерини бүдүрген',
-'accountcreatedtext' => '$1 ажыглакчының кирерин бүдүрген.',
-'loginlanguagelabel' => 'Дыл: $1',
+'yourname'                => 'Aжыглакчының ады',
+'yourpassword'            => 'Чажыт сөс',
+'remembermypassword'      => 'Мени бо компютерде сактып алыры (for a maximum of $1 {{PLURAL:$1|day|days}})',
+'login'                   => 'Кирери',
+'nav-login-createaccount' => 'Кирери / бүрүткел бижикти бүдүрери',
+'userlogin'               => 'Кирери / бүрүткел бижикти бүдүрери',
+'userloginnocreate'       => 'Кирери',
+'logout'                  => 'Үнери',
+'userlogout'              => 'Үнери',
+'notloggedin'             => 'Кирбес',
+'nologinlink'             => 'Бүрүткел бижикти бүдүрери',
+'createaccount'           => 'Бүрүткел бижикти бүдүрери',
+'gotaccountlink'          => 'Кирер',
+'createaccountmail'       => 'е-чагаа-биле',
+'badretype'               => 'Силерниң парлаан чажыт созуңер таарышпас.',
+'userexists'              => 'Силерниң парлаан адыңар амгы уеде ажыглаттынып турар. өске аттан шилип алыңар.',
+'loginerror'              => 'Багай кирери',
+'loginsuccesstitle'       => 'Чедимчелиг кирери',
+'mailmypassword'          => 'Меңээ чаа чажыт сөсту чорудаары',
+'accountcreated'          => 'Бүрүткел бижикти бүдүрген',
+'accountcreatedtext'      => '$1 деп ажыглакчының бүрүткел бижиини бүдүрген.',
+'loginlanguagelabel'      => 'Дыл: $1',
 
-# Password reset dialog
+# Change password dialog
 'resetpass'                 => 'Чажыт сөзү өскертир',
 'resetpass_header'          => 'Чажыт сөстү катап чогаадып кылыры',
 'oldpassword'               => 'Эгри чажыт сөс:',
@@ -282,6 +299,7 @@ $1',
 'resetpass_submit'          => 'Чажыт сөстү чоогадып кылыр база кирер.',
 'resetpass_forbidden'       => 'Чажыт сөстү өскертивейн болбас',
 'resetpass-submit-loggedin' => 'Чажыт сөзү өскертири',
+'resetpass-submit-cancel'   => 'Соксаары',
 
 # Edit page toolbar
 'bold_sample'     => 'Карартыр',
@@ -291,10 +309,10 @@ $1',
 'extlink_sample'  => 'http://www.example.com холбаадың ады',
 'extlink_tip'     => 'Даштыкы холбаа ("http://" чүве сактып алыр)',
 'headline_sample' => 'Кол сөс сөзүглел',
-'math_sample'     => 'Формуланы мынаар киирери',
 'nowiki_sample'   => 'Форматтаваан сөзүглелини бээр салыры',
 'nowiki_tip'      => 'Вики форматтаарын херекке албас',
 'image_sample'    => 'Чижек.jpg',
+'image_tip'       => 'Киир туткан файл',
 'media_sample'    => 'Чижек.ogg',
 'media_tip'       => 'Файлдың холбаазы',
 
@@ -311,9 +329,11 @@ $1',
 'summary-preview'    => 'Түңнелдү чижеглей көөрү:',
 'subject-preview'    => 'Кол сөс чижеглей көөр:',
 'nosuchsectiontitle' => 'Бо салбыр чок',
-'loginreqlink'       => 'кирер',
+'loginreqlink'       => 'кирери',
 'accmailtitle'       => 'Чажыт сөс чоргустунган.',
-'accmailtext'        => '',
+'accmailtext'        => "A randomly generated password for [[User talk:$1|$1]] has been sent to $2.
+
+The password for this new account can be changed on the ''[[Special:ChangePassword|change password]]'' page upon logging in.",
 'newarticle'         => '(Чаа)',
 'editing'            => '$1 деп арынны өскертип турар',
 'editingsection'     => '$1 деп арынның салбырын өскертип турар',
@@ -323,8 +343,10 @@ $1',
 'template-protected' => '(камгалаан)',
 
 # History pages
+'viewpagelogs'           => 'Бо арынның журналын көргүзери',
 'nohistory'              => 'Бо арынның өскерлиишкин төөгүзү чок.',
 'currentrev'             => 'Амгы үе үндүрери',
+'revisionasof'           => '$1 ündüreri',
 'previousrevision'       => '←Артык эрги үндүрери',
 'nextrevision'           => 'Артык чаа үндүрери→',
 'currentrevisionlink'    => 'Амгы үе үндүрери',
@@ -334,7 +356,6 @@ $1',
 'page_first'             => 'бирги',
 'page_last'              => 'сөөлгү',
 'history-fieldset-title' => 'Каралаары төөгүзү',
-'deletedrev'             => '[ап каан]',
 'histfirst'              => 'Эң эрте',
 'histlast'               => 'Эң дээм чаагы',
 'historysize'            => '({{PLURAL:$1|$1 байт}})',
@@ -344,50 +365,61 @@ $1',
 'history-feed-title' => 'Үндүрериниң төөгүзү',
 
 # Revision deletion
-'rev-deleted-comment'    => '(комментарийни ап каан)',
-'rev-deleted-user'       => '(ажыглакчының адын ап каан)',
-'rev-deleted-event'      => '',
-'rev-delundel'           => 'көргүзери/чажырары',
-'revisiondelete'         => 'Үндүрерилерни ап каар/диргисир',
-'revdelete-hide-comment' => 'Өскерлиишкинниң комментарийн чажырар',
-'revdelete-hide-user'    => 'Чогаалчының адын/ИП-адресин чажырар',
-'revdelete-log'          => 'Чылдагаан:',
-'pagehist'               => 'Арынның төөгүзү',
+'rev-deleted-comment'        => '(комментарийни ап каан)',
+'rev-deleted-user'           => '(ажыглакчының адын ап каан)',
+'rev-deleted-event'          => '(log action removed)',
+'rev-delundel'               => 'көргүзери/чажырары',
+'rev-showdeleted'            => 'көргүзери',
+'revisiondelete'             => 'Үндүрерилерни ырадыры/диргисири',
+'revdelete-show-file-submit' => 'Ийе',
+'revdelete-hide-comment'     => 'Өскерлиишкинниң комментарийн чажырар',
+'revdelete-hide-user'        => 'Чогаалчының адын/ИП-адресин чажырар',
+'revdelete-radio-set'        => 'Ийе',
+'revdelete-radio-unset'      => 'Чок',
+'revdelete-log'              => 'Чылдагаан:',
+'pagehist'                   => 'Арынның төөгүзү',
+'revdelete-otherreason'      => 'Өске/немелде чылдагаан:',
+'revdelete-reasonotherlist'  => 'Өске чылдагаан',
 
 # History merging
 'mergehistory-reason' => 'Чылдагаан:',
 
+# Merge log
+'revertmerge' => 'Чарары',
+
 # Diffs
 'history-title'           => '"$1" деп арынның үндүрери төөгүзү',
-'lineno'                  => '$1 одуруг:',
+'lineno'                  => 'Одуруг $1:',
 'compareselectedversions' => 'Шилип алган хевирлери деңнээри',
-'diff-width'              => 'калбаа',
-'diff-height'             => 'бедии',
 
 # Search results
-'searchresults'            => 'Түңнелдер',
-'prevn'                    => 'бүрүнгү $1',
-'nextn'                    => 'соонда $1',
-'viewprevnext'             => '($1) ($2) ($3) көөрү',
-'searchhelp-url'           => 'Help:Допчузу',
-'searchprofile-everything' => 'Бүгүде',
-'search-result-size'       => '$1 ({{PLURAL:$2|$2 сөс}})',
-'search-section'           => '("$1" деп салбыр)',
-'searchall'                => 'шупту',
-'powersearch'              => '',
+'searchresults'             => 'Түңнелдер',
+'prevn'                     => 'бүрүнгү {{PLURAL:$1|$1}}',
+'nextn'                     => 'соонда {{PLURAL:$1|$1}}',
+'viewprevnext'              => '($1 {{int:pipe-separator}} $2) ($3) көөрү',
+'searchhelp-url'            => 'Help:Допчузу',
+'searchprofile-images'      => 'Мультимедиа',
+'searchprofile-everything'  => 'Бүгүде',
+'search-result-size'        => '$1 ({{PLURAL:$2|$2 сөс}})',
+'search-section'            => '("$1" деп салбыр)',
+'search-interwiki-more'     => '(артык)',
+'search-mwsuggest-enabled'  => 'саналдар',
+'search-mwsuggest-disabled' => 'саналдар чок',
+'searchall'                 => 'шупту',
+'powersearch'               => 'Advanced search',
+'powersearch-toggleall'     => 'Шупту',
 
 # Preferences page
 'preferences'               => 'Шилиирилер',
 'mypreferences'             => 'Мээң шилиирилерим',
 'changepassword'            => 'Чажыт сөстү өскертир',
-'skin'                      => 'Кеш',
+'prefs-skin'                => 'Кеш',
 'skin-preview'              => 'Чижеглей көөр',
-'math_unknown_error'        => 'билбес алдаг',
 'prefs-personal'            => 'Ажыглакчының медээлери',
 'prefs-rc'                  => 'Дээм чаагы өскерлиишкиннер',
 'prefs-watchlist'           => 'Хайгаарылга даңзызы',
 'saveprefs'                 => 'Шыгжаар',
-'textboxsize'               => 'Өскертир',
+'prefs-editing'             => 'Өскертир',
 'rows'                      => 'Одуруглар:',
 'columns'                   => 'Баганалар:',
 'searchresultshead'         => 'Дилээр',
@@ -400,10 +432,18 @@ $1',
 'timezoneregion-australia'  => 'Австралия',
 'timezoneregion-europe'     => 'Европа',
 'default'                   => 'ниити',
-'files'                     => 'файлдар',
+'prefs-files'               => 'файлдар',
+'youremail'                 => 'Э-чагааңар:',
+'username'                  => 'Aжыглакчының ады:',
+'yourrealname'              => 'Шын адыңар *',
+'yourlanguage'              => 'Дылыңар:',
+'yournick'                  => 'Шола ат:',
+'gender-male'               => 'Эр',
+'gender-female'             => 'Кыс',
+'email'                     => 'Э-чагаа',
 
 # User rights
-'editinguser'       => '',
+'editinguser'       => "Changing user rights of user '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]]{{int:pipe-separator}}[[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-reason' => 'Чылдагаан:',
 
 # Groups
@@ -426,17 +466,22 @@ $1',
 'grouppage-bureaucrat' => '{{ns:project}}:Бюрократтар',
 'grouppage-suppress'   => '{{ns:project}}:Хынакчы',
 
+# Rights
+'right-createaccount' => 'Чаа бүрүткел бижиктерин бүдүрери',
+
 # User rights log
 'rightsnone' => '(чок)',
 
 # Associated actions - in the sentence "You do not have permission to X"
-'action-read' => 'бо арынны номчууру',
-'action-edit' => 'бо арынны өскертири',
-'action-move' => 'бо арынны шимчээри',
+'action-read'          => 'бо арынны номчууру',
+'action-edit'          => 'бо арынны өскертири',
+'action-createaccount' => 'бо бүрүткел бижиктерин бүдүрери',
+'action-move'          => 'бо арынны шимчээри',
 
 # Recent changes
 'nchanges'                          => '$1 {{PLURAL:$1|өскерлиишкин}}',
 'recentchanges'                     => 'Амгы өскерлиишкиннер',
+'recentchanges-label-minor'         => 'Бо өскерлиишкин биче-дир',
 'rcshowhideminor'                   => 'Бичии өскерлиишкиннерни $1',
 'rcshowhidebots'                    => 'Роботтарну $1',
 'rcshowhideliu'                     => 'Кирер ажыглакчыларны $1',
@@ -451,6 +496,8 @@ $1',
 'boteditletter'                     => 'р',
 'number_of_watching_users_pageview' => '[$1 хайгаараар {{PLURAL:$1|ажыглакчы}}]',
 'newsectionsummary'                 => '/* $1 */ чаа салбыр',
+'rc-enhanced-expand'                => 'Тодаларны көргүзери (JavaScript херек)',
+'rc-enhanced-hide'                  => 'Тодаларны чажырары',
 
 # Recent changes linked
 'recentchangeslinked-page' => 'Арынның ады:',
@@ -458,7 +505,6 @@ $1',
 # Upload
 'upload'            => 'Файлды салыры',
 'uploadbtn'         => 'Файлды салыры',
-'reupload'          => 'Катап киирер',
 'uploadnologin'     => 'Кирбес',
 'uploaderror'       => 'Кииреринге алдаг',
 'filename'          => 'файлдың ады:',
@@ -481,26 +527,27 @@ $1',
 'listfiles_description' => 'Тодарадып бижээни',
 
 # File description page
-'filehist'           => 'Файлдың төөгүзү',
-'filehist-deleteall' => 'шуптуну ап каар',
-'filehist-deleteone' => 'ап каары',
-'filehist-current'   => 'амгы',
-'filehist-datetime'  => 'Үе/Шак',
-'filehist-thumb'     => 'Бичии чурук',
-'filehist-user'      => 'Ажыглакчы',
-'filehist-filesize'  => 'Файл хемчээли',
-'filehist-comment'   => 'Комментарий',
-'imagelinks'         => 'Файлдың xолбаалары',
-'noimage-linktext'   => 'Ону киирер',
+'file-anchor-link'    => 'Файл',
+'filehist'            => 'Файлдың төөгүзү',
+'filehist-deleteall'  => 'шуптуну ырадыры',
+'filehist-deleteone'  => 'ырадыры',
+'filehist-current'    => 'амгы',
+'filehist-datetime'   => 'Үе/Шак',
+'filehist-thumb'      => 'Бичии чурук',
+'filehist-user'       => 'Ажыглакчы',
+'filehist-dimensions' => 'Хемчээлдери',
+'filehist-filesize'   => 'Файл хемчээли',
+'filehist-comment'    => 'Тайылбыр',
+'imagelinks'          => 'Файлдың xолбаалары',
 
 # File reversion
 'filerevert-comment' => 'Чылдагаан:',
 
 # File deletion
-'filedelete'                  => '$1 деп файлды ап каар',
-'filedelete-legend'           => 'Файлды ап каар',
+'filedelete'                  => '$1 деп файлды ырадыры',
+'filedelete-legend'           => 'Файлды ырадыры',
 'filedelete-comment'          => 'Чылдагаан:',
-'filedelete-submit'           => 'Ап каары',
+'filedelete-submit'           => 'Ырадыры',
 'filedelete-otherreason'      => 'Өске/немелде чылдагаан:',
 'filedelete-reason-otherlist' => 'Өске чылдагаан',
 
@@ -520,8 +567,8 @@ $1',
 # Statistics
 'statistics' => 'Статистика',
 
-'brokenredirects-edit'   => '(өскертир)',
-'brokenredirects-delete' => '(ап каар)',
+'brokenredirects-edit'   => 'өскертири',
+'brokenredirects-delete' => 'ырадыры',
 
 'withoutinterwiki' => 'Дыл холбаалар эвес арыннар',
 
@@ -570,6 +617,7 @@ $1',
 
 # Special:AllPages
 'allpages'       => 'Шупту арыннар',
+'alphaindexline' => '$1 деп арындан $2 деп арында',
 'nextpage'       => 'Соонда арын ($1)',
 'prevpage'       => 'Бүрүнгү арын ($1)',
 'allarticles'    => 'Шупту арыннар',
@@ -580,9 +628,24 @@ $1',
 # Special:Categories
 'categories' => 'Бөлүктер',
 
+# Special:LinkSearch
+'linksearch' => 'Даштыкы холбаалар',
+
 # Special:ListUsers
 'listusers-submit' => 'Көргүзери',
 
+# Special:ActiveUsers
+'activeusers-hidebots'   => 'Роботтарны чажырары',
+'activeusers-hidesysops' => 'Эргелекчыларны чажырары',
+
+# Special:Log/newusers
+'newuserlogpage'           => 'Чаа ажыглакчы кырында журнал',
+'newuserlog-create-entry'  => 'Чаа бүрүткел бижик',
+'newuserlog-create2-entry' => '$1 деп чаа бүрүткел бижикти бүдүрген',
+
+# Special:ListGroupRights
+'listgrouprights-members' => '(кежигүннүң даңзызы)',
+
 # E-mail user
 'emailuser'       => 'Бо ажыглакчыга э-чагааны чорудаары',
 'defemailsubject' => '{{grammar:ablative|{{SITENAME}}}} э-чагаа',
@@ -611,8 +674,10 @@ $1',
 'enotif_anon_editor'           => 'ат эвес ажыглакчы $1',
 
 # Delete
-'deletepage'            => 'Арынны ап каары',
+'deletepage'            => 'Арынны ырадыры',
 'exblank'               => 'Арын куруг турган',
+'delete-confirm'        => '"$1" деп арынны ырадыры',
+'delete-legend'         => 'Ырадыры',
 'actioncomplete'        => 'Ажыл доосту',
 'deletedarticle'        => '"[[$1]]" деп арынны ап каан',
 'deletecomment'         => 'Чылдагаан:',
@@ -621,8 +686,9 @@ $1',
 
 # Protect
 'protectlogpage'         => 'Камгалал кырында журнал',
+'protectedarticle'       => '"[[$1]]" деп арынны камгалаан',
 'protectcomment'         => 'Чылдагаан:',
-'protect-default'        => '',
+'protect-default'        => 'Allow all users',
 'protect-level-sysop'    => 'Чүгле эргелекчылар',
 'protect-otherreason'    => 'Өске/немелде чылдагаан:',
 'protect-otherreason-op' => 'Өске чылдагаан',
@@ -635,7 +701,9 @@ $1',
 
 # Undelete
 'undeletebtn'            => 'Диргисир',
+'undeletelink'           => 'көөрү/диргисири',
 'undeletecomment'        => 'Чылдагаан:',
+'undeletedarticle'       => '"[[$1]]" диргискен',
 'undelete-search-submit' => 'Дилээр',
 
 # Namespace form on various pages
@@ -644,35 +712,43 @@ $1',
 # Contributions
 'contributions' => 'Ажыглакчыниң немелделери',
 'mycontris'     => 'Мээң немелделерим',
+'contribsub2'   => '$1 ($2)',
 'uctop'         => '(баш)',
+'month'         => 'Айдан:',
+'year'          => 'Чылдан:',
 
 'sp-contributions-newbies'  => 'Чүгле чаа кирерилерниң немелделерин көргүзерн',
+'sp-contributions-blocklog' => 'ниимиктээриге журнал',
 'sp-contributions-logs'     => 'журналдар',
+'sp-contributions-talk'     => 'чугаалажыры',
 'sp-contributions-username' => 'ИП-адрес азы ажыглачының ады:',
 'sp-contributions-submit'   => 'Дилээри',
 
 # What links here
-'whatlinkshere'           => 'Pages that link here',
 'whatlinkshere-page'      => 'Арын:',
 'isimage'                 => 'чуруктуң холбаазы',
 'whatlinkshere-links'     => '← холбаалар',
 'whatlinkshere-hidelinks' => 'холбааларны $1',
+'whatlinkshere-filters'   => 'Шүүрлер',
 
 # Block/unblock
-'ipaddress'                => 'ИП-адрес',
-'ipadressorusername'       => 'ИП-адрес азы aжыглaкчының aды',
-'ipbreason'                => 'Чылдагаан:',
-'ipbreasonotherlist'       => 'Өске чылдагаан',
-'ipbother'                 => 'Өске шак:',
-'ipboptions'               => '2 шак:2 hours,1 хүн:1 day,3 хүн:3 days,1 чеди-хонук:1 week,2 чеди-хонук:2 weeks,1 ай:1 month,3 ай:3 months,6 ай:6 months,1 чыл:1 year,төнмес-батпас:infinite', # display1:time1,display2:time2,...
-'ipbotheroption'           => 'өске',
-'ipbotherreason'           => 'Өске/немелде чылдагаан:',
-'badipaddress'             => 'Багай ИП-адрес',
-'ipblocklist-username'     => 'Ажыглакчының ады азы ИП-адрес:',
-'ipblocklist-submit'       => 'Дилээр',
-'infiniteblock'            => 'кезээ-мөңгеде',
-'contribslink'             => 'немелделер',
-'block-log-flags-anononly' => 'чүгле ат эвес ажыглакчылар',
+'blockip'                    => 'Ажыглакчыны ниимиктээри',
+'ipadressorusername'         => 'ИП-адрес азы aжыглaкчының aды',
+'ipbreason'                  => 'Чылдагаан:',
+'ipbreasonotherlist'         => 'Өске чылдагаан',
+'ipbother'                   => 'Өске шак:',
+'ipboptions'                 => '2 шак:2 hours,1 хүн:1 day,3 хүн:3 days,1 чеди-хонук:1 week,2 чеди-хонук:2 weeks,1 ай:1 month,3 ай:3 months,6 ай:6 months,1 чыл:1 year,төнмес-батпас:infinite',
+'ipbotheroption'             => 'өске',
+'ipbotherreason'             => 'Өске/немелде чылдагаан:',
+'badipaddress'               => 'Багай ИП-адрес',
+'ipblocklist-submit'         => 'Дилээр',
+'infiniteblock'              => 'кезээ-мөңгеде',
+'blocklink'                  => 'ниимиктээри',
+'contribslink'               => 'немелделер',
+'blocklogpage'               => 'Ниимиктээриге журнал',
+'blocklogentry'              => ', [[$1]] $2 дургузунда ниимиктээн: $3',
+'block-log-flags-anononly'   => 'чүгле ат эвес ажыглакчылар',
+'block-log-flags-hiddenname' => 'ажыглакчының ады чажырган',
 
 # Developer tools
 'lockdb'    => 'Медээ шыгжамырын шоочалаар',
@@ -686,14 +762,18 @@ $1',
 'newtitle'         => 'Чаа ат:',
 'move-watch'       => 'Бо арынны хайгаараары',
 'movepagebtn'      => 'Арынны шимчээри',
+'movelogpage'      => 'Шимчээринге журнал',
 'movereason'       => 'Чылдагаан:',
-'delete_and_move'  => 'Ап каар болгаш шимчээр',
+'delete_and_move'  => 'Ырадыры болгаш шимчээри',
 
 # Namespace 8 related
-'allmessages'        => 'Системниң дыңнадыглары',
-'allmessagesname'    => 'Ат',
-'allmessagesdefault' => 'Ниити сөзүглел',
-'allmessagescurrent' => 'Амгы сөзүглел',
+'allmessages'               => 'Системниң дыңнадыглары',
+'allmessagesname'           => 'Ат',
+'allmessagesdefault'        => 'Ниити сөзүглел',
+'allmessagescurrent'        => 'Амгы сөзүглел',
+'allmessages-filter-all'    => 'Шупту',
+'allmessages-language'      => 'Дыл:',
+'allmessages-filter-submit' => 'Күүcедири',
 
 # Special:Import
 'import-comment' => 'Комментарий:',
@@ -703,13 +783,15 @@ $1',
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'       => 'Силерниң ажыглакчы арыныңнар',
-'tooltip-pt-mytalk'         => 'Силерниң чугаалажыр арныңар',
+'tooltip-pt-mytalk'         => 'Силерниң чугаалажыр арыныңар',
 'tooltip-pt-mycontris'      => 'Силерниң немелделериңерның даңзызы',
 'tooltip-pt-logout'         => 'Үнери',
-'tooltip-ca-talk'           => 'Бо арынның допчузузу дугайында чыгаалажыры',
+'tooltip-ca-talk'           => 'Бо арын дугайында чыгаалажыры',
 'tooltip-ca-protect'        => 'Бо арынны камгалаары',
-'tooltip-ca-delete'         => 'Бо арынны ап каары',
+'tooltip-ca-delete'         => 'Бо арынны ырадыры',
 'tooltip-ca-move'           => 'Бо арынны шимчээри',
+'tooltip-ca-watch'          => 'Силерниң хайгаарылга даңзызынга бо арынны немээри',
+'tooltip-ca-unwatch'        => 'Силерниң хайгаарылга даңзызындан бо арынны ырадыры',
 'tooltip-search'            => '{{grammar:locative|{{SITENAME}}}} дилээри',
 'tooltip-p-logo'            => 'Кол Арын',
 'tooltip-n-mainpage'        => 'Кол Арынны баары',
@@ -729,6 +811,7 @@ $1',
 'tooltip-ca-nstab-help'     => 'Дуза арынын көөрү',
 'tooltip-ca-nstab-category' => 'Бөлүктүң арынын көөрү',
 'tooltip-save'              => 'Силерниң өскерлиишкиннериңерни шыгжаары',
+'tooltip-watch'             => 'Силерниң хайгаарылга даңзызынга бо арынны немээри',
 
 # Attribution
 'anonymous' => '{{grammar:genitive|{{SITENAME}}}} ат эвес {{PLURAL:$1|ажыглакчызы|ажыглакчылары}}',
@@ -752,9 +835,10 @@ $1',
 'widthheightpage' => '$1x$2, $3 {{PLURAL:$3|арын}}',
 
 # Special:NewFiles
-'showhidebots' => '(боцду $1)',
-'noimages'     => '',
-'ilsubmit'     => 'Дилээр',
+'newimages-legend' => 'Шүүрү',
+'showhidebots'     => '(роботтарны $1)',
+'noimages'         => 'Nothing to see.',
+'ilsubmit'         => 'Дилээр',
 
 # EXIF tags
 'exif-imagewidth'       => 'Калбаа',
@@ -767,16 +851,18 @@ $1',
 'exif-subjectdistancerange-3' => 'ырак көрүш',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'шупту',
-'imagelistall'     => 'шупту',
-'watchlistall2'    => 'шупту',
-'namespacesall'    => 'шупту',
-'monthsall'        => 'шупту',
+'watchlistall2' => 'шупту',
+'namespacesall' => 'шупту',
+'monthsall'     => 'шупту',
+'limitall'      => 'шупту',
+
+# action=purge
+'confirm_purge_button' => 'Чөп',
 
 # Multipage image navigation
-'imgmultipageprev' => '← бүрүнгү арын',
+'imgmultipageprev' => '← мурнунда арын',
 'imgmultipagenext' => 'соонда арын →',
-'imgmultigo'       => '',
+'imgmultigo'       => 'Go!',
 
 # Table pager
 'table_pager_next'         => 'Соонда арын',
@@ -787,21 +873,24 @@ $1',
 'table_pager_empty'        => 'Түңнеллер чок',
 
 # Auto-summaries
-'autosumm-new' => '',
+'autosumm-new' => 'Created page with "$1"',
 
 # Watchlist editor
 'watchlistedit-normal-title'  => 'Хайгаарылга даңзызын өскертири',
-'watchlistedit-normal-submit' => 'Адарны ап каары',
+'watchlistedit-normal-submit' => 'Аттарны ырадыры',
 'watchlistedit-raw-title'     => 'Чиг хайгаарылга даңзын өскертир',
 'watchlistedit-raw-legend'    => 'Чиг хайгаарылга даңзын өскертир',
-'watchlistedit-raw-titles'    => 'Адар:',
+'watchlistedit-raw-titles'    => 'Aттар:',
 
 # Watchlist editing tools
 'watchlisttools-edit' => 'Хайгаарылга даңзызын көөрү болгаш өскертири',
 'watchlisttools-raw'  => 'Чиг хайгаарылга даңзызын өскертири',
 
 # Special:Version
-'version' => 'Үндүрери', # Not used as normal message but as header for the special page itself
+'version'                  => 'Үндүрери',
+'version-specialpages'     => 'Тускай арыннар',
+'version-other'            => 'Өске',
+'version-software-version' => 'Үндүрери',
 
 # Special:FilePath
 'filepath-page'   => 'Файл:',
@@ -809,14 +898,24 @@ $1',
 
 # Special:FileDuplicateSearch
 'fileduplicatesearch-filename' => 'Файлдың ады:',
+'fileduplicatesearch-submit'   => 'Дилээри',
 
 # Special:SpecialPages
-'specialpages' => 'Тускай арыннар',
+'specialpages'             => 'Тускай арыннар',
+'specialpages-group-other' => 'Өске тускай арыннар',
 
 # Special:BlankPage
 'blankpage' => 'Куруг арын',
 
 # Special:Tags
-'tags-edit' => 'өскертири',
+'tag-filter-submit' => 'Шүүрү',
+'tags-edit'         => 'өскертири',
+
+# Special:ComparePages
+'compare-page1' => 'Арын 1',
+'compare-page2' => 'Арын 2',
+
+# HTML forms
+'htmlform-submit' => 'Күүcедири',
 
 );
