@@ -6,8 +6,12 @@
  *
  * @file
  */
+if ( isset( $_SERVER['MW_COMPILED'] ) ) {
+	require ( 'phase3/includes/WebStart.php' );
+} else {
+	require ( dirname( __FILE__ ) . '/includes/WebStart.php' );
+}
 
-require_once( './includes/WebStart.php' );
 global $wgArticlePath;
 
 $page = $wgRequest->getVal( 'wpDropdown' );
